diff -ru openssh-3.7.1p2.orig/auth.c openssh-3.7.1p2/auth.c
--- openssh-3.7.1p2.orig/auth.c	2003-09-03 07:32:46.000000000 +1000
+++ openssh-3.7.1p2/auth.c	2003-10-06 17:50:04.000000000 +1000
@@ -36,6 +36,10 @@
 #include <libgen.h>
 #endif
 
+#if defined(__hpux) && !defined(HAVE_SECUREWARE)
+#include <prot.h>
+#endif
+
 #include "xmalloc.h"
 #include "match.h"
 #include "groupaccess.h"
@@ -90,6 +94,7 @@
 #ifdef HAS_SHADOW_EXPIRE
 #define	DAY		(24L * 60 * 60) /* 1 day in seconds */
 	if (!options.use_pam && spw != NULL) {
+		int disabled = 0;
 		time_t today;
 
 		today = time(NULL) / DAY;
@@ -106,13 +111,19 @@
 			return 0;
 		}
 
-		if (spw->sp_lstchg == 0) {
+#if defined(__hpux) && !defined(HAVE_SECUREWARE)
+		if (iscomsec() && spw->sp_min == 0 && spw->sp_max == 0 &&
+		    spw->sp_warn == 0)
+			disabled = 1;	/* Trusted Mode: expiry disabled */
+#endif
+
+		if (!disabled && spw->sp_lstchg == 0) {
 			logit("User %.100s password has expired (root forced)",
 			    pw->pw_name);
 			return 0;
 		}
 
-		if (spw->sp_max != -1 &&
+		if (!disabled && spw->sp_max != -1 &&
 		    today > spw->sp_lstchg + spw->sp_max) {
 			logit("User %.100s password has expired (password aged)",
 			    pw->pw_name);
@@ -147,6 +158,15 @@
 		if (strstr(passwd, LOCKED_PASSWD_SUBSTR))
 			locked = 1;
 #endif
+#if defined(__hpux) && !defined(HAVE_SECUREWARE)
+		if (iscomsec()) {
+			struct pr_field *pr;
+
+			if ((pr = getprpwnam(pw->pw_name)) != NULL)
+				if (pr->fd_lock)
+					locked = 1;
+		}
+#endif
 		if (locked) {
 			logit("User %.100s not allowed because account is locked",
 			    pw->pw_name);
diff -ru openssh-3.7.1p2.orig/configure openssh-3.7.1p2/configure
--- openssh-3.7.1p2.orig/configure	2003-09-23 19:55:43.000000000 +1000
+++ openssh-3.7.1p2/configure	2003-10-06 16:13:39.000000000 +1000
@@ -3587,10 +3587,6 @@
 EOF
 
 	cat >>confdefs.h <<\EOF
-#define DISABLE_SHADOW 1
-EOF
-
-	cat >>confdefs.h <<\EOF
 #define DISABLE_UTMP 1
 EOF
 
@@ -3604,7 +3600,7 @@
 
 	LIBS="$LIBS -lsec -lsecpw"
 
-echo "$as_me:3607: checking for t_error in -lxnet" >&5
+echo "$as_me:3603: checking for t_error in -lxnet" >&5
 echo $ECHO_N "checking for t_error in -lxnet... $ECHO_C" >&6
 if test "${ac_cv_lib_xnet_t_error+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3612,7 +3608,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lxnet  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 3615 "configure"
+#line 3611 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -3631,16 +3627,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3634: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3630: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3637: \$? = $ac_status" >&5
+  echo "$as_me:3633: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3640: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3636: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3643: \$? = $ac_status" >&5
+  echo "$as_me:3639: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_xnet_t_error=yes
 else
@@ -3651,7 +3647,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:3654: result: $ac_cv_lib_xnet_t_error" >&5
+echo "$as_me:3650: result: $ac_cv_lib_xnet_t_error" >&5
 echo "${ECHO_T}$ac_cv_lib_xnet_t_error" >&6
 if test $ac_cv_lib_xnet_t_error = yes; then
   cat >>confdefs.h <<EOF
@@ -3661,7 +3657,7 @@
   LIBS="-lxnet $LIBS"
 
 else
-  { { echo "$as_me:3664: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
+  { { echo "$as_me:3660: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
 echo "$as_me: error: *** -lxnet needed on HP-UX - check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -3687,10 +3683,6 @@
 EOF
 
 	cat >>confdefs.h <<\EOF
-#define DISABLE_SHADOW 1
-EOF
-
-	cat >>confdefs.h <<\EOF
 #define DISABLE_UTMP 1
 EOF
 
@@ -3704,7 +3696,7 @@
 
 	LIBS="$LIBS -lsec"
 
-echo "$as_me:3707: checking for t_error in -lxnet" >&5
+echo "$as_me:3699: checking for t_error in -lxnet" >&5
 echo $ECHO_N "checking for t_error in -lxnet... $ECHO_C" >&6
 if test "${ac_cv_lib_xnet_t_error+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3712,7 +3704,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lxnet  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 3715 "configure"
+#line 3707 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -3731,16 +3723,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3734: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3726: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3737: \$? = $ac_status" >&5
+  echo "$as_me:3729: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3740: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3732: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3743: \$? = $ac_status" >&5
+  echo "$as_me:3735: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_xnet_t_error=yes
 else
@@ -3751,7 +3743,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:3754: result: $ac_cv_lib_xnet_t_error" >&5
+echo "$as_me:3746: result: $ac_cv_lib_xnet_t_error" >&5
 echo "${ECHO_T}$ac_cv_lib_xnet_t_error" >&6
 if test $ac_cv_lib_xnet_t_error = yes; then
   cat >>confdefs.h <<EOF
@@ -3761,7 +3753,7 @@
   LIBS="-lxnet $LIBS"
 
 else
-  { { echo "$as_me:3764: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
+  { { echo "$as_me:3756: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
 echo "$as_me: error: *** -lxnet needed on HP-UX - check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -3787,10 +3779,6 @@
 EOF
 
 	cat >>confdefs.h <<\EOF
-#define DISABLE_SHADOW 1
-EOF
-
-	cat >>confdefs.h <<\EOF
 #define DISABLE_UTMP 1
 EOF
 
@@ -3804,7 +3792,7 @@
 
 	LIBS="$LIBS -lsec"
 
-echo "$as_me:3807: checking for t_error in -lxnet" >&5
+echo "$as_me:3795: checking for t_error in -lxnet" >&5
 echo $ECHO_N "checking for t_error in -lxnet... $ECHO_C" >&6
 if test "${ac_cv_lib_xnet_t_error+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3812,7 +3800,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lxnet  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 3815 "configure"
+#line 3803 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -3831,16 +3819,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3834: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3822: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3837: \$? = $ac_status" >&5
+  echo "$as_me:3825: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3840: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3828: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3843: \$? = $ac_status" >&5
+  echo "$as_me:3831: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_xnet_t_error=yes
 else
@@ -3851,7 +3839,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:3854: result: $ac_cv_lib_xnet_t_error" >&5
+echo "$as_me:3842: result: $ac_cv_lib_xnet_t_error" >&5
 echo "${ECHO_T}$ac_cv_lib_xnet_t_error" >&6
 if test $ac_cv_lib_xnet_t_error = yes; then
   cat >>confdefs.h <<EOF
@@ -3861,7 +3849,7 @@
   LIBS="-lxnet $LIBS"
 
 else
-  { { echo "$as_me:3864: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
+  { { echo "$as_me:3852: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
 echo "$as_me: error: *** -lxnet needed on HP-UX - check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -3900,13 +3888,13 @@
 #define WITH_IRIX_AUDIT 1
 EOF
 
-	echo "$as_me:3903: checking for jlimit_startjob" >&5
+	echo "$as_me:3891: checking for jlimit_startjob" >&5
 echo $ECHO_N "checking for jlimit_startjob... $ECHO_C" >&6
 if test "${ac_cv_func_jlimit_startjob+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 3909 "configure"
+#line 3897 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char jlimit_startjob (); below.  */
@@ -3937,16 +3925,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3940: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3928: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3943: \$? = $ac_status" >&5
+  echo "$as_me:3931: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3946: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3934: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3949: \$? = $ac_status" >&5
+  echo "$as_me:3937: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_jlimit_startjob=yes
 else
@@ -3956,7 +3944,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:3959: result: $ac_cv_func_jlimit_startjob" >&5
+echo "$as_me:3947: result: $ac_cv_func_jlimit_startjob" >&5
 echo "${ECHO_T}$ac_cv_func_jlimit_startjob" >&6
 if test $ac_cv_func_jlimit_startjob = yes; then
   cat >>confdefs.h <<\EOF
@@ -4104,11 +4092,11 @@
 	external_path_file=/etc/default/login
 	# hardwire lastlog location (can't detect it on some versions)
 	conf_lastlog_location="/var/adm/lastlog"
-	echo "$as_me:4107: checking for obsolete utmp and wtmp in solaris2.x" >&5
+	echo "$as_me:4095: checking for obsolete utmp and wtmp in solaris2.x" >&5
 echo $ECHO_N "checking for obsolete utmp and wtmp in solaris2.x... $ECHO_C" >&6
 	sol2ver=`echo "$host"| sed -e 's/.*[0-9]\.//'`
 	if test "$sol2ver" -ge 8; then
-		echo "$as_me:4111: result: yes" >&5
+		echo "$as_me:4099: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 		cat >>confdefs.h <<\EOF
 #define DISABLE_UTMP 1
@@ -4119,7 +4107,7 @@
 EOF
 
 	else
-		echo "$as_me:4122: result: no" >&5
+		echo "$as_me:4110: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 	;;
@@ -4129,13 +4117,13 @@
 for ac_func in getpwanam
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:4132: checking for $ac_func" >&5
+echo "$as_me:4120: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4138 "configure"
+#line 4126 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -4166,16 +4154,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4169: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4157: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4172: \$? = $ac_status" >&5
+  echo "$as_me:4160: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4175: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4163: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4178: \$? = $ac_status" >&5
+  echo "$as_me:4166: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -4185,7 +4173,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4188: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:4176: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -4331,13 +4319,13 @@
 for ac_func in getluid setluid
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:4334: checking for $ac_func" >&5
+echo "$as_me:4322: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4340 "configure"
+#line 4328 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -4368,16 +4356,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4371: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4359: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4374: \$? = $ac_status" >&5
+  echo "$as_me:4362: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4377: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4365: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4380: \$? = $ac_status" >&5
+  echo "$as_me:4368: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -4387,7 +4375,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4390: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:4378: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -4443,13 +4431,13 @@
 for ac_func in getluid setluid
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:4446: checking for $ac_func" >&5
+echo "$as_me:4434: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4452 "configure"
+#line 4440 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -4480,16 +4468,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4483: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4471: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4486: \$? = $ac_status" >&5
+  echo "$as_me:4474: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4489: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4477: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4492: \$? = $ac_status" >&5
+  echo "$as_me:4480: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -4499,7 +4487,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4502: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:4490: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -4559,7 +4547,7 @@
 	MANTYPE=cat
 	;;
 *-dec-osf*)
-	echo "$as_me:4562: checking for Digital Unix SIA" >&5
+	echo "$as_me:4550: checking for Digital Unix SIA" >&5
 echo $ECHO_N "checking for Digital Unix SIA... $ECHO_C" >&6
 	no_osfsia=""
 
@@ -4568,7 +4556,7 @@
   withval="$with_osfsia"
 
 			if test "x$withval" = "xno" ; then
-				echo "$as_me:4571: result: disabled" >&5
+				echo "$as_me:4559: result: disabled" >&5
 echo "${ECHO_T}disabled" >&6
 				no_osfsia=1
 			fi
@@ -4576,7 +4564,7 @@
 fi;
 	if test -z "$no_osfsia" ; then
 		if test -f /etc/sia/matrix.conf; then
-			echo "$as_me:4579: result: yes" >&5
+			echo "$as_me:4567: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 			cat >>confdefs.h <<\EOF
 #define HAVE_OSF_SIA 1
@@ -4592,7 +4580,7 @@
 
 			LIBS="$LIBS -lsecurity -ldb -lm -laud"
 		else
-			echo "$as_me:4595: result: no" >&5
+			echo "$as_me:4583: result: no" >&5
 echo "${ECHO_T}no" >&6
 		fi
 	fi
@@ -4688,15 +4676,15 @@
 
 fi;
 
-echo "$as_me:4691: checking compiler and flags for sanity" >&5
+echo "$as_me:4679: checking compiler and flags for sanity" >&5
 echo $ECHO_N "checking compiler and flags for sanity... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:4694: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:4682: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4699 "configure"
+#line 4687 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -4704,26 +4692,26 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:4707: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4695: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4710: \$? = $ac_status" >&5
+  echo "$as_me:4698: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:4712: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4700: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4715: \$? = $ac_status" >&5
+  echo "$as_me:4703: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  	echo "$as_me:4717: result: yes" >&5
+  	echo "$as_me:4705: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:4724: result: no" >&5
+		echo "$as_me:4712: result: no" >&5
 echo "${ECHO_T}no" >&6
-		{ { echo "$as_me:4726: error: *** compiler cannot create working executables, check config.log ***" >&5
+		{ { echo "$as_me:4714: error: *** compiler cannot create working executables, check config.log ***" >&5
 echo "$as_me: error: *** compiler cannot create working executables, check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -4745,23 +4733,23 @@
 	util.h utime.h utmp.h utmpx.h vis.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:4748: checking for $ac_header" >&5
+echo "$as_me:4736: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4754 "configure"
+#line 4742 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:4758: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:4746: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:4764: \$? = $ac_status" >&5
+  echo "$as_me:4752: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -4780,7 +4768,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:4783: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:4771: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -4791,13 +4779,13 @@
 done
 
 # Checks for libraries.
-echo "$as_me:4794: checking for yp_match" >&5
+echo "$as_me:4782: checking for yp_match" >&5
 echo $ECHO_N "checking for yp_match... $ECHO_C" >&6
 if test "${ac_cv_func_yp_match+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4800 "configure"
+#line 4788 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char yp_match (); below.  */
@@ -4828,16 +4816,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4831: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4819: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4834: \$? = $ac_status" >&5
+  echo "$as_me:4822: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4837: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4825: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4840: \$? = $ac_status" >&5
+  echo "$as_me:4828: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_yp_match=yes
 else
@@ -4847,13 +4835,13 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4850: result: $ac_cv_func_yp_match" >&5
+echo "$as_me:4838: result: $ac_cv_func_yp_match" >&5
 echo "${ECHO_T}$ac_cv_func_yp_match" >&6
 if test $ac_cv_func_yp_match = yes; then
   :
 else
 
-echo "$as_me:4856: checking for yp_match in -lnsl" >&5
+echo "$as_me:4844: checking for yp_match in -lnsl" >&5
 echo $ECHO_N "checking for yp_match in -lnsl... $ECHO_C" >&6
 if test "${ac_cv_lib_nsl_yp_match+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4861,7 +4849,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lnsl  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 4864 "configure"
+#line 4852 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -4880,16 +4868,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4883: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4871: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4886: \$? = $ac_status" >&5
+  echo "$as_me:4874: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4889: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4877: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4892: \$? = $ac_status" >&5
+  echo "$as_me:4880: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_nsl_yp_match=yes
 else
@@ -4900,7 +4888,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:4903: result: $ac_cv_lib_nsl_yp_match" >&5
+echo "$as_me:4891: result: $ac_cv_lib_nsl_yp_match" >&5
 echo "${ECHO_T}$ac_cv_lib_nsl_yp_match" >&6
 if test $ac_cv_lib_nsl_yp_match = yes; then
   cat >>confdefs.h <<EOF
@@ -4913,13 +4901,13 @@
 
 fi
 
-echo "$as_me:4916: checking for setsockopt" >&5
+echo "$as_me:4904: checking for setsockopt" >&5
 echo $ECHO_N "checking for setsockopt... $ECHO_C" >&6
 if test "${ac_cv_func_setsockopt+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4922 "configure"
+#line 4910 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char setsockopt (); below.  */
@@ -4950,16 +4938,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4953: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4941: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4956: \$? = $ac_status" >&5
+  echo "$as_me:4944: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4959: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4947: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4962: \$? = $ac_status" >&5
+  echo "$as_me:4950: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_setsockopt=yes
 else
@@ -4969,13 +4957,13 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4972: result: $ac_cv_func_setsockopt" >&5
+echo "$as_me:4960: result: $ac_cv_func_setsockopt" >&5
 echo "${ECHO_T}$ac_cv_func_setsockopt" >&6
 if test $ac_cv_func_setsockopt = yes; then
   :
 else
 
-echo "$as_me:4978: checking for setsockopt in -lsocket" >&5
+echo "$as_me:4966: checking for setsockopt in -lsocket" >&5
 echo $ECHO_N "checking for setsockopt in -lsocket... $ECHO_C" >&6
 if test "${ac_cv_lib_socket_setsockopt+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4983,7 +4971,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lsocket  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 4986 "configure"
+#line 4974 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5002,16 +4990,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5005: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4993: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5008: \$? = $ac_status" >&5
+  echo "$as_me:4996: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5011: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4999: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5014: \$? = $ac_status" >&5
+  echo "$as_me:5002: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_socket_setsockopt=yes
 else
@@ -5022,7 +5010,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5025: result: $ac_cv_lib_socket_setsockopt" >&5
+echo "$as_me:5013: result: $ac_cv_lib_socket_setsockopt" >&5
 echo "${ECHO_T}$ac_cv_lib_socket_setsockopt" >&6
 if test $ac_cv_lib_socket_setsockopt = yes; then
   cat >>confdefs.h <<EOF
@@ -5037,7 +5025,7 @@
 
 if test "x$with_tcp_wrappers" != "xno" ; then
     if test "x$do_sco3_extra_lib_check" = "xyes" ; then
-	echo "$as_me:5040: checking for innetgr in -lrpc" >&5
+	echo "$as_me:5028: checking for innetgr in -lrpc" >&5
 echo $ECHO_N "checking for innetgr in -lrpc... $ECHO_C" >&6
 if test "${ac_cv_lib_rpc_innetgr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5045,7 +5033,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lrpc -lyp -lrpc $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5048 "configure"
+#line 5036 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5064,16 +5052,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5067: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5055: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5070: \$? = $ac_status" >&5
+  echo "$as_me:5058: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5073: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5061: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5076: \$? = $ac_status" >&5
+  echo "$as_me:5064: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_rpc_innetgr=yes
 else
@@ -5084,7 +5072,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5087: result: $ac_cv_lib_rpc_innetgr" >&5
+echo "$as_me:5075: result: $ac_cv_lib_rpc_innetgr" >&5
 echo "${ECHO_T}$ac_cv_lib_rpc_innetgr" >&6
 if test $ac_cv_lib_rpc_innetgr = yes; then
   LIBS="-lrpc -lyp -lrpc $LIBS"
@@ -5096,13 +5084,13 @@
 for ac_func in dirname
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:5099: checking for $ac_func" >&5
+echo "$as_me:5087: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5105 "configure"
+#line 5093 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -5133,16 +5121,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5136: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5124: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5139: \$? = $ac_status" >&5
+  echo "$as_me:5127: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5142: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5130: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5145: \$? = $ac_status" >&5
+  echo "$as_me:5133: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -5152,7 +5140,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:5155: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:5143: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -5162,23 +5150,23 @@
 for ac_header in libgen.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:5165: checking for $ac_header" >&5
+echo "$as_me:5153: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5171 "configure"
+#line 5159 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:5175: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:5163: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:5181: \$? = $ac_status" >&5
+  echo "$as_me:5169: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -5197,7 +5185,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:5200: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:5188: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -5209,7 +5197,7 @@
 
 else
 
-	echo "$as_me:5212: checking for dirname in -lgen" >&5
+	echo "$as_me:5200: checking for dirname in -lgen" >&5
 echo $ECHO_N "checking for dirname in -lgen... $ECHO_C" >&6
 if test "${ac_cv_lib_gen_dirname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5217,7 +5205,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgen  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5220 "configure"
+#line 5208 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5236,16 +5224,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5239: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5227: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5242: \$? = $ac_status" >&5
+  echo "$as_me:5230: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5245: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5233: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5248: \$? = $ac_status" >&5
+  echo "$as_me:5236: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gen_dirname=yes
 else
@@ -5256,11 +5244,11 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5259: result: $ac_cv_lib_gen_dirname" >&5
+echo "$as_me:5247: result: $ac_cv_lib_gen_dirname" >&5
 echo "${ECHO_T}$ac_cv_lib_gen_dirname" >&6
 if test $ac_cv_lib_gen_dirname = yes; then
 
-		echo "$as_me:5263: checking for broken dirname" >&5
+		echo "$as_me:5251: checking for broken dirname" >&5
 echo $ECHO_N "checking for broken dirname... $ECHO_C" >&6
 if test "${ac_cv_have_broken_dirname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5269,12 +5257,12 @@
 			save_LIBS="$LIBS"
 			LIBS="$LIBS -lgen"
 			if test "$cross_compiling" = yes; then
-  { { echo "$as_me:5272: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:5260: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5277 "configure"
+#line 5265 "configure"
 #include "confdefs.h"
 
 #include <libgen.h>
@@ -5294,15 +5282,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:5297: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5285: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5300: \$? = $ac_status" >&5
+  echo "$as_me:5288: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:5302: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5290: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5305: \$? = $ac_status" >&5
+  echo "$as_me:5293: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_broken_dirname="no"
 else
@@ -5317,7 +5305,7 @@
 			LIBS="$save_LIBS"
 
 fi
-echo "$as_me:5320: result: $ac_cv_have_broken_dirname" >&5
+echo "$as_me:5308: result: $ac_cv_have_broken_dirname" >&5
 echo "${ECHO_T}$ac_cv_have_broken_dirname" >&6
 		if test "x$ac_cv_have_broken_dirname" = "xno" ; then
 			LIBS="$LIBS -lgen"
@@ -5328,23 +5316,23 @@
 for ac_header in libgen.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:5331: checking for $ac_header" >&5
+echo "$as_me:5319: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5337 "configure"
+#line 5325 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:5341: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:5329: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:5347: \$? = $ac_status" >&5
+  echo "$as_me:5335: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -5363,7 +5351,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:5366: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:5354: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -5380,13 +5368,13 @@
 fi
 done
 
-echo "$as_me:5383: checking for getspnam" >&5
+echo "$as_me:5371: checking for getspnam" >&5
 echo $ECHO_N "checking for getspnam... $ECHO_C" >&6
 if test "${ac_cv_func_getspnam+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5389 "configure"
+#line 5377 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char getspnam (); below.  */
@@ -5417,16 +5405,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5420: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5408: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5423: \$? = $ac_status" >&5
+  echo "$as_me:5411: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5426: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5414: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5429: \$? = $ac_status" >&5
+  echo "$as_me:5417: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_getspnam=yes
 else
@@ -5436,12 +5424,12 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:5439: result: $ac_cv_func_getspnam" >&5
+echo "$as_me:5427: result: $ac_cv_func_getspnam" >&5
 echo "${ECHO_T}$ac_cv_func_getspnam" >&6
 if test $ac_cv_func_getspnam = yes; then
   :
 else
-  echo "$as_me:5444: checking for getspnam in -lgen" >&5
+  echo "$as_me:5432: checking for getspnam in -lgen" >&5
 echo $ECHO_N "checking for getspnam in -lgen... $ECHO_C" >&6
 if test "${ac_cv_lib_gen_getspnam+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5449,7 +5437,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgen  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5452 "configure"
+#line 5440 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5468,16 +5456,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5471: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5459: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5474: \$? = $ac_status" >&5
+  echo "$as_me:5462: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5477: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5465: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5480: \$? = $ac_status" >&5
+  echo "$as_me:5468: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gen_getspnam=yes
 else
@@ -5488,7 +5476,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5491: result: $ac_cv_lib_gen_getspnam" >&5
+echo "$as_me:5479: result: $ac_cv_lib_gen_getspnam" >&5
 echo "${ECHO_T}$ac_cv_lib_gen_getspnam" >&6
 if test $ac_cv_lib_gen_getspnam = yes; then
   LIBS="$LIBS -lgen"
@@ -5496,7 +5484,7 @@
 
 fi
 
-echo "$as_me:5499: checking for library containing basename" >&5
+echo "$as_me:5487: checking for library containing basename" >&5
 echo $ECHO_N "checking for library containing basename... $ECHO_C" >&6
 if test "${ac_cv_search_basename+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5504,7 +5492,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_basename=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 5507 "configure"
+#line 5495 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5523,16 +5511,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5526: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5514: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5529: \$? = $ac_status" >&5
+  echo "$as_me:5517: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5532: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5520: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5535: \$? = $ac_status" >&5
+  echo "$as_me:5523: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_basename="none required"
 else
@@ -5544,7 +5532,7 @@
   for ac_lib in gen; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 5547 "configure"
+#line 5535 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5563,16 +5551,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5566: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5554: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5569: \$? = $ac_status" >&5
+  echo "$as_me:5557: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5572: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5560: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5575: \$? = $ac_status" >&5
+  echo "$as_me:5563: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_basename="-l$ac_lib"
 break
@@ -5585,7 +5573,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:5588: result: $ac_cv_search_basename" >&5
+echo "$as_me:5576: result: $ac_cv_search_basename" >&5
 echo "${ECHO_T}$ac_cv_search_basename" >&6
 if test "$ac_cv_search_basename" != no; then
   test "$ac_cv_search_basename" = "none required" || LIBS="$ac_cv_search_basename $LIBS"
@@ -5613,7 +5601,7 @@
   withval="$with_zlib"
 
 		if test "x$withval" = "xno" ; then
-			{ { echo "$as_me:5616: error: *** zlib is required ***" >&5
+			{ { echo "$as_me:5604: error: *** zlib is required ***" >&5
 echo "$as_me: error: *** zlib is required ***" >&2;}
    { (exit 1); exit 1; }; }
 		fi
@@ -5638,7 +5626,7 @@
 
 fi;
 
-echo "$as_me:5641: checking for deflate in -lz" >&5
+echo "$as_me:5629: checking for deflate in -lz" >&5
 echo $ECHO_N "checking for deflate in -lz... $ECHO_C" >&6
 if test "${ac_cv_lib_z_deflate+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5646,7 +5634,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lz  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5649 "configure"
+#line 5637 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5665,16 +5653,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5668: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5656: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5671: \$? = $ac_status" >&5
+  echo "$as_me:5659: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5674: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5662: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5677: \$? = $ac_status" >&5
+  echo "$as_me:5665: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_z_deflate=yes
 else
@@ -5685,7 +5673,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5688: result: $ac_cv_lib_z_deflate" >&5
+echo "$as_me:5676: result: $ac_cv_lib_z_deflate" >&5
 echo "${ECHO_T}$ac_cv_lib_z_deflate" >&6
 if test $ac_cv_lib_z_deflate = yes; then
   cat >>confdefs.h <<EOF
@@ -5695,18 +5683,18 @@
   LIBS="-lz $LIBS"
 
 else
-  { { echo "$as_me:5698: error: *** zlib missing - please install first or check config.log ***" >&5
+  { { echo "$as_me:5686: error: *** zlib missing - please install first or check config.log ***" >&5
 echo "$as_me: error: *** zlib missing - please install first or check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 fi
 
-echo "$as_me:5703: checking for strcasecmp" >&5
+echo "$as_me:5691: checking for strcasecmp" >&5
 echo $ECHO_N "checking for strcasecmp... $ECHO_C" >&6
 if test "${ac_cv_func_strcasecmp+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5709 "configure"
+#line 5697 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char strcasecmp (); below.  */
@@ -5737,16 +5725,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5740: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5728: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5743: \$? = $ac_status" >&5
+  echo "$as_me:5731: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5746: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5734: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5749: \$? = $ac_status" >&5
+  echo "$as_me:5737: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_strcasecmp=yes
 else
@@ -5756,12 +5744,12 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:5759: result: $ac_cv_func_strcasecmp" >&5
+echo "$as_me:5747: result: $ac_cv_func_strcasecmp" >&5
 echo "${ECHO_T}$ac_cv_func_strcasecmp" >&6
 if test $ac_cv_func_strcasecmp = yes; then
   :
 else
-   echo "$as_me:5764: checking for strcasecmp in -lresolv" >&5
+   echo "$as_me:5752: checking for strcasecmp in -lresolv" >&5
 echo $ECHO_N "checking for strcasecmp in -lresolv... $ECHO_C" >&6
 if test "${ac_cv_lib_resolv_strcasecmp+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5769,7 +5757,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lresolv  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5772 "configure"
+#line 5760 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5788,16 +5776,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5791: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5779: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5794: \$? = $ac_status" >&5
+  echo "$as_me:5782: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5797: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5785: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5800: \$? = $ac_status" >&5
+  echo "$as_me:5788: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_resolv_strcasecmp=yes
 else
@@ -5808,7 +5796,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5811: result: $ac_cv_lib_resolv_strcasecmp" >&5
+echo "$as_me:5799: result: $ac_cv_lib_resolv_strcasecmp" >&5
 echo "${ECHO_T}$ac_cv_lib_resolv_strcasecmp" >&6
 if test $ac_cv_lib_resolv_strcasecmp = yes; then
   LIBS="$LIBS -lresolv"
@@ -5816,13 +5804,13 @@
 
 fi
 
-echo "$as_me:5819: checking for utimes" >&5
+echo "$as_me:5807: checking for utimes" >&5
 echo $ECHO_N "checking for utimes... $ECHO_C" >&6
 if test "${ac_cv_func_utimes+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5825 "configure"
+#line 5813 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char utimes (); below.  */
@@ -5853,16 +5841,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5856: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5844: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5859: \$? = $ac_status" >&5
+  echo "$as_me:5847: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5862: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5850: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5865: \$? = $ac_status" >&5
+  echo "$as_me:5853: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_utimes=yes
 else
@@ -5872,12 +5860,12 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:5875: result: $ac_cv_func_utimes" >&5
+echo "$as_me:5863: result: $ac_cv_func_utimes" >&5
 echo "${ECHO_T}$ac_cv_func_utimes" >&6
 if test $ac_cv_func_utimes = yes; then
   :
 else
-   echo "$as_me:5880: checking for utimes in -lc89" >&5
+   echo "$as_me:5868: checking for utimes in -lc89" >&5
 echo $ECHO_N "checking for utimes in -lc89... $ECHO_C" >&6
 if test "${ac_cv_lib_c89_utimes+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5885,7 +5873,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lc89  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5888 "configure"
+#line 5876 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5904,16 +5892,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5907: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5895: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5910: \$? = $ac_status" >&5
+  echo "$as_me:5898: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5913: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5901: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5916: \$? = $ac_status" >&5
+  echo "$as_me:5904: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_c89_utimes=yes
 else
@@ -5924,7 +5912,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5927: result: $ac_cv_lib_c89_utimes" >&5
+echo "$as_me:5915: result: $ac_cv_lib_c89_utimes" >&5
 echo "${ECHO_T}$ac_cv_lib_c89_utimes" >&6
 if test $ac_cv_lib_c89_utimes = yes; then
   cat >>confdefs.h <<\EOF
@@ -5939,23 +5927,23 @@
 for ac_header in libutil.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:5942: checking for $ac_header" >&5
+echo "$as_me:5930: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5948 "configure"
+#line 5936 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:5952: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:5940: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:5958: \$? = $ac_status" >&5
+  echo "$as_me:5946: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -5974,7 +5962,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:5977: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:5965: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -5984,7 +5972,7 @@
 fi
 done
 
-echo "$as_me:5987: checking for library containing login" >&5
+echo "$as_me:5975: checking for library containing login" >&5
 echo $ECHO_N "checking for library containing login... $ECHO_C" >&6
 if test "${ac_cv_search_login+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5992,7 +5980,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_login=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 5995 "configure"
+#line 5983 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6011,16 +5999,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6014: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6002: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6017: \$? = $ac_status" >&5
+  echo "$as_me:6005: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6020: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6008: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6023: \$? = $ac_status" >&5
+  echo "$as_me:6011: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_login="none required"
 else
@@ -6032,7 +6020,7 @@
   for ac_lib in util bsd; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 6035 "configure"
+#line 6023 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6051,16 +6039,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6054: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6042: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6057: \$? = $ac_status" >&5
+  echo "$as_me:6045: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6060: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6048: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6063: \$? = $ac_status" >&5
+  echo "$as_me:6051: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_login="-l$ac_lib"
 break
@@ -6073,7 +6061,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:6076: result: $ac_cv_search_login" >&5
+echo "$as_me:6064: result: $ac_cv_search_login" >&5
 echo "${ECHO_T}$ac_cv_search_login" >&6
 if test "$ac_cv_search_login" != no; then
   test "$ac_cv_search_login" = "none required" || LIBS="$ac_cv_search_login $LIBS"
@@ -6086,13 +6074,13 @@
 for ac_func in logout updwtmp logwtmp
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:6089: checking for $ac_func" >&5
+echo "$as_me:6077: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6095 "configure"
+#line 6083 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -6123,16 +6111,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6126: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6114: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6129: \$? = $ac_status" >&5
+  echo "$as_me:6117: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6132: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6120: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6135: \$? = $ac_status" >&5
+  echo "$as_me:6123: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -6142,7 +6130,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6145: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:6133: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -6155,13 +6143,13 @@
 for ac_func in strftime
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:6158: checking for $ac_func" >&5
+echo "$as_me:6146: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6164 "configure"
+#line 6152 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -6192,16 +6180,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6195: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6183: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6198: \$? = $ac_status" >&5
+  echo "$as_me:6186: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6201: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6189: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6204: \$? = $ac_status" >&5
+  echo "$as_me:6192: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -6211,7 +6199,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6214: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:6202: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -6220,7 +6208,7 @@
 
 else
   # strftime is in -lintl on SCO UNIX.
-echo "$as_me:6223: checking for strftime in -lintl" >&5
+echo "$as_me:6211: checking for strftime in -lintl" >&5
 echo $ECHO_N "checking for strftime in -lintl... $ECHO_C" >&6
 if test "${ac_cv_lib_intl_strftime+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6228,7 +6216,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lintl  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 6231 "configure"
+#line 6219 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6247,16 +6235,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6250: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6238: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6253: \$? = $ac_status" >&5
+  echo "$as_me:6241: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6256: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6244: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6259: \$? = $ac_status" >&5
+  echo "$as_me:6247: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_intl_strftime=yes
 else
@@ -6267,7 +6255,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:6270: result: $ac_cv_lib_intl_strftime" >&5
+echo "$as_me:6258: result: $ac_cv_lib_intl_strftime" >&5
 echo "${ECHO_T}$ac_cv_lib_intl_strftime" >&6
 if test $ac_cv_lib_intl_strftime = yes; then
   cat >>confdefs.h <<\EOF
@@ -6281,10 +6269,10 @@
 done
 
 # Check for ALTDIRFUNC glob() extension
-echo "$as_me:6284: checking for GLOB_ALTDIRFUNC support" >&5
+echo "$as_me:6272: checking for GLOB_ALTDIRFUNC support" >&5
 echo $ECHO_N "checking for GLOB_ALTDIRFUNC support... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 6287 "configure"
+#line 6275 "configure"
 #include "confdefs.h"
 
 		#include <glob.h>
@@ -6300,22 +6288,22 @@
 #define GLOB_HAS_ALTDIRFUNC 1
 EOF
 
-		echo "$as_me:6303: result: yes" >&5
+		echo "$as_me:6291: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
 
-		echo "$as_me:6308: result: no" >&5
+		echo "$as_me:6296: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest*
 
 # Check for g.gl_matchc glob() extension
-echo "$as_me:6315: checking for gl_matchc field in glob_t" >&5
+echo "$as_me:6303: checking for gl_matchc field in glob_t" >&5
 echo $ECHO_N "checking for gl_matchc field in glob_t... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 6318 "configure"
+#line 6306 "configure"
 #include "confdefs.h"
 
                 #include <glob.h>
@@ -6329,26 +6317,26 @@
 #define GLOB_HAS_GL_MATCHC 1
 EOF
 
-                echo "$as_me:6332: result: yes" >&5
+                echo "$as_me:6320: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
 
-                echo "$as_me:6337: result: no" >&5
+                echo "$as_me:6325: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest*
 
-echo "$as_me:6343: checking whether struct dirent allocates space for d_name" >&5
+echo "$as_me:6331: checking whether struct dirent allocates space for d_name" >&5
 echo $ECHO_N "checking whether struct dirent allocates space for d_name... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:6346: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:6334: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6351 "configure"
+#line 6339 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -6357,24 +6345,24 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:6360: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6348: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6363: \$? = $ac_status" >&5
+  echo "$as_me:6351: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:6365: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6353: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6368: \$? = $ac_status" >&5
+  echo "$as_me:6356: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:6370: result: yes" >&5
+  echo "$as_me:6358: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:6377: result: no" >&5
+		echo "$as_me:6365: result: no" >&5
 echo "${ECHO_T}no" >&6
 		cat >>confdefs.h <<\EOF
 #define BROKEN_ONE_BYTE_DIRENT_D_NAME 1
@@ -6405,15 +6393,15 @@
 			LIBS="-lskey $LIBS"
 			SKEY_MSG="yes"
 
-			echo "$as_me:6408: checking for s/key support" >&5
+			echo "$as_me:6396: checking for s/key support" >&5
 echo $ECHO_N "checking for s/key support... $ECHO_C" >&6
 			if test "$cross_compiling" = yes; then
-  { { echo "$as_me:6411: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:6399: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6416 "configure"
+#line 6404 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -6422,26 +6410,26 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:6425: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6413: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6428: \$? = $ac_status" >&5
+  echo "$as_me:6416: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:6430: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6418: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6433: \$? = $ac_status" >&5
+  echo "$as_me:6421: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:6435: result: yes" >&5
+  echo "$as_me:6423: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-					echo "$as_me:6442: result: no" >&5
+					echo "$as_me:6430: result: no" >&5
 echo "${ECHO_T}no" >&6
-					{ { echo "$as_me:6444: error: ** Incomplete or missing s/key libraries." >&5
+					{ { echo "$as_me:6432: error: ** Incomplete or missing s/key libraries." >&5
 echo "$as_me: error: ** Incomplete or missing s/key libraries." >&2;}
    { (exit 1); exit 1; }; }
 
@@ -6485,10 +6473,10 @@
 			fi
 			LIBWRAP="-lwrap"
 			LIBS="$LIBWRAP $LIBS"
-			echo "$as_me:6488: checking for libwrap" >&5
+			echo "$as_me:6476: checking for libwrap" >&5
 echo $ECHO_N "checking for libwrap... $ECHO_C" >&6
 			cat >conftest.$ac_ext <<_ACEOF
-#line 6491 "configure"
+#line 6479 "configure"
 #include "confdefs.h"
 
 #include <tcpd.h>
@@ -6503,19 +6491,19 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6506: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6494: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6509: \$? = $ac_status" >&5
+  echo "$as_me:6497: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6512: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6500: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6515: \$? = $ac_status" >&5
+  echo "$as_me:6503: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
-					echo "$as_me:6518: result: yes" >&5
+					echo "$as_me:6506: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 					cat >>confdefs.h <<\EOF
 #define LIBWRAP 1
@@ -6527,7 +6515,7 @@
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-					{ { echo "$as_me:6530: error: *** libwrap missing" >&5
+					{ { echo "$as_me:6518: error: *** libwrap missing" >&5
 echo "$as_me: error: *** libwrap missing" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -6554,13 +6542,13 @@
 
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:6557: checking for $ac_func" >&5
+echo "$as_me:6545: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6563 "configure"
+#line 6551 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -6591,16 +6579,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6594: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6582: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6597: \$? = $ac_status" >&5
+  echo "$as_me:6585: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6600: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6588: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6603: \$? = $ac_status" >&5
+  echo "$as_me:6591: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -6610,7 +6598,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6613: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:6601: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -6625,13 +6613,13 @@
 for ac_func in gai_strerror
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:6628: checking for $ac_func" >&5
+echo "$as_me:6616: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6634 "configure"
+#line 6622 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -6662,16 +6650,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6665: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6653: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6668: \$? = $ac_status" >&5
+  echo "$as_me:6656: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6671: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6659: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6674: \$? = $ac_status" >&5
+  echo "$as_me:6662: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -6681,7 +6669,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6684: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:6672: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -6693,7 +6681,7 @@
 EOF
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 6696 "configure"
+#line 6684 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -6713,16 +6701,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:6716: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:6704: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:6719: \$? = $ac_status" >&5
+  echo "$as_me:6707: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:6722: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6710: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6725: \$? = $ac_status" >&5
+  echo "$as_me:6713: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 cat >>confdefs.h <<\EOF
@@ -6737,7 +6725,7 @@
 fi
 done
 
-echo "$as_me:6740: checking for library containing nanosleep" >&5
+echo "$as_me:6728: checking for library containing nanosleep" >&5
 echo $ECHO_N "checking for library containing nanosleep... $ECHO_C" >&6
 if test "${ac_cv_search_nanosleep+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6745,7 +6733,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_nanosleep=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 6748 "configure"
+#line 6736 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6764,16 +6752,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6767: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6755: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6770: \$? = $ac_status" >&5
+  echo "$as_me:6758: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6773: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6761: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6776: \$? = $ac_status" >&5
+  echo "$as_me:6764: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_nanosleep="none required"
 else
@@ -6785,7 +6773,7 @@
   for ac_lib in rt posix4; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 6788 "configure"
+#line 6776 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6804,16 +6792,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6807: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6795: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6810: \$? = $ac_status" >&5
+  echo "$as_me:6798: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6813: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6801: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6816: \$? = $ac_status" >&5
+  echo "$as_me:6804: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_nanosleep="-l$ac_lib"
 break
@@ -6826,7 +6814,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:6829: result: $ac_cv_search_nanosleep" >&5
+echo "$as_me:6817: result: $ac_cv_search_nanosleep" >&5
 echo "${ECHO_T}$ac_cv_search_nanosleep" >&6
 if test "$ac_cv_search_nanosleep" != no; then
   test "$ac_cv_search_nanosleep" = "none required" || LIBS="$ac_cv_search_nanosleep $LIBS"
@@ -6836,13 +6824,13 @@
 
 fi
 
-echo "$as_me:6839: checking for ANSI C header files" >&5
+echo "$as_me:6827: checking for ANSI C header files" >&5
 echo $ECHO_N "checking for ANSI C header files... $ECHO_C" >&6
 if test "${ac_cv_header_stdc+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6845 "configure"
+#line 6833 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 #include <stdarg.h>
@@ -6850,13 +6838,13 @@
 #include <float.h>
 
 _ACEOF
-if { (eval echo "$as_me:6853: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:6841: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:6859: \$? = $ac_status" >&5
+  echo "$as_me:6847: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -6878,7 +6866,7 @@
 if test $ac_cv_header_stdc = yes; then
   # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
   cat >conftest.$ac_ext <<_ACEOF
-#line 6881 "configure"
+#line 6869 "configure"
 #include "confdefs.h"
 #include <string.h>
 
@@ -6896,7 +6884,7 @@
 if test $ac_cv_header_stdc = yes; then
   # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
   cat >conftest.$ac_ext <<_ACEOF
-#line 6899 "configure"
+#line 6887 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 
@@ -6917,7 +6905,7 @@
   :
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6920 "configure"
+#line 6908 "configure"
 #include "confdefs.h"
 #include <ctype.h>
 #if ((' ' & 0x0FF) == 0x020)
@@ -6943,15 +6931,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:6946: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6934: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6949: \$? = $ac_status" >&5
+  echo "$as_me:6937: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:6951: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6939: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6954: \$? = $ac_status" >&5
+  echo "$as_me:6942: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -6964,7 +6952,7 @@
 fi
 fi
 fi
-echo "$as_me:6967: result: $ac_cv_header_stdc" >&5
+echo "$as_me:6955: result: $ac_cv_header_stdc" >&5
 echo "${ECHO_T}$ac_cv_header_stdc" >&6
 if test $ac_cv_header_stdc = yes; then
 
@@ -6980,28 +6968,28 @@
                   inttypes.h stdint.h unistd.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:6983: checking for $ac_header" >&5
+echo "$as_me:6971: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6989 "configure"
+#line 6977 "configure"
 #include "confdefs.h"
 $ac_includes_default
 #include <$ac_header>
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:6995: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:6983: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:6998: \$? = $ac_status" >&5
+  echo "$as_me:6986: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:7001: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6989: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7004: \$? = $ac_status" >&5
+  echo "$as_me:6992: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_Header=yes"
 else
@@ -7011,7 +6999,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:7014: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:7002: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7021,13 +7009,13 @@
 fi
 done
 
-echo "$as_me:7024: checking whether strsep is declared" >&5
+echo "$as_me:7012: checking whether strsep is declared" >&5
 echo $ECHO_N "checking whether strsep is declared... $ECHO_C" >&6
 if test "${ac_cv_have_decl_strsep+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7030 "configure"
+#line 7018 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -7042,16 +7030,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:7045: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:7033: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:7048: \$? = $ac_status" >&5
+  echo "$as_me:7036: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:7051: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7039: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7054: \$? = $ac_status" >&5
+  echo "$as_me:7042: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_have_decl_strsep=yes
 else
@@ -7061,20 +7049,20 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:7064: result: $ac_cv_have_decl_strsep" >&5
+echo "$as_me:7052: result: $ac_cv_have_decl_strsep" >&5
 echo "${ECHO_T}$ac_cv_have_decl_strsep" >&6
 if test $ac_cv_have_decl_strsep = yes; then
 
 for ac_func in strsep
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7071: checking for $ac_func" >&5
+echo "$as_me:7059: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7077 "configure"
+#line 7065 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7105,16 +7093,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7108: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7096: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7111: \$? = $ac_status" >&5
+  echo "$as_me:7099: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7114: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7102: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7117: \$? = $ac_status" >&5
+  echo "$as_me:7105: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7124,7 +7112,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7127: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7115: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7136,13 +7124,13 @@
 
 fi
 
-echo "$as_me:7139: checking whether getrusage is declared" >&5
+echo "$as_me:7127: checking whether getrusage is declared" >&5
 echo $ECHO_N "checking whether getrusage is declared... $ECHO_C" >&6
 if test "${ac_cv_have_decl_getrusage+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7145 "configure"
+#line 7133 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -7157,16 +7145,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:7160: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:7148: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:7163: \$? = $ac_status" >&5
+  echo "$as_me:7151: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:7166: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7154: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7169: \$? = $ac_status" >&5
+  echo "$as_me:7157: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_have_decl_getrusage=yes
 else
@@ -7176,20 +7164,20 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:7179: result: $ac_cv_have_decl_getrusage" >&5
+echo "$as_me:7167: result: $ac_cv_have_decl_getrusage" >&5
 echo "${ECHO_T}$ac_cv_have_decl_getrusage" >&6
 if test $ac_cv_have_decl_getrusage = yes; then
 
 for ac_func in getrusage
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7186: checking for $ac_func" >&5
+echo "$as_me:7174: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7192 "configure"
+#line 7180 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7220,16 +7208,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7223: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7211: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7226: \$? = $ac_status" >&5
+  echo "$as_me:7214: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7229: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7217: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7232: \$? = $ac_status" >&5
+  echo "$as_me:7220: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7239,7 +7227,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7242: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7230: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7251,13 +7239,13 @@
 
 fi
 
-echo "$as_me:7254: checking whether tcsendbreak is declared" >&5
+echo "$as_me:7242: checking whether tcsendbreak is declared" >&5
 echo $ECHO_N "checking whether tcsendbreak is declared... $ECHO_C" >&6
 if test "${ac_cv_have_decl_tcsendbreak+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7260 "configure"
+#line 7248 "configure"
 #include "confdefs.h"
 #include <termios.h>
 
@@ -7273,16 +7261,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:7276: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:7264: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:7279: \$? = $ac_status" >&5
+  echo "$as_me:7267: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:7282: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7270: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7285: \$? = $ac_status" >&5
+  echo "$as_me:7273: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_have_decl_tcsendbreak=yes
 else
@@ -7292,7 +7280,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:7295: result: $ac_cv_have_decl_tcsendbreak" >&5
+echo "$as_me:7283: result: $ac_cv_have_decl_tcsendbreak" >&5
 echo "${ECHO_T}$ac_cv_have_decl_tcsendbreak" >&6
 if test $ac_cv_have_decl_tcsendbreak = yes; then
   cat >>confdefs.h <<\EOF
@@ -7304,13 +7292,13 @@
 for ac_func in tcsendbreak
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7307: checking for $ac_func" >&5
+echo "$as_me:7295: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7313 "configure"
+#line 7301 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7341,16 +7329,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7344: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7332: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7347: \$? = $ac_status" >&5
+  echo "$as_me:7335: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7350: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7338: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7353: \$? = $ac_status" >&5
+  echo "$as_me:7341: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7360,7 +7348,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7363: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7351: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7375,13 +7363,13 @@
 for ac_func in gettimeofday time
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7378: checking for $ac_func" >&5
+echo "$as_me:7366: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7384 "configure"
+#line 7372 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7412,16 +7400,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7415: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7403: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7418: \$? = $ac_status" >&5
+  echo "$as_me:7406: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7421: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7409: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7424: \$? = $ac_status" >&5
+  echo "$as_me:7412: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7431,7 +7419,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7434: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7422: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7444,13 +7432,13 @@
 for ac_func in endutent getutent getutid getutline pututline setutent
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7447: checking for $ac_func" >&5
+echo "$as_me:7435: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7453 "configure"
+#line 7441 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7481,16 +7469,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7484: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7472: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7487: \$? = $ac_status" >&5
+  echo "$as_me:7475: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7490: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7478: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7493: \$? = $ac_status" >&5
+  echo "$as_me:7481: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7500,7 +7488,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7503: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7491: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7513,13 +7501,13 @@
 for ac_func in utmpname
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7516: checking for $ac_func" >&5
+echo "$as_me:7504: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7522 "configure"
+#line 7510 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7550,16 +7538,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7553: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7541: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7556: \$? = $ac_status" >&5
+  echo "$as_me:7544: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7559: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7547: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7562: \$? = $ac_status" >&5
+  echo "$as_me:7550: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7569,7 +7557,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7572: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7560: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7582,13 +7570,13 @@
 for ac_func in endutxent getutxent getutxid getutxline pututxline
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7585: checking for $ac_func" >&5
+echo "$as_me:7573: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7591 "configure"
+#line 7579 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7619,16 +7607,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7622: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7610: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7625: \$? = $ac_status" >&5
+  echo "$as_me:7613: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7628: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7616: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7631: \$? = $ac_status" >&5
+  echo "$as_me:7619: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7638,7 +7626,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7641: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7629: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7651,13 +7639,13 @@
 for ac_func in setutxent utmpxname
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7654: checking for $ac_func" >&5
+echo "$as_me:7642: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7660 "configure"
+#line 7648 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7688,16 +7676,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7691: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7679: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7694: \$? = $ac_status" >&5
+  echo "$as_me:7682: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7697: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7685: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7700: \$? = $ac_status" >&5
+  echo "$as_me:7688: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7707,7 +7695,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7710: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7698: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7717,13 +7705,13 @@
 fi
 done
 
-echo "$as_me:7720: checking for daemon" >&5
+echo "$as_me:7708: checking for daemon" >&5
 echo $ECHO_N "checking for daemon... $ECHO_C" >&6
 if test "${ac_cv_func_daemon+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7726 "configure"
+#line 7714 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char daemon (); below.  */
@@ -7754,16 +7742,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7757: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7745: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7760: \$? = $ac_status" >&5
+  echo "$as_me:7748: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7763: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7751: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7766: \$? = $ac_status" >&5
+  echo "$as_me:7754: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_daemon=yes
 else
@@ -7773,7 +7761,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7776: result: $ac_cv_func_daemon" >&5
+echo "$as_me:7764: result: $ac_cv_func_daemon" >&5
 echo "${ECHO_T}$ac_cv_func_daemon" >&6
 if test $ac_cv_func_daemon = yes; then
   cat >>confdefs.h <<\EOF
@@ -7781,7 +7769,7 @@
 EOF
 
 else
-  echo "$as_me:7784: checking for daemon in -lbsd" >&5
+  echo "$as_me:7772: checking for daemon in -lbsd" >&5
 echo $ECHO_N "checking for daemon in -lbsd... $ECHO_C" >&6
 if test "${ac_cv_lib_bsd_daemon+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -7789,7 +7777,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lbsd  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 7792 "configure"
+#line 7780 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -7808,16 +7796,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7811: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7799: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7814: \$? = $ac_status" >&5
+  echo "$as_me:7802: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7817: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7805: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7820: \$? = $ac_status" >&5
+  echo "$as_me:7808: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_bsd_daemon=yes
 else
@@ -7828,7 +7816,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:7831: result: $ac_cv_lib_bsd_daemon" >&5
+echo "$as_me:7819: result: $ac_cv_lib_bsd_daemon" >&5
 echo "${ECHO_T}$ac_cv_lib_bsd_daemon" >&6
 if test $ac_cv_lib_bsd_daemon = yes; then
   LIBS="$LIBS -lbsd"; cat >>confdefs.h <<\EOF
@@ -7839,13 +7827,13 @@
 
 fi
 
-echo "$as_me:7842: checking for getpagesize" >&5
+echo "$as_me:7830: checking for getpagesize" >&5
 echo $ECHO_N "checking for getpagesize... $ECHO_C" >&6
 if test "${ac_cv_func_getpagesize+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7848 "configure"
+#line 7836 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char getpagesize (); below.  */
@@ -7876,16 +7864,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7879: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7867: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7882: \$? = $ac_status" >&5
+  echo "$as_me:7870: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7885: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7873: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7888: \$? = $ac_status" >&5
+  echo "$as_me:7876: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_getpagesize=yes
 else
@@ -7895,7 +7883,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7898: result: $ac_cv_func_getpagesize" >&5
+echo "$as_me:7886: result: $ac_cv_func_getpagesize" >&5
 echo "${ECHO_T}$ac_cv_func_getpagesize" >&6
 if test $ac_cv_func_getpagesize = yes; then
   cat >>confdefs.h <<\EOF
@@ -7903,7 +7891,7 @@
 EOF
 
 else
-  echo "$as_me:7906: checking for getpagesize in -lucb" >&5
+  echo "$as_me:7894: checking for getpagesize in -lucb" >&5
 echo $ECHO_N "checking for getpagesize in -lucb... $ECHO_C" >&6
 if test "${ac_cv_lib_ucb_getpagesize+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -7911,7 +7899,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lucb  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 7914 "configure"
+#line 7902 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -7930,16 +7918,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7933: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7921: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7936: \$? = $ac_status" >&5
+  echo "$as_me:7924: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7939: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7927: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7942: \$? = $ac_status" >&5
+  echo "$as_me:7930: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_ucb_getpagesize=yes
 else
@@ -7950,7 +7938,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:7953: result: $ac_cv_lib_ucb_getpagesize" >&5
+echo "$as_me:7941: result: $ac_cv_lib_ucb_getpagesize" >&5
 echo "${ECHO_T}$ac_cv_lib_ucb_getpagesize" >&6
 if test $ac_cv_lib_ucb_getpagesize = yes; then
   LIBS="$LIBS -lucb"; cat >>confdefs.h <<\EOF
@@ -7963,15 +7951,15 @@
 
 # Check for broken snprintf
 if test "x$ac_cv_func_snprintf" = "xyes" ; then
-	echo "$as_me:7966: checking whether snprintf correctly terminates long strings" >&5
+	echo "$as_me:7954: checking whether snprintf correctly terminates long strings" >&5
 echo $ECHO_N "checking whether snprintf correctly terminates long strings... $ECHO_C" >&6
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:7969: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:7957: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7974 "configure"
+#line 7962 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -7979,30 +7967,30 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:7982: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7970: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7985: \$? = $ac_status" >&5
+  echo "$as_me:7973: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:7987: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7975: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7990: \$? = $ac_status" >&5
+  echo "$as_me:7978: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:7992: result: yes" >&5
+  echo "$as_me:7980: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-			echo "$as_me:7999: result: no" >&5
+			echo "$as_me:7987: result: no" >&5
 echo "${ECHO_T}no" >&6
 			cat >>confdefs.h <<\EOF
 #define BROKEN_SNPRINTF 1
 EOF
 
-			{ echo "$as_me:8005: WARNING: ****** Your snprintf() function is broken, complain to your vendor" >&5
+			{ echo "$as_me:7993: WARNING: ****** Your snprintf() function is broken, complain to your vendor" >&5
 echo "$as_me: WARNING: ****** Your snprintf() function is broken, complain to your vendor" >&2;}
 
 fi
@@ -8011,11 +7999,11 @@
 fi
 
 if test "x$ac_cv_func_mkdtemp" = "xyes" ; then
-echo "$as_me:8014: checking for (overly) strict mkstemp" >&5
+echo "$as_me:8002: checking for (overly) strict mkstemp" >&5
 echo $ECHO_N "checking for (overly) strict mkstemp... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
 
-		echo "$as_me:8018: result: yes" >&5
+		echo "$as_me:8006: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 		cat >>confdefs.h <<\EOF
 #define HAVE_STRICT_MKSTEMP 1
@@ -8023,7 +8011,7 @@
 
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8026 "configure"
+#line 8014 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -8035,18 +8023,18 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8038: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8026: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8041: \$? = $ac_status" >&5
+  echo "$as_me:8029: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8043: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8031: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8046: \$? = $ac_status" >&5
+  echo "$as_me:8034: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
-		echo "$as_me:8049: result: no" >&5
+		echo "$as_me:8037: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 else
@@ -8054,7 +8042,7 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:8057: result: yes" >&5
+		echo "$as_me:8045: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 		cat >>confdefs.h <<\EOF
 #define HAVE_STRICT_MKSTEMP 1
@@ -8066,15 +8054,15 @@
 fi
 
 if test ! -z "$check_for_openpty_ctty_bug"; then
-	echo "$as_me:8069: checking if openpty correctly handles controlling tty" >&5
+	echo "$as_me:8057: checking if openpty correctly handles controlling tty" >&5
 echo $ECHO_N "checking if openpty correctly handles controlling tty... $ECHO_C" >&6
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8072: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:8060: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8077 "configure"
+#line 8065 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -8111,18 +8099,18 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8114: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8102: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8117: \$? = $ac_status" >&5
+  echo "$as_me:8105: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8119: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8107: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8122: \$? = $ac_status" >&5
+  echo "$as_me:8110: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
-			echo "$as_me:8125: result: yes" >&5
+			echo "$as_me:8113: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
@@ -8130,7 +8118,7 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-			echo "$as_me:8133: result: no" >&5
+			echo "$as_me:8121: result: no" >&5
 echo "${ECHO_T}no" >&6
 			cat >>confdefs.h <<\EOF
 #define SSHD_ACQUIRES_CTTY 1
@@ -8141,14 +8129,14 @@
 fi
 fi
 
-echo "$as_me:8144: checking whether getpgrp takes no argument" >&5
+echo "$as_me:8132: checking whether getpgrp takes no argument" >&5
 echo $ECHO_N "checking whether getpgrp takes no argument... $ECHO_C" >&6
 if test "${ac_cv_func_getpgrp_void+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   # Use it with a single arg.
 cat >conftest.$ac_ext <<_ACEOF
-#line 8151 "configure"
+#line 8139 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -8160,16 +8148,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8163: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8151: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8166: \$? = $ac_status" >&5
+  echo "$as_me:8154: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8169: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8157: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8172: \$? = $ac_status" >&5
+  echo "$as_me:8160: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_func_getpgrp_1=yes
 else
@@ -8180,7 +8168,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 # Use it with no arg.
 cat >conftest.$ac_ext <<_ACEOF
-#line 8183 "configure"
+#line 8171 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -8192,16 +8180,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8195: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8183: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8198: \$? = $ac_status" >&5
+  echo "$as_me:8186: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8201: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8189: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8204: \$? = $ac_status" >&5
+  echo "$as_me:8192: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_func_getpgrp_0=yes
 else
@@ -8215,12 +8203,12 @@
   yes:no) ac_cv_func_getpgrp_void=yes;;
   no:yes) ac_cv_func_getpgrp_void=false;;
   *) if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8218: error: cannot check getpgrp if cross compiling" >&5
+  { { echo "$as_me:8206: error: cannot check getpgrp if cross compiling" >&5
 echo "$as_me: error: cannot check getpgrp if cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8223 "configure"
+#line 8211 "configure"
 #include "confdefs.h"
 $ac_includes_default
 
@@ -8274,15 +8262,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8277: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8265: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8280: \$? = $ac_status" >&5
+  echo "$as_me:8268: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8282: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8270: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8285: \$? = $ac_status" >&5
+  echo "$as_me:8273: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_getpgrp_void=yes
 else
@@ -8296,7 +8284,7 @@
 esac # $ac_func_getpgrp_0:$ac_func_getpgrp_1
 
 fi
-echo "$as_me:8299: result: $ac_cv_func_getpgrp_void" >&5
+echo "$as_me:8287: result: $ac_cv_func_getpgrp_void" >&5
 echo "${ECHO_T}$ac_cv_func_getpgrp_void" >&6
 if test $ac_cv_func_getpgrp_void = yes; then
 
@@ -8315,12 +8303,12 @@
 
 		if test "x$withval" != "xno" ; then
 			if test "x$ac_cv_header_security_pam_appl_h" != "xyes" ; then
-				{ { echo "$as_me:8318: error: PAM headers not found" >&5
+				{ { echo "$as_me:8306: error: PAM headers not found" >&5
 echo "$as_me: error: PAM headers not found" >&2;}
    { (exit 1); exit 1; }; }
 			fi
 
-echo "$as_me:8323: checking for dlopen in -ldl" >&5
+echo "$as_me:8311: checking for dlopen in -ldl" >&5
 echo $ECHO_N "checking for dlopen in -ldl... $ECHO_C" >&6
 if test "${ac_cv_lib_dl_dlopen+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8328,7 +8316,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-ldl  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 8331 "configure"
+#line 8319 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8347,16 +8335,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8350: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8338: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8353: \$? = $ac_status" >&5
+  echo "$as_me:8341: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8356: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8344: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8359: \$? = $ac_status" >&5
+  echo "$as_me:8347: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_dl_dlopen=yes
 else
@@ -8367,7 +8355,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:8370: result: $ac_cv_lib_dl_dlopen" >&5
+echo "$as_me:8358: result: $ac_cv_lib_dl_dlopen" >&5
 echo "${ECHO_T}$ac_cv_lib_dl_dlopen" >&6
 if test $ac_cv_lib_dl_dlopen = yes; then
   cat >>confdefs.h <<EOF
@@ -8378,7 +8366,7 @@
 
 fi
 
-echo "$as_me:8381: checking for pam_set_item in -lpam" >&5
+echo "$as_me:8369: checking for pam_set_item in -lpam" >&5
 echo $ECHO_N "checking for pam_set_item in -lpam... $ECHO_C" >&6
 if test "${ac_cv_lib_pam_pam_set_item+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8386,7 +8374,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lpam  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 8389 "configure"
+#line 8377 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8405,16 +8393,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8408: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8396: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8411: \$? = $ac_status" >&5
+  echo "$as_me:8399: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8414: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8402: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8417: \$? = $ac_status" >&5
+  echo "$as_me:8405: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_pam_pam_set_item=yes
 else
@@ -8425,7 +8413,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:8428: result: $ac_cv_lib_pam_pam_set_item" >&5
+echo "$as_me:8416: result: $ac_cv_lib_pam_pam_set_item" >&5
 echo "${ECHO_T}$ac_cv_lib_pam_pam_set_item" >&6
 if test $ac_cv_lib_pam_pam_set_item = yes; then
   cat >>confdefs.h <<EOF
@@ -8435,7 +8423,7 @@
   LIBS="-lpam $LIBS"
 
 else
-  { { echo "$as_me:8438: error: *** libpam missing" >&5
+  { { echo "$as_me:8426: error: *** libpam missing" >&5
 echo "$as_me: error: *** libpam missing" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -8443,13 +8431,13 @@
 for ac_func in pam_getenvlist
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:8446: checking for $ac_func" >&5
+echo "$as_me:8434: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8452 "configure"
+#line 8440 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -8480,16 +8468,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8483: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8471: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8486: \$? = $ac_status" >&5
+  echo "$as_me:8474: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8489: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8477: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8492: \$? = $ac_status" >&5
+  echo "$as_me:8480: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -8499,7 +8487,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:8502: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:8490: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -8512,13 +8500,13 @@
 for ac_func in pam_putenv
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:8515: checking for $ac_func" >&5
+echo "$as_me:8503: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8521 "configure"
+#line 8509 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -8549,16 +8537,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8552: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8540: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8555: \$? = $ac_status" >&5
+  echo "$as_me:8543: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8558: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8546: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8561: \$? = $ac_status" >&5
+  echo "$as_me:8549: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -8568,7 +8556,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:8571: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:8559: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -8578,7 +8566,6 @@
 fi
 done
 
-			disable_shadow=yes
 			PAM_MSG="yes"
 
 			cat >>confdefs.h <<\EOF
@@ -8598,10 +8585,10 @@
 # Check for older PAM
 if test "x$PAM_MSG" = "xyes" ; then
 	# Check PAM strerror arguments (old PAM)
-	echo "$as_me:8601: checking whether pam_strerror takes only one argument" >&5
+	echo "$as_me:8588: checking whether pam_strerror takes only one argument" >&5
 echo $ECHO_N "checking whether pam_strerror takes only one argument... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 8604 "configure"
+#line 8591 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -8616,18 +8603,18 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8619: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8606: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8622: \$? = $ac_status" >&5
+  echo "$as_me:8609: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8625: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8612: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8628: \$? = $ac_status" >&5
+  echo "$as_me:8615: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:8630: result: no" >&5
+  echo "$as_me:8617: result: no" >&5
 echo "${ECHO_T}no" >&6
 else
   echo "$as_me: failed program was:" >&5
@@ -8637,7 +8624,7 @@
 #define HAVE_OLD_PAM 1
 EOF
 
-			echo "$as_me:8640: result: yes" >&5
+			echo "$as_me:8627: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 			PAM_MSG="yes (old library)"
 
@@ -8649,7 +8636,7 @@
 # because the system crypt() is more featureful.
 if test "x$check_for_libcrypt_before" = "x1"; then
 
-echo "$as_me:8652: checking for crypt in -lcrypt" >&5
+echo "$as_me:8639: checking for crypt in -lcrypt" >&5
 echo $ECHO_N "checking for crypt in -lcrypt... $ECHO_C" >&6
 if test "${ac_cv_lib_crypt_crypt+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8657,7 +8644,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lcrypt  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 8660 "configure"
+#line 8647 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8676,16 +8663,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8679: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8666: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8682: \$? = $ac_status" >&5
+  echo "$as_me:8669: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8685: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8672: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8688: \$? = $ac_status" >&5
+  echo "$as_me:8675: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_crypt_crypt=yes
 else
@@ -8696,7 +8683,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:8699: result: $ac_cv_lib_crypt_crypt" >&5
+echo "$as_me:8686: result: $ac_cv_lib_crypt_crypt" >&5
 echo "${ECHO_T}$ac_cv_lib_crypt_crypt" >&6
 if test $ac_cv_lib_crypt_crypt = yes; then
   cat >>confdefs.h <<EOF
@@ -8741,7 +8728,7 @@
 fi;
 LIBS="$LIBS -lcrypto"
 cat >conftest.$ac_ext <<_ACEOF
-#line 8744 "configure"
+#line 8731 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8760,16 +8747,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8763: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8750: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8766: \$? = $ac_status" >&5
+  echo "$as_me:8753: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8769: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8756: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8772: \$? = $ac_status" >&5
+  echo "$as_me:8759: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cat >>confdefs.h <<\EOF
 #define HAVE_OPENSSL 1
@@ -8786,7 +8773,7 @@
 		fi
 		CPPFLAGS="-I/usr/local/ssl/include ${saved_CPPFLAGS}"
 		cat >conftest.$ac_ext <<_ACEOF
-#line 8789 "configure"
+#line 8776 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8805,16 +8792,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8808: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8795: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8811: \$? = $ac_status" >&5
+  echo "$as_me:8798: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8814: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8801: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8817: \$? = $ac_status" >&5
+  echo "$as_me:8804: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cat >>confdefs.h <<\EOF
 #define HAVE_OPENSSL 1
@@ -8824,7 +8811,7 @@
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-				{ { echo "$as_me:8827: error: *** Can't find recent OpenSSL libcrypto (see config.log for details) ***" >&5
+				{ { echo "$as_me:8814: error: *** Can't find recent OpenSSL libcrypto (see config.log for details) ***" >&5
 echo "$as_me: error: *** Can't find recent OpenSSL libcrypto (see config.log for details) ***" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -8835,15 +8822,15 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 # Determine OpenSSL header version
-echo "$as_me:8838: checking OpenSSL header version" >&5
+echo "$as_me:8825: checking OpenSSL header version" >&5
 echo $ECHO_N "checking OpenSSL header version... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8841: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:8828: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8846 "configure"
+#line 8833 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -8866,19 +8853,19 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8869: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8856: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8872: \$? = $ac_status" >&5
+  echo "$as_me:8859: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8874: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8861: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8877: \$? = $ac_status" >&5
+  echo "$as_me:8864: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		ssl_header_ver=`cat conftest.sslincver`
-		echo "$as_me:8881: result: $ssl_header_ver" >&5
+		echo "$as_me:8868: result: $ssl_header_ver" >&5
 echo "${ECHO_T}$ssl_header_ver" >&6
 
 else
@@ -8886,9 +8873,9 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:8889: result: not found" >&5
+		echo "$as_me:8876: result: not found" >&5
 echo "${ECHO_T}not found" >&6
-		{ { echo "$as_me:8891: error: OpenSSL version header not found." >&5
+		{ { echo "$as_me:8878: error: OpenSSL version header not found." >&5
 echo "$as_me: error: OpenSSL version header not found." >&2;}
    { (exit 1); exit 1; }; }
 
@@ -8897,15 +8884,15 @@
 fi
 
 # Determine OpenSSL library version
-echo "$as_me:8900: checking OpenSSL library version" >&5
+echo "$as_me:8887: checking OpenSSL library version" >&5
 echo $ECHO_N "checking OpenSSL library version... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8903: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:8890: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8908 "configure"
+#line 8895 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -8929,19 +8916,19 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8932: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8919: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8935: \$? = $ac_status" >&5
+  echo "$as_me:8922: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8937: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8924: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8940: \$? = $ac_status" >&5
+  echo "$as_me:8927: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		ssl_library_ver=`cat conftest.ssllibver`
-		echo "$as_me:8944: result: $ssl_library_ver" >&5
+		echo "$as_me:8931: result: $ssl_library_ver" >&5
 echo "${ECHO_T}$ssl_library_ver" >&6
 
 else
@@ -8949,9 +8936,9 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:8952: result: not found" >&5
+		echo "$as_me:8939: result: not found" >&5
 echo "${ECHO_T}not found" >&6
-		{ { echo "$as_me:8954: error: OpenSSL library not found." >&5
+		{ { echo "$as_me:8941: error: OpenSSL library not found." >&5
 echo "$as_me: error: OpenSSL library not found." >&2;}
    { (exit 1); exit 1; }; }
 
@@ -8960,15 +8947,15 @@
 fi
 
 # Sanity check OpenSSL headers
-echo "$as_me:8963: checking whether OpenSSL's headers match the library" >&5
+echo "$as_me:8950: checking whether OpenSSL's headers match the library" >&5
 echo $ECHO_N "checking whether OpenSSL's headers match the library... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8966: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:8953: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8971 "configure"
+#line 8958 "configure"
 #include "confdefs.h"
 
 #include <string.h>
@@ -8977,18 +8964,18 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8980: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8967: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8983: \$? = $ac_status" >&5
+  echo "$as_me:8970: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8985: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8972: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8988: \$? = $ac_status" >&5
+  echo "$as_me:8975: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
-		echo "$as_me:8991: result: yes" >&5
+		echo "$as_me:8978: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
@@ -8996,9 +8983,9 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:8999: result: no" >&5
+		echo "$as_me:8986: result: no" >&5
 echo "${ECHO_T}no" >&6
-		{ { echo "$as_me:9001: error: Your OpenSSL headers do not match your library.
+		{ { echo "$as_me:8988: error: Your OpenSSL headers do not match your library.
 Check config.log for details.
 Also see contrib/findssl.sh for help identifying header/library mismatches." >&5
 echo "$as_me: error: Your OpenSSL headers do not match your library.
@@ -9013,7 +9000,7 @@
 # Some Linux systems (Slackware) need crypt() from libcrypt, *not* the
 # version in OpenSSL. Skip this for PAM
 if test "x$check_for_libcrypt_later" = "x1"; then
-	echo "$as_me:9016: checking for crypt in -lcrypt" >&5
+	echo "$as_me:9003: checking for crypt in -lcrypt" >&5
 echo $ECHO_N "checking for crypt in -lcrypt... $ECHO_C" >&6
 if test "${ac_cv_lib_crypt_crypt+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9021,7 +9008,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lcrypt  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 9024 "configure"
+#line 9011 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -9040,16 +9027,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:9043: \"$ac_link\"") >&5
+if { (eval echo "$as_me:9030: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:9046: \$? = $ac_status" >&5
+  echo "$as_me:9033: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:9049: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9036: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9052: \$? = $ac_status" >&5
+  echo "$as_me:9039: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_crypt_crypt=yes
 else
@@ -9060,7 +9047,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:9063: result: $ac_cv_lib_crypt_crypt" >&5
+echo "$as_me:9050: result: $ac_cv_lib_crypt_crypt" >&5
 echo "${ECHO_T}$ac_cv_lib_crypt_crypt" >&6
 if test $ac_cv_lib_crypt_crypt = yes; then
   LIBS="$LIBS -lcrypt"
@@ -9071,15 +9058,15 @@
 ### Configure cryptographic random number support
 
 # Check wheter OpenSSL seeds itself
-echo "$as_me:9074: checking whether OpenSSL's PRNG is internally seeded" >&5
+echo "$as_me:9061: checking whether OpenSSL's PRNG is internally seeded" >&5
 echo $ECHO_N "checking whether OpenSSL's PRNG is internally seeded... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:9077: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:9064: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 9082 "configure"
+#line 9069 "configure"
 #include "confdefs.h"
 
 #include <string.h>
@@ -9088,19 +9075,19 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:9091: \"$ac_link\"") >&5
+if { (eval echo "$as_me:9078: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:9094: \$? = $ac_status" >&5
+  echo "$as_me:9081: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:9096: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9083: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9099: \$? = $ac_status" >&5
+  echo "$as_me:9086: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		OPENSSL_SEEDS_ITSELF=yes
-		echo "$as_me:9103: result: yes" >&5
+		echo "$as_me:9090: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
@@ -9108,7 +9095,7 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:9111: result: no" >&5
+		echo "$as_me:9098: result: no" >&5
 echo "${ECHO_T}no" >&6
 		# Default to use of the rand helper if OpenSSL doesn't
 		# seed itself
@@ -9128,7 +9115,7 @@
 			# Force use of OpenSSL's internal RNG, even if
 			# the previous test showed it to be unseeded.
 			if test -z "$OPENSSL_SEEDS_ITSELF" ; then
-				{ echo "$as_me:9131: WARNING: *** Forcing use of OpenSSL's non-self-seeding PRNG" >&5
+				{ echo "$as_me:9118: WARNING: *** Forcing use of OpenSSL's non-self-seeding PRNG" >&5
 echo "$as_me: WARNING: *** Forcing use of OpenSSL's non-self-seeding PRNG" >&2;}
 				OPENSSL_SEEDS_ITSELF=yes
 				USE_RAND_HELPER=""
@@ -9169,7 +9156,7 @@
 		[0-9]*)
 			;;
 		*)
-			{ { echo "$as_me:9172: error: You must specify a numeric port number for --with-prngd-port" >&5
+			{ { echo "$as_me:9159: error: You must specify a numeric port number for --with-prngd-port" >&5
 echo "$as_me: error: You must specify a numeric port number for --with-prngd-port" >&2;}
    { (exit 1); exit 1; }; }
 			;;
@@ -9200,7 +9187,7 @@
 		/*)
 			;;
 		*)
-			{ { echo "$as_me:9203: error: You must specify an absolute path to the entropy socket" >&5
+			{ { echo "$as_me:9190: error: You must specify an absolute path to the entropy socket" >&5
 echo "$as_me: error: You must specify an absolute path to the entropy socket" >&2;}
    { (exit 1); exit 1; }; }
 			;;
@@ -9208,12 +9195,12 @@
 
 		if test ! -z "$withval" ; then
 			if test ! -z "$PRNGD_PORT" ; then
-				{ { echo "$as_me:9211: error: You may not specify both a PRNGD/EGD port and socket" >&5
+				{ { echo "$as_me:9198: error: You may not specify both a PRNGD/EGD port and socket" >&5
 echo "$as_me: error: You may not specify both a PRNGD/EGD port and socket" >&2;}
    { (exit 1); exit 1; }; }
 			fi
 			if test ! -r "$withval" ; then
-				{ echo "$as_me:9216: WARNING: Entropy socket is not readable" >&5
+				{ echo "$as_me:9203: WARNING: Entropy socket is not readable" >&5
 echo "$as_me: WARNING: Entropy socket is not readable" >&2;}
 			fi
 			PRNGD_SOCKET="$withval"
@@ -9227,7 +9214,7 @@
 
 		# Check for existing socket only if we don't have a random device already
 		if test "$USE_RAND_HELPER" = yes ; then
-			echo "$as_me:9230: checking for PRNGD/EGD socket" >&5
+			echo "$as_me:9217: checking for PRNGD/EGD socket" >&5
 echo $ECHO_N "checking for PRNGD/EGD socket... $ECHO_C" >&6
 			# Insert other locations here
 			for sock in /var/run/egd-pool /dev/egd-pool /etc/entropy; do
@@ -9241,10 +9228,10 @@
 				fi
 			done
 			if test ! -z "$PRNGD_SOCKET" ; then
-				echo "$as_me:9244: result: $PRNGD_SOCKET" >&5
+				echo "$as_me:9231: result: $PRNGD_SOCKET" >&5
 echo "${ECHO_T}$PRNGD_SOCKET" >&6
 			else
-				echo "$as_me:9247: result: not found" >&5
+				echo "$as_me:9234: result: not found" >&5
 echo "${ECHO_T}not found" >&6
 			fi
 		fi
@@ -9300,7 +9287,7 @@
 
 	# Extract the first word of "ls", so it can be a program name with args.
 set dummy ls; ac_word=$2
-echo "$as_me:9303: checking for $ac_word" >&5
+echo "$as_me:9290: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_LS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9317,7 +9304,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_LS="$ac_dir/$ac_word"
-   echo "$as_me:9320: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9307: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9328,10 +9315,10 @@
 PROG_LS=$ac_cv_path_PROG_LS
 
 if test -n "$PROG_LS"; then
-  echo "$as_me:9331: result: $PROG_LS" >&5
+  echo "$as_me:9318: result: $PROG_LS" >&5
 echo "${ECHO_T}$PROG_LS" >&6
 else
-  echo "$as_me:9334: result: no" >&5
+  echo "$as_me:9321: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9341,7 +9328,7 @@
 
 	# Extract the first word of "netstat", so it can be a program name with args.
 set dummy netstat; ac_word=$2
-echo "$as_me:9344: checking for $ac_word" >&5
+echo "$as_me:9331: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_NETSTAT+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9358,7 +9345,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_NETSTAT="$ac_dir/$ac_word"
-   echo "$as_me:9361: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9348: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9369,10 +9356,10 @@
 PROG_NETSTAT=$ac_cv_path_PROG_NETSTAT
 
 if test -n "$PROG_NETSTAT"; then
-  echo "$as_me:9372: result: $PROG_NETSTAT" >&5
+  echo "$as_me:9359: result: $PROG_NETSTAT" >&5
 echo "${ECHO_T}$PROG_NETSTAT" >&6
 else
-  echo "$as_me:9375: result: no" >&5
+  echo "$as_me:9362: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9382,7 +9369,7 @@
 
 	# Extract the first word of "arp", so it can be a program name with args.
 set dummy arp; ac_word=$2
-echo "$as_me:9385: checking for $ac_word" >&5
+echo "$as_me:9372: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_ARP+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9399,7 +9386,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_ARP="$ac_dir/$ac_word"
-   echo "$as_me:9402: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9389: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9410,10 +9397,10 @@
 PROG_ARP=$ac_cv_path_PROG_ARP
 
 if test -n "$PROG_ARP"; then
-  echo "$as_me:9413: result: $PROG_ARP" >&5
+  echo "$as_me:9400: result: $PROG_ARP" >&5
 echo "${ECHO_T}$PROG_ARP" >&6
 else
-  echo "$as_me:9416: result: no" >&5
+  echo "$as_me:9403: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9423,7 +9410,7 @@
 
 	# Extract the first word of "ifconfig", so it can be a program name with args.
 set dummy ifconfig; ac_word=$2
-echo "$as_me:9426: checking for $ac_word" >&5
+echo "$as_me:9413: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_IFCONFIG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9440,7 +9427,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_IFCONFIG="$ac_dir/$ac_word"
-   echo "$as_me:9443: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9430: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9451,10 +9438,10 @@
 PROG_IFCONFIG=$ac_cv_path_PROG_IFCONFIG
 
 if test -n "$PROG_IFCONFIG"; then
-  echo "$as_me:9454: result: $PROG_IFCONFIG" >&5
+  echo "$as_me:9441: result: $PROG_IFCONFIG" >&5
 echo "${ECHO_T}$PROG_IFCONFIG" >&6
 else
-  echo "$as_me:9457: result: no" >&5
+  echo "$as_me:9444: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9464,7 +9451,7 @@
 
 	# Extract the first word of "jstat", so it can be a program name with args.
 set dummy jstat; ac_word=$2
-echo "$as_me:9467: checking for $ac_word" >&5
+echo "$as_me:9454: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_JSTAT+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9481,7 +9468,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_JSTAT="$ac_dir/$ac_word"
-   echo "$as_me:9484: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9471: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9492,10 +9479,10 @@
 PROG_JSTAT=$ac_cv_path_PROG_JSTAT
 
 if test -n "$PROG_JSTAT"; then
-  echo "$as_me:9495: result: $PROG_JSTAT" >&5
+  echo "$as_me:9482: result: $PROG_JSTAT" >&5
 echo "${ECHO_T}$PROG_JSTAT" >&6
 else
-  echo "$as_me:9498: result: no" >&5
+  echo "$as_me:9485: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9505,7 +9492,7 @@
 
 	# Extract the first word of "ps", so it can be a program name with args.
 set dummy ps; ac_word=$2
-echo "$as_me:9508: checking for $ac_word" >&5
+echo "$as_me:9495: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_PS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9522,7 +9509,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_PS="$ac_dir/$ac_word"
-   echo "$as_me:9525: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9512: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9533,10 +9520,10 @@
 PROG_PS=$ac_cv_path_PROG_PS
 
 if test -n "$PROG_PS"; then
-  echo "$as_me:9536: result: $PROG_PS" >&5
+  echo "$as_me:9523: result: $PROG_PS" >&5
 echo "${ECHO_T}$PROG_PS" >&6
 else
-  echo "$as_me:9539: result: no" >&5
+  echo "$as_me:9526: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9546,7 +9533,7 @@
 
 	# Extract the first word of "sar", so it can be a program name with args.
 set dummy sar; ac_word=$2
-echo "$as_me:9549: checking for $ac_word" >&5
+echo "$as_me:9536: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_SAR+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9563,7 +9550,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_SAR="$ac_dir/$ac_word"
-   echo "$as_me:9566: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9553: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9574,10 +9561,10 @@
 PROG_SAR=$ac_cv_path_PROG_SAR
 
 if test -n "$PROG_SAR"; then
-  echo "$as_me:9577: result: $PROG_SAR" >&5
+  echo "$as_me:9564: result: $PROG_SAR" >&5
 echo "${ECHO_T}$PROG_SAR" >&6
 else
-  echo "$as_me:9580: result: no" >&5
+  echo "$as_me:9567: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9587,7 +9574,7 @@
 
 	# Extract the first word of "w", so it can be a program name with args.
 set dummy w; ac_word=$2
-echo "$as_me:9590: checking for $ac_word" >&5
+echo "$as_me:9577: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_W+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9604,7 +9591,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_W="$ac_dir/$ac_word"
-   echo "$as_me:9607: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9594: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9615,10 +9602,10 @@
 PROG_W=$ac_cv_path_PROG_W
 
 if test -n "$PROG_W"; then
-  echo "$as_me:9618: result: $PROG_W" >&5
+  echo "$as_me:9605: result: $PROG_W" >&5
 echo "${ECHO_T}$PROG_W" >&6
 else
-  echo "$as_me:9621: result: no" >&5
+  echo "$as_me:9608: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9628,7 +9615,7 @@
 
 	# Extract the first word of "who", so it can be a program name with args.
 set dummy who; ac_word=$2
-echo "$as_me:9631: checking for $ac_word" >&5
+echo "$as_me:9618: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_WHO+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9645,7 +9632,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_WHO="$ac_dir/$ac_word"
-   echo "$as_me:9648: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9635: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9656,10 +9643,10 @@
 PROG_WHO=$ac_cv_path_PROG_WHO
 
 if test -n "$PROG_WHO"; then
-  echo "$as_me:9659: result: $PROG_WHO" >&5
+  echo "$as_me:9646: result: $PROG_WHO" >&5
 echo "${ECHO_T}$PROG_WHO" >&6
 else
-  echo "$as_me:9662: result: no" >&5
+  echo "$as_me:9649: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9669,7 +9656,7 @@
 
 	# Extract the first word of "last", so it can be a program name with args.
 set dummy last; ac_word=$2
-echo "$as_me:9672: checking for $ac_word" >&5
+echo "$as_me:9659: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_LAST+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9686,7 +9673,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_LAST="$ac_dir/$ac_word"
-   echo "$as_me:9689: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9676: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9697,10 +9684,10 @@
 PROG_LAST=$ac_cv_path_PROG_LAST
 
 if test -n "$PROG_LAST"; then
-  echo "$as_me:9700: result: $PROG_LAST" >&5
+  echo "$as_me:9687: result: $PROG_LAST" >&5
 echo "${ECHO_T}$PROG_LAST" >&6
 else
-  echo "$as_me:9703: result: no" >&5
+  echo "$as_me:9690: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9710,7 +9697,7 @@
 
 	# Extract the first word of "lastlog", so it can be a program name with args.
 set dummy lastlog; ac_word=$2
-echo "$as_me:9713: checking for $ac_word" >&5
+echo "$as_me:9700: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_LASTLOG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9727,7 +9714,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_LASTLOG="$ac_dir/$ac_word"
-   echo "$as_me:9730: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9717: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9738,10 +9725,10 @@
 PROG_LASTLOG=$ac_cv_path_PROG_LASTLOG
 
 if test -n "$PROG_LASTLOG"; then
-  echo "$as_me:9741: result: $PROG_LASTLOG" >&5
+  echo "$as_me:9728: result: $PROG_LASTLOG" >&5
 echo "${ECHO_T}$PROG_LASTLOG" >&6
 else
-  echo "$as_me:9744: result: no" >&5
+  echo "$as_me:9731: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9751,7 +9738,7 @@
 
 	# Extract the first word of "df", so it can be a program name with args.
 set dummy df; ac_word=$2
-echo "$as_me:9754: checking for $ac_word" >&5
+echo "$as_me:9741: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_DF+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9768,7 +9755,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_DF="$ac_dir/$ac_word"
-   echo "$as_me:9771: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9758: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9779,10 +9766,10 @@
 PROG_DF=$ac_cv_path_PROG_DF
 
 if test -n "$PROG_DF"; then
-  echo "$as_me:9782: result: $PROG_DF" >&5
+  echo "$as_me:9769: result: $PROG_DF" >&5
 echo "${ECHO_T}$PROG_DF" >&6
 else
-  echo "$as_me:9785: result: no" >&5
+  echo "$as_me:9772: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9792,7 +9779,7 @@
 
 	# Extract the first word of "vmstat", so it can be a program name with args.
 set dummy vmstat; ac_word=$2
-echo "$as_me:9795: checking for $ac_word" >&5
+echo "$as_me:9782: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_VMSTAT+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9809,7 +9796,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_VMSTAT="$ac_dir/$ac_word"
-   echo "$as_me:9812: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9799: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9820,10 +9807,10 @@
 PROG_VMSTAT=$ac_cv_path_PROG_VMSTAT
 
 if test -n "$PROG_VMSTAT"; then
-  echo "$as_me:9823: result: $PROG_VMSTAT" >&5
+  echo "$as_me:9810: result: $PROG_VMSTAT" >&5
 echo "${ECHO_T}$PROG_VMSTAT" >&6
 else
-  echo "$as_me:9826: result: no" >&5
+  echo "$as_me:9813: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9833,7 +9820,7 @@
 
 	# Extract the first word of "uptime", so it can be a program name with args.
 set dummy uptime; ac_word=$2
-echo "$as_me:9836: checking for $ac_word" >&5
+echo "$as_me:9823: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_UPTIME+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9850,7 +9837,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_UPTIME="$ac_dir/$ac_word"
-   echo "$as_me:9853: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9840: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9861,10 +9848,10 @@
 PROG_UPTIME=$ac_cv_path_PROG_UPTIME
 
 if test -n "$PROG_UPTIME"; then
-  echo "$as_me:9864: result: $PROG_UPTIME" >&5
+  echo "$as_me:9851: result: $PROG_UPTIME" >&5
 echo "${ECHO_T}$PROG_UPTIME" >&6
 else
-  echo "$as_me:9867: result: no" >&5
+  echo "$as_me:9854: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9874,7 +9861,7 @@
 
 	# Extract the first word of "ipcs", so it can be a program name with args.
 set dummy ipcs; ac_word=$2
-echo "$as_me:9877: checking for $ac_word" >&5
+echo "$as_me:9864: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_IPCS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9891,7 +9878,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_IPCS="$ac_dir/$ac_word"
-   echo "$as_me:9894: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9881: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9902,10 +9889,10 @@
 PROG_IPCS=$ac_cv_path_PROG_IPCS
 
 if test -n "$PROG_IPCS"; then
-  echo "$as_me:9905: result: $PROG_IPCS" >&5
+  echo "$as_me:9892: result: $PROG_IPCS" >&5
 echo "${ECHO_T}$PROG_IPCS" >&6
 else
-  echo "$as_me:9908: result: no" >&5
+  echo "$as_me:9895: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9915,7 +9902,7 @@
 
 	# Extract the first word of "tail", so it can be a program name with args.
 set dummy tail; ac_word=$2
-echo "$as_me:9918: checking for $ac_word" >&5
+echo "$as_me:9905: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_TAIL+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9932,7 +9919,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_TAIL="$ac_dir/$ac_word"
-   echo "$as_me:9935: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9922: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9943,10 +9930,10 @@
 PROG_TAIL=$ac_cv_path_PROG_TAIL
 
 if test -n "$PROG_TAIL"; then
-  echo "$as_me:9946: result: $PROG_TAIL" >&5
+  echo "$as_me:9933: result: $PROG_TAIL" >&5
 echo "${ECHO_T}$PROG_TAIL" >&6
 else
-  echo "$as_me:9949: result: no" >&5
+  echo "$as_me:9936: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9977,13 +9964,13 @@
 fi
 
 # Checks for data types
-echo "$as_me:9980: checking for char" >&5
+echo "$as_me:9967: checking for char" >&5
 echo $ECHO_N "checking for char... $ECHO_C" >&6
 if test "${ac_cv_type_char+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 9986 "configure"
+#line 9973 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -9998,16 +9985,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10001: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9988: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10004: \$? = $ac_status" >&5
+  echo "$as_me:9991: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10007: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9994: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10010: \$? = $ac_status" >&5
+  echo "$as_me:9997: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_char=yes
 else
@@ -10017,10 +10004,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10020: result: $ac_cv_type_char" >&5
+echo "$as_me:10007: result: $ac_cv_type_char" >&5
 echo "${ECHO_T}$ac_cv_type_char" >&6
 
-echo "$as_me:10023: checking size of char" >&5
+echo "$as_me:10010: checking size of char" >&5
 echo $ECHO_N "checking size of char... $ECHO_C" >&6
 if test "${ac_cv_sizeof_char+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10029,7 +10016,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10032 "configure"
+#line 10019 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10041,21 +10028,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10044: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10031: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10047: \$? = $ac_status" >&5
+  echo "$as_me:10034: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10050: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10037: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10053: \$? = $ac_status" >&5
+  echo "$as_me:10040: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10058 "configure"
+#line 10045 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10067,16 +10054,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10070: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10057: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10073: \$? = $ac_status" >&5
+  echo "$as_me:10060: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10076: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10063: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10079: \$? = $ac_status" >&5
+  echo "$as_me:10066: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -10092,7 +10079,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10095 "configure"
+#line 10082 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10104,16 +10091,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10107: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10094: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10110: \$? = $ac_status" >&5
+  echo "$as_me:10097: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10113: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10100: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10116: \$? = $ac_status" >&5
+  echo "$as_me:10103: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -10129,7 +10116,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 10132 "configure"
+#line 10119 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10141,16 +10128,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10144: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10131: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10147: \$? = $ac_status" >&5
+  echo "$as_me:10134: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10150: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10137: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10153: \$? = $ac_status" >&5
+  echo "$as_me:10140: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -10163,12 +10150,12 @@
 ac_cv_sizeof_char=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:10166: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:10153: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10171 "configure"
+#line 10158 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10184,15 +10171,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10187: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10174: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10190: \$? = $ac_status" >&5
+  echo "$as_me:10177: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10192: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10179: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10195: \$? = $ac_status" >&5
+  echo "$as_me:10182: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_char=`cat conftest.val`
 else
@@ -10208,19 +10195,19 @@
   ac_cv_sizeof_char=0
 fi
 fi
-echo "$as_me:10211: result: $ac_cv_sizeof_char" >&5
+echo "$as_me:10198: result: $ac_cv_sizeof_char" >&5
 echo "${ECHO_T}$ac_cv_sizeof_char" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_CHAR $ac_cv_sizeof_char
 EOF
 
-echo "$as_me:10217: checking for short int" >&5
+echo "$as_me:10204: checking for short int" >&5
 echo $ECHO_N "checking for short int... $ECHO_C" >&6
 if test "${ac_cv_type_short_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10223 "configure"
+#line 10210 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10235,16 +10222,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10238: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10225: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10241: \$? = $ac_status" >&5
+  echo "$as_me:10228: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10244: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10231: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10247: \$? = $ac_status" >&5
+  echo "$as_me:10234: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_short_int=yes
 else
@@ -10254,10 +10241,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10257: result: $ac_cv_type_short_int" >&5
+echo "$as_me:10244: result: $ac_cv_type_short_int" >&5
 echo "${ECHO_T}$ac_cv_type_short_int" >&6
 
-echo "$as_me:10260: checking size of short int" >&5
+echo "$as_me:10247: checking size of short int" >&5
 echo $ECHO_N "checking size of short int... $ECHO_C" >&6
 if test "${ac_cv_sizeof_short_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10266,7 +10253,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10269 "configure"
+#line 10256 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10278,21 +10265,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10281: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10268: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10284: \$? = $ac_status" >&5
+  echo "$as_me:10271: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10287: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10274: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10290: \$? = $ac_status" >&5
+  echo "$as_me:10277: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10295 "configure"
+#line 10282 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10304,16 +10291,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10307: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10294: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10310: \$? = $ac_status" >&5
+  echo "$as_me:10297: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10313: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10300: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10316: \$? = $ac_status" >&5
+  echo "$as_me:10303: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -10329,7 +10316,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10332 "configure"
+#line 10319 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10341,16 +10328,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10344: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10331: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10347: \$? = $ac_status" >&5
+  echo "$as_me:10334: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10350: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10337: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10353: \$? = $ac_status" >&5
+  echo "$as_me:10340: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -10366,7 +10353,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 10369 "configure"
+#line 10356 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10378,16 +10365,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10381: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10368: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10384: \$? = $ac_status" >&5
+  echo "$as_me:10371: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10387: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10374: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10390: \$? = $ac_status" >&5
+  echo "$as_me:10377: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -10400,12 +10387,12 @@
 ac_cv_sizeof_short_int=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:10403: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:10390: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10408 "configure"
+#line 10395 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10421,15 +10408,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10424: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10411: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10427: \$? = $ac_status" >&5
+  echo "$as_me:10414: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10429: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10416: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10432: \$? = $ac_status" >&5
+  echo "$as_me:10419: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_short_int=`cat conftest.val`
 else
@@ -10445,19 +10432,19 @@
   ac_cv_sizeof_short_int=0
 fi
 fi
-echo "$as_me:10448: result: $ac_cv_sizeof_short_int" >&5
+echo "$as_me:10435: result: $ac_cv_sizeof_short_int" >&5
 echo "${ECHO_T}$ac_cv_sizeof_short_int" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_SHORT_INT $ac_cv_sizeof_short_int
 EOF
 
-echo "$as_me:10454: checking for int" >&5
+echo "$as_me:10441: checking for int" >&5
 echo $ECHO_N "checking for int... $ECHO_C" >&6
 if test "${ac_cv_type_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10460 "configure"
+#line 10447 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10472,16 +10459,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10475: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10462: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10478: \$? = $ac_status" >&5
+  echo "$as_me:10465: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10481: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10468: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10484: \$? = $ac_status" >&5
+  echo "$as_me:10471: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_int=yes
 else
@@ -10491,10 +10478,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10494: result: $ac_cv_type_int" >&5
+echo "$as_me:10481: result: $ac_cv_type_int" >&5
 echo "${ECHO_T}$ac_cv_type_int" >&6
 
-echo "$as_me:10497: checking size of int" >&5
+echo "$as_me:10484: checking size of int" >&5
 echo $ECHO_N "checking size of int... $ECHO_C" >&6
 if test "${ac_cv_sizeof_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10503,7 +10490,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10506 "configure"
+#line 10493 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10515,21 +10502,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10518: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10505: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10521: \$? = $ac_status" >&5
+  echo "$as_me:10508: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10524: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10511: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10527: \$? = $ac_status" >&5
+  echo "$as_me:10514: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10532 "configure"
+#line 10519 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10541,16 +10528,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10544: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10531: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10547: \$? = $ac_status" >&5
+  echo "$as_me:10534: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10550: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10537: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10553: \$? = $ac_status" >&5
+  echo "$as_me:10540: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -10566,7 +10553,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10569 "configure"
+#line 10556 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10578,16 +10565,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10581: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10568: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10584: \$? = $ac_status" >&5
+  echo "$as_me:10571: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10587: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10574: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10590: \$? = $ac_status" >&5
+  echo "$as_me:10577: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -10603,7 +10590,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 10606 "configure"
+#line 10593 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10615,16 +10602,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10618: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10605: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10621: \$? = $ac_status" >&5
+  echo "$as_me:10608: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10624: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10611: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10627: \$? = $ac_status" >&5
+  echo "$as_me:10614: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -10637,12 +10624,12 @@
 ac_cv_sizeof_int=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:10640: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:10627: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10645 "configure"
+#line 10632 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10658,15 +10645,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10661: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10648: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10664: \$? = $ac_status" >&5
+  echo "$as_me:10651: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10666: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10653: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10669: \$? = $ac_status" >&5
+  echo "$as_me:10656: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_int=`cat conftest.val`
 else
@@ -10682,19 +10669,19 @@
   ac_cv_sizeof_int=0
 fi
 fi
-echo "$as_me:10685: result: $ac_cv_sizeof_int" >&5
+echo "$as_me:10672: result: $ac_cv_sizeof_int" >&5
 echo "${ECHO_T}$ac_cv_sizeof_int" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_INT $ac_cv_sizeof_int
 EOF
 
-echo "$as_me:10691: checking for long int" >&5
+echo "$as_me:10678: checking for long int" >&5
 echo $ECHO_N "checking for long int... $ECHO_C" >&6
 if test "${ac_cv_type_long_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10697 "configure"
+#line 10684 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10709,16 +10696,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10712: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10699: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10715: \$? = $ac_status" >&5
+  echo "$as_me:10702: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10718: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10705: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10721: \$? = $ac_status" >&5
+  echo "$as_me:10708: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_long_int=yes
 else
@@ -10728,10 +10715,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10731: result: $ac_cv_type_long_int" >&5
+echo "$as_me:10718: result: $ac_cv_type_long_int" >&5
 echo "${ECHO_T}$ac_cv_type_long_int" >&6
 
-echo "$as_me:10734: checking size of long int" >&5
+echo "$as_me:10721: checking size of long int" >&5
 echo $ECHO_N "checking size of long int... $ECHO_C" >&6
 if test "${ac_cv_sizeof_long_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10740,7 +10727,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10743 "configure"
+#line 10730 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10752,21 +10739,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10755: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10742: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10758: \$? = $ac_status" >&5
+  echo "$as_me:10745: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10761: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10748: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10764: \$? = $ac_status" >&5
+  echo "$as_me:10751: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10769 "configure"
+#line 10756 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10778,16 +10765,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10781: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10768: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10784: \$? = $ac_status" >&5
+  echo "$as_me:10771: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10787: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10774: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10790: \$? = $ac_status" >&5
+  echo "$as_me:10777: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -10803,7 +10790,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10806 "configure"
+#line 10793 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10815,16 +10802,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10818: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10805: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10821: \$? = $ac_status" >&5
+  echo "$as_me:10808: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10824: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10811: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10827: \$? = $ac_status" >&5
+  echo "$as_me:10814: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -10840,7 +10827,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 10843 "configure"
+#line 10830 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10852,16 +10839,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10855: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10842: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10858: \$? = $ac_status" >&5
+  echo "$as_me:10845: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10861: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10848: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10864: \$? = $ac_status" >&5
+  echo "$as_me:10851: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -10874,12 +10861,12 @@
 ac_cv_sizeof_long_int=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:10877: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:10864: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10882 "configure"
+#line 10869 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10895,15 +10882,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10898: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10885: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10901: \$? = $ac_status" >&5
+  echo "$as_me:10888: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10903: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10890: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10906: \$? = $ac_status" >&5
+  echo "$as_me:10893: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_long_int=`cat conftest.val`
 else
@@ -10919,19 +10906,19 @@
   ac_cv_sizeof_long_int=0
 fi
 fi
-echo "$as_me:10922: result: $ac_cv_sizeof_long_int" >&5
+echo "$as_me:10909: result: $ac_cv_sizeof_long_int" >&5
 echo "${ECHO_T}$ac_cv_sizeof_long_int" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_LONG_INT $ac_cv_sizeof_long_int
 EOF
 
-echo "$as_me:10928: checking for long long int" >&5
+echo "$as_me:10915: checking for long long int" >&5
 echo $ECHO_N "checking for long long int... $ECHO_C" >&6
 if test "${ac_cv_type_long_long_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10934 "configure"
+#line 10921 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10946,16 +10933,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10949: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10936: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10952: \$? = $ac_status" >&5
+  echo "$as_me:10939: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10955: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10942: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10958: \$? = $ac_status" >&5
+  echo "$as_me:10945: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_long_long_int=yes
 else
@@ -10965,10 +10952,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10968: result: $ac_cv_type_long_long_int" >&5
+echo "$as_me:10955: result: $ac_cv_type_long_long_int" >&5
 echo "${ECHO_T}$ac_cv_type_long_long_int" >&6
 
-echo "$as_me:10971: checking size of long long int" >&5
+echo "$as_me:10958: checking size of long long int" >&5
 echo $ECHO_N "checking size of long long int... $ECHO_C" >&6
 if test "${ac_cv_sizeof_long_long_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10977,7 +10964,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10980 "configure"
+#line 10967 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10989,21 +10976,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10992: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10979: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10995: \$? = $ac_status" >&5
+  echo "$as_me:10982: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10998: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10985: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11001: \$? = $ac_status" >&5
+  echo "$as_me:10988: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 11006 "configure"
+#line 10993 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -11015,16 +11002,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11018: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11005: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11021: \$? = $ac_status" >&5
+  echo "$as_me:11008: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11024: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11011: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11027: \$? = $ac_status" >&5
+  echo "$as_me:11014: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -11040,7 +11027,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 11043 "configure"
+#line 11030 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -11052,16 +11039,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11055: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11042: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11058: \$? = $ac_status" >&5
+  echo "$as_me:11045: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11061: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11048: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11064: \$? = $ac_status" >&5
+  echo "$as_me:11051: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -11077,7 +11064,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 11080 "configure"
+#line 11067 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -11089,16 +11076,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11092: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11079: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11095: \$? = $ac_status" >&5
+  echo "$as_me:11082: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11098: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11085: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11101: \$? = $ac_status" >&5
+  echo "$as_me:11088: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -11111,12 +11098,12 @@
 ac_cv_sizeof_long_long_int=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:11114: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:11101: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 11119 "configure"
+#line 11106 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -11132,15 +11119,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:11135: \"$ac_link\"") >&5
+if { (eval echo "$as_me:11122: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:11138: \$? = $ac_status" >&5
+  echo "$as_me:11125: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:11140: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11127: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11143: \$? = $ac_status" >&5
+  echo "$as_me:11130: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_long_long_int=`cat conftest.val`
 else
@@ -11156,7 +11143,7 @@
   ac_cv_sizeof_long_long_int=0
 fi
 fi
-echo "$as_me:11159: result: $ac_cv_sizeof_long_long_int" >&5
+echo "$as_me:11146: result: $ac_cv_sizeof_long_long_int" >&5
 echo "${ECHO_T}$ac_cv_sizeof_long_long_int" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_LONG_LONG_INT $ac_cv_sizeof_long_long_int
@@ -11168,14 +11155,14 @@
 fi
 
 # More checks for data types
-echo "$as_me:11171: checking for u_int type" >&5
+echo "$as_me:11158: checking for u_int type" >&5
 echo $ECHO_N "checking for u_int type... $ECHO_C" >&6
 if test "${ac_cv_have_u_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11178 "configure"
+#line 11165 "configure"
 #include "confdefs.h"
  #include <sys/types.h>
 int
@@ -11187,16 +11174,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11190: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11177: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11193: \$? = $ac_status" >&5
+  echo "$as_me:11180: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11196: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11183: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11199: \$? = $ac_status" >&5
+  echo "$as_me:11186: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_u_int="yes"
 else
@@ -11208,7 +11195,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11211: result: $ac_cv_have_u_int" >&5
+echo "$as_me:11198: result: $ac_cv_have_u_int" >&5
 echo "${ECHO_T}$ac_cv_have_u_int" >&6
 if test "x$ac_cv_have_u_int" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11218,14 +11205,14 @@
 	have_u_int=1
 fi
 
-echo "$as_me:11221: checking for intXX_t types" >&5
+echo "$as_me:11208: checking for intXX_t types" >&5
 echo $ECHO_N "checking for intXX_t types... $ECHO_C" >&6
 if test "${ac_cv_have_intxx_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11228 "configure"
+#line 11215 "configure"
 #include "confdefs.h"
  #include <sys/types.h>
 int
@@ -11237,16 +11224,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11240: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11227: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11243: \$? = $ac_status" >&5
+  echo "$as_me:11230: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11246: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11233: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11249: \$? = $ac_status" >&5
+  echo "$as_me:11236: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_intxx_t="yes"
 else
@@ -11258,7 +11245,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11261: result: $ac_cv_have_intxx_t" >&5
+echo "$as_me:11248: result: $ac_cv_have_intxx_t" >&5
 echo "${ECHO_T}$ac_cv_have_intxx_t" >&6
 if test "x$ac_cv_have_intxx_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11271,10 +11258,10 @@
 if (test -z "$have_intxx_t" && \
            test "x$ac_cv_header_stdint_h" = "xyes")
 then
-    echo "$as_me:11274: checking for intXX_t types in stdint.h" >&5
+    echo "$as_me:11261: checking for intXX_t types in stdint.h" >&5
 echo $ECHO_N "checking for intXX_t types in stdint.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11277 "configure"
+#line 11264 "configure"
 #include "confdefs.h"
  #include <stdint.h>
 int
@@ -11286,43 +11273,43 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11289: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11276: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11292: \$? = $ac_status" >&5
+  echo "$as_me:11279: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11295: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11282: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11298: \$? = $ac_status" >&5
+  echo "$as_me:11285: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
 #define HAVE_INTXX_T 1
 EOF
 
-			echo "$as_me:11305: result: yes" >&5
+			echo "$as_me:11292: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:11311: result: no" >&5
+ echo "$as_me:11298: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
 
-echo "$as_me:11318: checking for int64_t type" >&5
+echo "$as_me:11305: checking for int64_t type" >&5
 echo $ECHO_N "checking for int64_t type... $ECHO_C" >&6
 if test "${ac_cv_have_int64_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11325 "configure"
+#line 11312 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -11343,16 +11330,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11346: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11333: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11349: \$? = $ac_status" >&5
+  echo "$as_me:11336: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11352: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11339: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11355: \$? = $ac_status" >&5
+  echo "$as_me:11342: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_int64_t="yes"
 else
@@ -11364,7 +11351,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11367: result: $ac_cv_have_int64_t" >&5
+echo "$as_me:11354: result: $ac_cv_have_int64_t" >&5
 echo "${ECHO_T}$ac_cv_have_int64_t" >&6
 if test "x$ac_cv_have_int64_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11373,14 +11360,14 @@
 
 fi
 
-echo "$as_me:11376: checking for u_intXX_t types" >&5
+echo "$as_me:11363: checking for u_intXX_t types" >&5
 echo $ECHO_N "checking for u_intXX_t types... $ECHO_C" >&6
 if test "${ac_cv_have_u_intxx_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11383 "configure"
+#line 11370 "configure"
 #include "confdefs.h"
  #include <sys/types.h>
 int
@@ -11392,16 +11379,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11395: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11382: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11398: \$? = $ac_status" >&5
+  echo "$as_me:11385: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11401: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11388: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11404: \$? = $ac_status" >&5
+  echo "$as_me:11391: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_u_intxx_t="yes"
 else
@@ -11413,7 +11400,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11416: result: $ac_cv_have_u_intxx_t" >&5
+echo "$as_me:11403: result: $ac_cv_have_u_intxx_t" >&5
 echo "${ECHO_T}$ac_cv_have_u_intxx_t" >&6
 if test "x$ac_cv_have_u_intxx_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11424,10 +11411,10 @@
 fi
 
 if test -z "$have_u_intxx_t" ; then
-    echo "$as_me:11427: checking for u_intXX_t types in sys/socket.h" >&5
+    echo "$as_me:11414: checking for u_intXX_t types in sys/socket.h" >&5
 echo $ECHO_N "checking for u_intXX_t types in sys/socket.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11430 "configure"
+#line 11417 "configure"
 #include "confdefs.h"
  #include <sys/socket.h>
 int
@@ -11439,43 +11426,43 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11442: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11429: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11445: \$? = $ac_status" >&5
+  echo "$as_me:11432: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11448: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11435: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11451: \$? = $ac_status" >&5
+  echo "$as_me:11438: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
 #define HAVE_U_INTXX_T 1
 EOF
 
-			echo "$as_me:11458: result: yes" >&5
+			echo "$as_me:11445: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:11464: result: no" >&5
+ echo "$as_me:11451: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
 
-echo "$as_me:11471: checking for u_int64_t types" >&5
+echo "$as_me:11458: checking for u_int64_t types" >&5
 echo $ECHO_N "checking for u_int64_t types... $ECHO_C" >&6
 if test "${ac_cv_have_u_int64_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11478 "configure"
+#line 11465 "configure"
 #include "confdefs.h"
  #include <sys/types.h>
 int
@@ -11487,16 +11474,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11490: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11477: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11493: \$? = $ac_status" >&5
+  echo "$as_me:11480: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11496: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11483: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11499: \$? = $ac_status" >&5
+  echo "$as_me:11486: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_u_int64_t="yes"
 else
@@ -11508,7 +11495,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11511: result: $ac_cv_have_u_int64_t" >&5
+echo "$as_me:11498: result: $ac_cv_have_u_int64_t" >&5
 echo "${ECHO_T}$ac_cv_have_u_int64_t" >&6
 if test "x$ac_cv_have_u_int64_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11519,10 +11506,10 @@
 fi
 
 if test -z "$have_u_int64_t" ; then
-    echo "$as_me:11522: checking for u_int64_t type in sys/bitypes.h" >&5
+    echo "$as_me:11509: checking for u_int64_t type in sys/bitypes.h" >&5
 echo $ECHO_N "checking for u_int64_t type in sys/bitypes.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11525 "configure"
+#line 11512 "configure"
 #include "confdefs.h"
  #include <sys/bitypes.h>
 int
@@ -11534,29 +11521,29 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11537: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11524: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11540: \$? = $ac_status" >&5
+  echo "$as_me:11527: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11543: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11530: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11546: \$? = $ac_status" >&5
+  echo "$as_me:11533: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
 #define HAVE_U_INT64_T 1
 EOF
 
-			echo "$as_me:11553: result: yes" >&5
+			echo "$as_me:11540: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:11559: result: no" >&5
+ echo "$as_me:11546: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
@@ -11564,14 +11551,14 @@
 fi
 
 if test -z "$have_u_intxx_t" ; then
-	echo "$as_me:11567: checking for uintXX_t types" >&5
+	echo "$as_me:11554: checking for uintXX_t types" >&5
 echo $ECHO_N "checking for uintXX_t types... $ECHO_C" >&6
 if test "${ac_cv_have_uintxx_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 11574 "configure"
+#line 11561 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -11585,16 +11572,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11588: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11575: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11591: \$? = $ac_status" >&5
+  echo "$as_me:11578: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11594: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11581: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11597: \$? = $ac_status" >&5
+  echo "$as_me:11584: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_uintxx_t="yes"
 else
@@ -11606,7 +11593,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11609: result: $ac_cv_have_uintxx_t" >&5
+echo "$as_me:11596: result: $ac_cv_have_uintxx_t" >&5
 echo "${ECHO_T}$ac_cv_have_uintxx_t" >&6
 	if test "x$ac_cv_have_uintxx_t" = "xyes" ; then
 		cat >>confdefs.h <<\EOF
@@ -11617,10 +11604,10 @@
 fi
 
 if test -z "$have_uintxx_t" ; then
-    echo "$as_me:11620: checking for uintXX_t types in stdint.h" >&5
+    echo "$as_me:11607: checking for uintXX_t types in stdint.h" >&5
 echo $ECHO_N "checking for uintXX_t types in stdint.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11623 "configure"
+#line 11610 "configure"
 #include "confdefs.h"
  #include <stdint.h>
 int
@@ -11632,29 +11619,29 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11635: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11622: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11638: \$? = $ac_status" >&5
+  echo "$as_me:11625: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11641: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11628: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11644: \$? = $ac_status" >&5
+  echo "$as_me:11631: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
 #define HAVE_UINTXX_T 1
 EOF
 
-			echo "$as_me:11651: result: yes" >&5
+			echo "$as_me:11638: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:11657: result: no" >&5
+ echo "$as_me:11644: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
@@ -11664,10 +11651,10 @@
 if (test -z "$have_u_intxx_t" || test -z "$have_intxx_t" && \
            test "x$ac_cv_header_sys_bitypes_h" = "xyes")
 then
-	echo "$as_me:11667: checking for intXX_t and u_intXX_t types in sys/bitypes.h" >&5
+	echo "$as_me:11654: checking for intXX_t and u_intXX_t types in sys/bitypes.h" >&5
 echo $ECHO_N "checking for intXX_t and u_intXX_t types in sys/bitypes.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11670 "configure"
+#line 11657 "configure"
 #include "confdefs.h"
 
 #include <sys/bitypes.h>
@@ -11685,16 +11672,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11688: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11675: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11691: \$? = $ac_status" >&5
+  echo "$as_me:11678: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11694: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11681: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11697: \$? = $ac_status" >&5
+  echo "$as_me:11684: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
@@ -11705,27 +11692,27 @@
 #define HAVE_INTXX_T 1
 EOF
 
-			echo "$as_me:11708: result: yes" >&5
+			echo "$as_me:11695: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
-echo "$as_me:11714: result: no" >&5
+echo "$as_me:11701: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
 
-echo "$as_me:11721: checking for u_char" >&5
+echo "$as_me:11708: checking for u_char" >&5
 echo $ECHO_N "checking for u_char... $ECHO_C" >&6
 if test "${ac_cv_have_u_char+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11728 "configure"
+#line 11715 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -11739,16 +11726,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11742: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11729: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11745: \$? = $ac_status" >&5
+  echo "$as_me:11732: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11748: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11735: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11751: \$? = $ac_status" >&5
+  echo "$as_me:11738: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_u_char="yes"
 else
@@ -11760,7 +11747,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11763: result: $ac_cv_have_u_char" >&5
+echo "$as_me:11750: result: $ac_cv_have_u_char" >&5
 echo "${ECHO_T}$ac_cv_have_u_char" >&6
 if test "x$ac_cv_have_u_char" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11769,13 +11756,13 @@
 
 fi
 
-   echo "$as_me:11772: checking for socklen_t" >&5
+   echo "$as_me:11759: checking for socklen_t" >&5
 echo $ECHO_N "checking for socklen_t... $ECHO_C" >&6
 if test "${ac_cv_type_socklen_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 11778 "configure"
+#line 11765 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -11792,16 +11779,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11795: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11782: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11798: \$? = $ac_status" >&5
+  echo "$as_me:11785: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11801: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11788: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11804: \$? = $ac_status" >&5
+  echo "$as_me:11791: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_socklen_t=yes
 else
@@ -11811,13 +11798,13 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:11814: result: $ac_cv_type_socklen_t" >&5
+echo "$as_me:11801: result: $ac_cv_type_socklen_t" >&5
 echo "${ECHO_T}$ac_cv_type_socklen_t" >&6
 if test $ac_cv_type_socklen_t = yes; then
   :
 else
 
-      echo "$as_me:11820: checking for socklen_t equivalent" >&5
+      echo "$as_me:11807: checking for socklen_t equivalent" >&5
 echo $ECHO_N "checking for socklen_t equivalent... $ECHO_C" >&6
       if test "${curl_cv_socklen_t_equiv+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -11829,7 +11816,7 @@
 	 for arg2 in "struct sockaddr" void; do
 	    for t in int size_t unsigned long "unsigned long"; do
 	       cat >conftest.$ac_ext <<_ACEOF
-#line 11832 "configure"
+#line 11819 "configure"
 #include "confdefs.h"
 
 		  #include <sys/types.h>
@@ -11849,16 +11836,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11852: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11839: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11855: \$? = $ac_status" >&5
+  echo "$as_me:11842: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11858: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11845: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11861: \$? = $ac_status" >&5
+  echo "$as_me:11848: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		  curl_cv_socklen_t_equiv="$t"
@@ -11873,14 +11860,14 @@
 	 done
 
 	 if test "x$curl_cv_socklen_t_equiv" = x; then
-	    { { echo "$as_me:11876: error: Cannot find a type to use in place of socklen_t" >&5
+	    { { echo "$as_me:11863: error: Cannot find a type to use in place of socklen_t" >&5
 echo "$as_me: error: Cannot find a type to use in place of socklen_t" >&2;}
    { (exit 1); exit 1; }; }
 	 fi
 
 fi
 
-      echo "$as_me:11883: result: $curl_cv_socklen_t_equiv" >&5
+      echo "$as_me:11870: result: $curl_cv_socklen_t_equiv" >&5
 echo "${ECHO_T}$curl_cv_socklen_t_equiv" >&6
 
 cat >>confdefs.h <<EOF
@@ -11889,13 +11876,13 @@
 
 fi
 
-echo "$as_me:11892: checking for sig_atomic_t" >&5
+echo "$as_me:11879: checking for sig_atomic_t" >&5
 echo $ECHO_N "checking for sig_atomic_t... $ECHO_C" >&6
 if test "${ac_cv_type_sig_atomic_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 11898 "configure"
+#line 11885 "configure"
 #include "confdefs.h"
 #include <signal.h>
 
@@ -11911,16 +11898,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11914: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11901: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11917: \$? = $ac_status" >&5
+  echo "$as_me:11904: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11920: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11907: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11923: \$? = $ac_status" >&5
+  echo "$as_me:11910: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_sig_atomic_t=yes
 else
@@ -11930,7 +11917,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:11933: result: $ac_cv_type_sig_atomic_t" >&5
+echo "$as_me:11920: result: $ac_cv_type_sig_atomic_t" >&5
 echo "${ECHO_T}$ac_cv_type_sig_atomic_t" >&6
 if test $ac_cv_type_sig_atomic_t = yes; then
 
@@ -11940,14 +11927,14 @@
 
 fi
 
-echo "$as_me:11943: checking for size_t" >&5
+echo "$as_me:11930: checking for size_t" >&5
 echo $ECHO_N "checking for size_t... $ECHO_C" >&6
 if test "${ac_cv_have_size_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11950 "configure"
+#line 11937 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -11961,16 +11948,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11964: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11951: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11967: \$? = $ac_status" >&5
+  echo "$as_me:11954: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11970: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11957: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11973: \$? = $ac_status" >&5
+  echo "$as_me:11960: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_size_t="yes"
 else
@@ -11982,7 +11969,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11985: result: $ac_cv_have_size_t" >&5
+echo "$as_me:11972: result: $ac_cv_have_size_t" >&5
 echo "${ECHO_T}$ac_cv_have_size_t" >&6
 if test "x$ac_cv_have_size_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11991,14 +11978,14 @@
 
 fi
 
-echo "$as_me:11994: checking for ssize_t" >&5
+echo "$as_me:11981: checking for ssize_t" >&5
 echo $ECHO_N "checking for ssize_t... $ECHO_C" >&6
 if test "${ac_cv_have_ssize_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12001 "configure"
+#line 11988 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12012,16 +11999,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12015: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12002: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12018: \$? = $ac_status" >&5
+  echo "$as_me:12005: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12021: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12008: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12024: \$? = $ac_status" >&5
+  echo "$as_me:12011: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_ssize_t="yes"
 else
@@ -12033,7 +12020,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12036: result: $ac_cv_have_ssize_t" >&5
+echo "$as_me:12023: result: $ac_cv_have_ssize_t" >&5
 echo "${ECHO_T}$ac_cv_have_ssize_t" >&6
 if test "x$ac_cv_have_ssize_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12042,14 +12029,14 @@
 
 fi
 
-echo "$as_me:12045: checking for clock_t" >&5
+echo "$as_me:12032: checking for clock_t" >&5
 echo $ECHO_N "checking for clock_t... $ECHO_C" >&6
 if test "${ac_cv_have_clock_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12052 "configure"
+#line 12039 "configure"
 #include "confdefs.h"
 
 #include <time.h>
@@ -12063,16 +12050,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12066: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12053: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12069: \$? = $ac_status" >&5
+  echo "$as_me:12056: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12072: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12059: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12075: \$? = $ac_status" >&5
+  echo "$as_me:12062: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_clock_t="yes"
 else
@@ -12084,7 +12071,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12087: result: $ac_cv_have_clock_t" >&5
+echo "$as_me:12074: result: $ac_cv_have_clock_t" >&5
 echo "${ECHO_T}$ac_cv_have_clock_t" >&6
 if test "x$ac_cv_have_clock_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12093,14 +12080,14 @@
 
 fi
 
-echo "$as_me:12096: checking for sa_family_t" >&5
+echo "$as_me:12083: checking for sa_family_t" >&5
 echo $ECHO_N "checking for sa_family_t... $ECHO_C" >&6
 if test "${ac_cv_have_sa_family_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12103 "configure"
+#line 12090 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12115,23 +12102,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12118: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12105: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12121: \$? = $ac_status" >&5
+  echo "$as_me:12108: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12124: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12111: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12127: \$? = $ac_status" >&5
+  echo "$as_me:12114: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_sa_family_t="yes"
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
  cat >conftest.$ac_ext <<_ACEOF
-#line 12134 "configure"
+#line 12121 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12147,16 +12134,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12150: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12137: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12153: \$? = $ac_status" >&5
+  echo "$as_me:12140: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12156: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12143: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12159: \$? = $ac_status" >&5
+  echo "$as_me:12146: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_sa_family_t="yes"
 else
@@ -12171,7 +12158,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12174: result: $ac_cv_have_sa_family_t" >&5
+echo "$as_me:12161: result: $ac_cv_have_sa_family_t" >&5
 echo "${ECHO_T}$ac_cv_have_sa_family_t" >&6
 if test "x$ac_cv_have_sa_family_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12180,14 +12167,14 @@
 
 fi
 
-echo "$as_me:12183: checking for pid_t" >&5
+echo "$as_me:12170: checking for pid_t" >&5
 echo $ECHO_N "checking for pid_t... $ECHO_C" >&6
 if test "${ac_cv_have_pid_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12190 "configure"
+#line 12177 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12201,16 +12188,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12204: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12191: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12207: \$? = $ac_status" >&5
+  echo "$as_me:12194: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12210: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12197: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12213: \$? = $ac_status" >&5
+  echo "$as_me:12200: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_pid_t="yes"
 else
@@ -12222,7 +12209,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12225: result: $ac_cv_have_pid_t" >&5
+echo "$as_me:12212: result: $ac_cv_have_pid_t" >&5
 echo "${ECHO_T}$ac_cv_have_pid_t" >&6
 if test "x$ac_cv_have_pid_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12231,14 +12218,14 @@
 
 fi
 
-echo "$as_me:12234: checking for mode_t" >&5
+echo "$as_me:12221: checking for mode_t" >&5
 echo $ECHO_N "checking for mode_t... $ECHO_C" >&6
 if test "${ac_cv_have_mode_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12241 "configure"
+#line 12228 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12252,16 +12239,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12255: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12242: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12258: \$? = $ac_status" >&5
+  echo "$as_me:12245: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12261: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12248: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12264: \$? = $ac_status" >&5
+  echo "$as_me:12251: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_mode_t="yes"
 else
@@ -12273,7 +12260,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12276: result: $ac_cv_have_mode_t" >&5
+echo "$as_me:12263: result: $ac_cv_have_mode_t" >&5
 echo "${ECHO_T}$ac_cv_have_mode_t" >&6
 if test "x$ac_cv_have_mode_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12282,14 +12269,14 @@
 
 fi
 
-echo "$as_me:12285: checking for struct sockaddr_storage" >&5
+echo "$as_me:12272: checking for struct sockaddr_storage" >&5
 echo $ECHO_N "checking for struct sockaddr_storage... $ECHO_C" >&6
 if test "${ac_cv_have_struct_sockaddr_storage+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12292 "configure"
+#line 12279 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12304,16 +12291,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12307: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12294: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12310: \$? = $ac_status" >&5
+  echo "$as_me:12297: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12313: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12300: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12316: \$? = $ac_status" >&5
+  echo "$as_me:12303: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_sockaddr_storage="yes"
 else
@@ -12325,7 +12312,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12328: result: $ac_cv_have_struct_sockaddr_storage" >&5
+echo "$as_me:12315: result: $ac_cv_have_struct_sockaddr_storage" >&5
 echo "${ECHO_T}$ac_cv_have_struct_sockaddr_storage" >&6
 if test "x$ac_cv_have_struct_sockaddr_storage" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12334,14 +12321,14 @@
 
 fi
 
-echo "$as_me:12337: checking for struct sockaddr_in6" >&5
+echo "$as_me:12324: checking for struct sockaddr_in6" >&5
 echo $ECHO_N "checking for struct sockaddr_in6... $ECHO_C" >&6
 if test "${ac_cv_have_struct_sockaddr_in6+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12344 "configure"
+#line 12331 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12356,16 +12343,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12359: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12346: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12362: \$? = $ac_status" >&5
+  echo "$as_me:12349: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12365: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12352: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12368: \$? = $ac_status" >&5
+  echo "$as_me:12355: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_sockaddr_in6="yes"
 else
@@ -12377,7 +12364,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12380: result: $ac_cv_have_struct_sockaddr_in6" >&5
+echo "$as_me:12367: result: $ac_cv_have_struct_sockaddr_in6" >&5
 echo "${ECHO_T}$ac_cv_have_struct_sockaddr_in6" >&6
 if test "x$ac_cv_have_struct_sockaddr_in6" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12386,14 +12373,14 @@
 
 fi
 
-echo "$as_me:12389: checking for struct in6_addr" >&5
+echo "$as_me:12376: checking for struct in6_addr" >&5
 echo $ECHO_N "checking for struct in6_addr... $ECHO_C" >&6
 if test "${ac_cv_have_struct_in6_addr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12396 "configure"
+#line 12383 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12408,16 +12395,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12411: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12398: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12414: \$? = $ac_status" >&5
+  echo "$as_me:12401: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12417: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12404: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12420: \$? = $ac_status" >&5
+  echo "$as_me:12407: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_in6_addr="yes"
 else
@@ -12429,7 +12416,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12432: result: $ac_cv_have_struct_in6_addr" >&5
+echo "$as_me:12419: result: $ac_cv_have_struct_in6_addr" >&5
 echo "${ECHO_T}$ac_cv_have_struct_in6_addr" >&6
 if test "x$ac_cv_have_struct_in6_addr" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12438,14 +12425,14 @@
 
 fi
 
-echo "$as_me:12441: checking for struct addrinfo" >&5
+echo "$as_me:12428: checking for struct addrinfo" >&5
 echo $ECHO_N "checking for struct addrinfo... $ECHO_C" >&6
 if test "${ac_cv_have_struct_addrinfo+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12448 "configure"
+#line 12435 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12461,16 +12448,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12464: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12451: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12467: \$? = $ac_status" >&5
+  echo "$as_me:12454: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12470: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12457: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12473: \$? = $ac_status" >&5
+  echo "$as_me:12460: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_addrinfo="yes"
 else
@@ -12482,7 +12469,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12485: result: $ac_cv_have_struct_addrinfo" >&5
+echo "$as_me:12472: result: $ac_cv_have_struct_addrinfo" >&5
 echo "${ECHO_T}$ac_cv_have_struct_addrinfo" >&6
 if test "x$ac_cv_have_struct_addrinfo" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12491,14 +12478,14 @@
 
 fi
 
-echo "$as_me:12494: checking for struct timeval" >&5
+echo "$as_me:12481: checking for struct timeval" >&5
 echo $ECHO_N "checking for struct timeval... $ECHO_C" >&6
 if test "${ac_cv_have_struct_timeval+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12501 "configure"
+#line 12488 "configure"
 #include "confdefs.h"
  #include <sys/time.h>
 int
@@ -12510,16 +12497,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12513: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12500: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12516: \$? = $ac_status" >&5
+  echo "$as_me:12503: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12519: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12506: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12522: \$? = $ac_status" >&5
+  echo "$as_me:12509: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_timeval="yes"
 else
@@ -12531,7 +12518,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12534: result: $ac_cv_have_struct_timeval" >&5
+echo "$as_me:12521: result: $ac_cv_have_struct_timeval" >&5
 echo "${ECHO_T}$ac_cv_have_struct_timeval" >&6
 if test "x$ac_cv_have_struct_timeval" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12541,13 +12528,13 @@
 	have_struct_timeval=1
 fi
 
-echo "$as_me:12544: checking for struct timespec" >&5
+echo "$as_me:12531: checking for struct timespec" >&5
 echo $ECHO_N "checking for struct timespec... $ECHO_C" >&6
 if test "${ac_cv_type_struct_timespec+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12550 "configure"
+#line 12537 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -12562,16 +12549,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12565: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12552: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12568: \$? = $ac_status" >&5
+  echo "$as_me:12555: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12571: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12558: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12574: \$? = $ac_status" >&5
+  echo "$as_me:12561: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_struct_timespec=yes
 else
@@ -12581,7 +12568,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:12584: result: $ac_cv_type_struct_timespec" >&5
+echo "$as_me:12571: result: $ac_cv_type_struct_timespec" >&5
 echo "${ECHO_T}$ac_cv_type_struct_timespec" >&6
 if test $ac_cv_type_struct_timespec = yes; then
 
@@ -12601,12 +12588,12 @@
 	exit 1;
 else
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:12604: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:12591: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12609 "configure"
+#line 12596 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -12634,15 +12621,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:12637: \"$ac_link\"") >&5
+if { (eval echo "$as_me:12624: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:12640: \$? = $ac_status" >&5
+  echo "$as_me:12627: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:12642: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12629: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12645: \$? = $ac_status" >&5
+  echo "$as_me:12632: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    true
 else
@@ -12661,14 +12648,14 @@
 # look for field 'ut_host' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_host
-	echo "$as_me:12664: checking for ut_host field in utmp.h" >&5
+	echo "$as_me:12651: checking for ut_host field in utmp.h" >&5
 echo $ECHO_N "checking for ut_host field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12671 "configure"
+#line 12658 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12685,7 +12672,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12688: result: $ossh_result" >&5
+		echo "$as_me:12675: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12694,21 +12681,21 @@
 
 		fi
 	else
-		echo "$as_me:12697: result: no" >&5
+		echo "$as_me:12684: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_host' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_host
-	echo "$as_me:12704: checking for ut_host field in utmpx.h" >&5
+	echo "$as_me:12691: checking for ut_host field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_host field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12711 "configure"
+#line 12698 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -12725,7 +12712,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12728: result: $ossh_result" >&5
+		echo "$as_me:12715: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12734,21 +12721,21 @@
 
 		fi
 	else
-		echo "$as_me:12737: result: no" >&5
+		echo "$as_me:12724: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'syslen' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"syslen
-	echo "$as_me:12744: checking for syslen field in utmpx.h" >&5
+	echo "$as_me:12731: checking for syslen field in utmpx.h" >&5
 echo $ECHO_N "checking for syslen field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12751 "configure"
+#line 12738 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -12765,7 +12752,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12768: result: $ossh_result" >&5
+		echo "$as_me:12755: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12774,21 +12761,21 @@
 
 		fi
 	else
-		echo "$as_me:12777: result: no" >&5
+		echo "$as_me:12764: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_pid' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_pid
-	echo "$as_me:12784: checking for ut_pid field in utmp.h" >&5
+	echo "$as_me:12771: checking for ut_pid field in utmp.h" >&5
 echo $ECHO_N "checking for ut_pid field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12791 "configure"
+#line 12778 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12805,7 +12792,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12808: result: $ossh_result" >&5
+		echo "$as_me:12795: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12814,21 +12801,21 @@
 
 		fi
 	else
-		echo "$as_me:12817: result: no" >&5
+		echo "$as_me:12804: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_type' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_type
-	echo "$as_me:12824: checking for ut_type field in utmp.h" >&5
+	echo "$as_me:12811: checking for ut_type field in utmp.h" >&5
 echo $ECHO_N "checking for ut_type field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12831 "configure"
+#line 12818 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12845,7 +12832,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12848: result: $ossh_result" >&5
+		echo "$as_me:12835: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12854,21 +12841,21 @@
 
 		fi
 	else
-		echo "$as_me:12857: result: no" >&5
+		echo "$as_me:12844: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_type' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_type
-	echo "$as_me:12864: checking for ut_type field in utmpx.h" >&5
+	echo "$as_me:12851: checking for ut_type field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_type field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12871 "configure"
+#line 12858 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -12885,7 +12872,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12888: result: $ossh_result" >&5
+		echo "$as_me:12875: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12894,21 +12881,21 @@
 
 		fi
 	else
-		echo "$as_me:12897: result: no" >&5
+		echo "$as_me:12884: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_tv' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_tv
-	echo "$as_me:12904: checking for ut_tv field in utmp.h" >&5
+	echo "$as_me:12891: checking for ut_tv field in utmp.h" >&5
 echo $ECHO_N "checking for ut_tv field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12911 "configure"
+#line 12898 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12925,7 +12912,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12928: result: $ossh_result" >&5
+		echo "$as_me:12915: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12934,21 +12921,21 @@
 
 		fi
 	else
-		echo "$as_me:12937: result: no" >&5
+		echo "$as_me:12924: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_id' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_id
-	echo "$as_me:12944: checking for ut_id field in utmp.h" >&5
+	echo "$as_me:12931: checking for ut_id field in utmp.h" >&5
 echo $ECHO_N "checking for ut_id field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12951 "configure"
+#line 12938 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12965,7 +12952,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12968: result: $ossh_result" >&5
+		echo "$as_me:12955: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12974,21 +12961,21 @@
 
 		fi
 	else
-		echo "$as_me:12977: result: no" >&5
+		echo "$as_me:12964: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_id' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_id
-	echo "$as_me:12984: checking for ut_id field in utmpx.h" >&5
+	echo "$as_me:12971: checking for ut_id field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_id field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12991 "configure"
+#line 12978 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13005,7 +12992,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13008: result: $ossh_result" >&5
+		echo "$as_me:12995: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13014,21 +13001,21 @@
 
 		fi
 	else
-		echo "$as_me:13017: result: no" >&5
+		echo "$as_me:13004: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_addr' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_addr
-	echo "$as_me:13024: checking for ut_addr field in utmp.h" >&5
+	echo "$as_me:13011: checking for ut_addr field in utmp.h" >&5
 echo $ECHO_N "checking for ut_addr field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13031 "configure"
+#line 13018 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -13045,7 +13032,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13048: result: $ossh_result" >&5
+		echo "$as_me:13035: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13054,21 +13041,21 @@
 
 		fi
 	else
-		echo "$as_me:13057: result: no" >&5
+		echo "$as_me:13044: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_addr' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_addr
-	echo "$as_me:13064: checking for ut_addr field in utmpx.h" >&5
+	echo "$as_me:13051: checking for ut_addr field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_addr field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13071 "configure"
+#line 13058 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13085,7 +13072,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13088: result: $ossh_result" >&5
+		echo "$as_me:13075: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13094,21 +13081,21 @@
 
 		fi
 	else
-		echo "$as_me:13097: result: no" >&5
+		echo "$as_me:13084: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_addr_v6' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_addr_v6
-	echo "$as_me:13104: checking for ut_addr_v6 field in utmp.h" >&5
+	echo "$as_me:13091: checking for ut_addr_v6 field in utmp.h" >&5
 echo $ECHO_N "checking for ut_addr_v6 field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13111 "configure"
+#line 13098 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -13125,7 +13112,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13128: result: $ossh_result" >&5
+		echo "$as_me:13115: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13134,21 +13121,21 @@
 
 		fi
 	else
-		echo "$as_me:13137: result: no" >&5
+		echo "$as_me:13124: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_addr_v6' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_addr_v6
-	echo "$as_me:13144: checking for ut_addr_v6 field in utmpx.h" >&5
+	echo "$as_me:13131: checking for ut_addr_v6 field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_addr_v6 field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13151 "configure"
+#line 13138 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13165,7 +13152,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13168: result: $ossh_result" >&5
+		echo "$as_me:13155: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13174,21 +13161,21 @@
 
 		fi
 	else
-		echo "$as_me:13177: result: no" >&5
+		echo "$as_me:13164: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_exit' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_exit
-	echo "$as_me:13184: checking for ut_exit field in utmp.h" >&5
+	echo "$as_me:13171: checking for ut_exit field in utmp.h" >&5
 echo $ECHO_N "checking for ut_exit field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13191 "configure"
+#line 13178 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -13205,7 +13192,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13208: result: $ossh_result" >&5
+		echo "$as_me:13195: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13214,21 +13201,21 @@
 
 		fi
 	else
-		echo "$as_me:13217: result: no" >&5
+		echo "$as_me:13204: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_time' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_time
-	echo "$as_me:13224: checking for ut_time field in utmp.h" >&5
+	echo "$as_me:13211: checking for ut_time field in utmp.h" >&5
 echo $ECHO_N "checking for ut_time field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13231 "configure"
+#line 13218 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -13245,7 +13232,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13248: result: $ossh_result" >&5
+		echo "$as_me:13235: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13254,21 +13241,21 @@
 
 		fi
 	else
-		echo "$as_me:13257: result: no" >&5
+		echo "$as_me:13244: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_time' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_time
-	echo "$as_me:13264: checking for ut_time field in utmpx.h" >&5
+	echo "$as_me:13251: checking for ut_time field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_time field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13271 "configure"
+#line 13258 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13285,7 +13272,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13288: result: $ossh_result" >&5
+		echo "$as_me:13275: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13294,21 +13281,21 @@
 
 		fi
 	else
-		echo "$as_me:13297: result: no" >&5
+		echo "$as_me:13284: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_tv' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_tv
-	echo "$as_me:13304: checking for ut_tv field in utmpx.h" >&5
+	echo "$as_me:13291: checking for ut_tv field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_tv field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13311 "configure"
+#line 13298 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13325,7 +13312,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13328: result: $ossh_result" >&5
+		echo "$as_me:13315: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13334,17 +13321,17 @@
 
 		fi
 	else
-		echo "$as_me:13337: result: no" >&5
+		echo "$as_me:13324: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
-echo "$as_me:13341: checking for struct stat.st_blksize" >&5
+echo "$as_me:13328: checking for struct stat.st_blksize" >&5
 echo $ECHO_N "checking for struct stat.st_blksize... $ECHO_C" >&6
 if test "${ac_cv_member_struct_stat_st_blksize+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 13347 "configure"
+#line 13334 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -13358,16 +13345,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13361: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13348: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13364: \$? = $ac_status" >&5
+  echo "$as_me:13351: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13367: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13354: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13370: \$? = $ac_status" >&5
+  echo "$as_me:13357: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_member_struct_stat_st_blksize=yes
 else
@@ -13377,7 +13364,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:13380: result: $ac_cv_member_struct_stat_st_blksize" >&5
+echo "$as_me:13367: result: $ac_cv_member_struct_stat_st_blksize" >&5
 echo "${ECHO_T}$ac_cv_member_struct_stat_st_blksize" >&6
 if test $ac_cv_member_struct_stat_st_blksize = yes; then
 
@@ -13387,14 +13374,14 @@
 
 fi
 
-echo "$as_me:13390: checking for ss_family field in struct sockaddr_storage" >&5
+echo "$as_me:13377: checking for ss_family field in struct sockaddr_storage" >&5
 echo $ECHO_N "checking for ss_family field in struct sockaddr_storage... $ECHO_C" >&6
 if test "${ac_cv_have_ss_family_in_struct_ss+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13397 "configure"
+#line 13384 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -13409,16 +13396,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13412: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13399: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13415: \$? = $ac_status" >&5
+  echo "$as_me:13402: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13418: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13405: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13421: \$? = $ac_status" >&5
+  echo "$as_me:13408: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_ss_family_in_struct_ss="yes"
 else
@@ -13429,7 +13416,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13432: result: $ac_cv_have_ss_family_in_struct_ss" >&5
+echo "$as_me:13419: result: $ac_cv_have_ss_family_in_struct_ss" >&5
 echo "${ECHO_T}$ac_cv_have_ss_family_in_struct_ss" >&6
 if test "x$ac_cv_have_ss_family_in_struct_ss" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13438,14 +13425,14 @@
 
 fi
 
-echo "$as_me:13441: checking for __ss_family field in struct sockaddr_storage" >&5
+echo "$as_me:13428: checking for __ss_family field in struct sockaddr_storage" >&5
 echo $ECHO_N "checking for __ss_family field in struct sockaddr_storage... $ECHO_C" >&6
 if test "${ac_cv_have___ss_family_in_struct_ss+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13448 "configure"
+#line 13435 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -13460,16 +13447,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13463: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13450: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13466: \$? = $ac_status" >&5
+  echo "$as_me:13453: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13469: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13456: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13472: \$? = $ac_status" >&5
+  echo "$as_me:13459: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have___ss_family_in_struct_ss="yes"
 else
@@ -13481,7 +13468,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13484: result: $ac_cv_have___ss_family_in_struct_ss" >&5
+echo "$as_me:13471: result: $ac_cv_have___ss_family_in_struct_ss" >&5
 echo "${ECHO_T}$ac_cv_have___ss_family_in_struct_ss" >&6
 if test "x$ac_cv_have___ss_family_in_struct_ss" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13490,14 +13477,14 @@
 
 fi
 
-echo "$as_me:13493: checking for pw_class field in struct passwd" >&5
+echo "$as_me:13480: checking for pw_class field in struct passwd" >&5
 echo $ECHO_N "checking for pw_class field in struct passwd... $ECHO_C" >&6
 if test "${ac_cv_have_pw_class_in_struct_passwd+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13500 "configure"
+#line 13487 "configure"
 #include "confdefs.h"
 
 #include <pwd.h>
@@ -13511,16 +13498,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13514: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13501: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13517: \$? = $ac_status" >&5
+  echo "$as_me:13504: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13520: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13507: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13523: \$? = $ac_status" >&5
+  echo "$as_me:13510: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_pw_class_in_struct_passwd="yes"
 else
@@ -13532,7 +13519,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13535: result: $ac_cv_have_pw_class_in_struct_passwd" >&5
+echo "$as_me:13522: result: $ac_cv_have_pw_class_in_struct_passwd" >&5
 echo "${ECHO_T}$ac_cv_have_pw_class_in_struct_passwd" >&6
 if test "x$ac_cv_have_pw_class_in_struct_passwd" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13541,14 +13528,14 @@
 
 fi
 
-echo "$as_me:13544: checking for pw_expire field in struct passwd" >&5
+echo "$as_me:13531: checking for pw_expire field in struct passwd" >&5
 echo $ECHO_N "checking for pw_expire field in struct passwd... $ECHO_C" >&6
 if test "${ac_cv_have_pw_expire_in_struct_passwd+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13551 "configure"
+#line 13538 "configure"
 #include "confdefs.h"
 
 #include <pwd.h>
@@ -13562,16 +13549,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13565: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13552: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13568: \$? = $ac_status" >&5
+  echo "$as_me:13555: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13571: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13558: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13574: \$? = $ac_status" >&5
+  echo "$as_me:13561: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_pw_expire_in_struct_passwd="yes"
 else
@@ -13583,7 +13570,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13586: result: $ac_cv_have_pw_expire_in_struct_passwd" >&5
+echo "$as_me:13573: result: $ac_cv_have_pw_expire_in_struct_passwd" >&5
 echo "${ECHO_T}$ac_cv_have_pw_expire_in_struct_passwd" >&6
 if test "x$ac_cv_have_pw_expire_in_struct_passwd" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13592,14 +13579,14 @@
 
 fi
 
-echo "$as_me:13595: checking for pw_change field in struct passwd" >&5
+echo "$as_me:13582: checking for pw_change field in struct passwd" >&5
 echo $ECHO_N "checking for pw_change field in struct passwd... $ECHO_C" >&6
 if test "${ac_cv_have_pw_change_in_struct_passwd+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13602 "configure"
+#line 13589 "configure"
 #include "confdefs.h"
 
 #include <pwd.h>
@@ -13613,16 +13600,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13616: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13603: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13619: \$? = $ac_status" >&5
+  echo "$as_me:13606: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13622: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13609: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13625: \$? = $ac_status" >&5
+  echo "$as_me:13612: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_pw_change_in_struct_passwd="yes"
 else
@@ -13634,7 +13621,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13637: result: $ac_cv_have_pw_change_in_struct_passwd" >&5
+echo "$as_me:13624: result: $ac_cv_have_pw_change_in_struct_passwd" >&5
 echo "${ECHO_T}$ac_cv_have_pw_change_in_struct_passwd" >&6
 if test "x$ac_cv_have_pw_change_in_struct_passwd" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13643,19 +13630,19 @@
 
 fi
 
-echo "$as_me:13646: checking for msg_accrights field in struct msghdr" >&5
+echo "$as_me:13633: checking for msg_accrights field in struct msghdr" >&5
 echo $ECHO_N "checking for msg_accrights field in struct msghdr... $ECHO_C" >&6
 if test "${ac_cv_have_accrights_in_msghdr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:13653: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:13640: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 13658 "configure"
+#line 13645 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -13672,15 +13659,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:13675: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13662: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13678: \$? = $ac_status" >&5
+  echo "$as_me:13665: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:13680: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13667: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13683: \$? = $ac_status" >&5
+  echo "$as_me:13670: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_accrights_in_msghdr="yes"
 else
@@ -13694,7 +13681,7 @@
 fi
 
 fi
-echo "$as_me:13697: result: $ac_cv_have_accrights_in_msghdr" >&5
+echo "$as_me:13684: result: $ac_cv_have_accrights_in_msghdr" >&5
 echo "${ECHO_T}$ac_cv_have_accrights_in_msghdr" >&6
 if test "x$ac_cv_have_accrights_in_msghdr" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13703,19 +13690,19 @@
 
 fi
 
-echo "$as_me:13706: checking for msg_control field in struct msghdr" >&5
+echo "$as_me:13693: checking for msg_control field in struct msghdr" >&5
 echo $ECHO_N "checking for msg_control field in struct msghdr... $ECHO_C" >&6
 if test "${ac_cv_have_control_in_msghdr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:13713: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:13700: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 13718 "configure"
+#line 13705 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -13732,15 +13719,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:13735: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13722: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13738: \$? = $ac_status" >&5
+  echo "$as_me:13725: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:13740: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13727: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13743: \$? = $ac_status" >&5
+  echo "$as_me:13730: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_control_in_msghdr="yes"
 else
@@ -13754,7 +13741,7 @@
 fi
 
 fi
-echo "$as_me:13757: result: $ac_cv_have_control_in_msghdr" >&5
+echo "$as_me:13744: result: $ac_cv_have_control_in_msghdr" >&5
 echo "${ECHO_T}$ac_cv_have_control_in_msghdr" >&6
 if test "x$ac_cv_have_control_in_msghdr" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13763,14 +13750,14 @@
 
 fi
 
-echo "$as_me:13766: checking if libc defines __progname" >&5
+echo "$as_me:13753: checking if libc defines __progname" >&5
 echo $ECHO_N "checking if libc defines __progname... $ECHO_C" >&6
 if test "${ac_cv_libc_defines___progname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13773 "configure"
+#line 13760 "configure"
 #include "confdefs.h"
 
 int
@@ -13782,16 +13769,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13785: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13772: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13788: \$? = $ac_status" >&5
+  echo "$as_me:13775: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13791: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13778: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13794: \$? = $ac_status" >&5
+  echo "$as_me:13781: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_libc_defines___progname="yes"
 else
@@ -13803,7 +13790,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:13806: result: $ac_cv_libc_defines___progname" >&5
+echo "$as_me:13793: result: $ac_cv_libc_defines___progname" >&5
 echo "${ECHO_T}$ac_cv_libc_defines___progname" >&6
 if test "x$ac_cv_libc_defines___progname" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13812,14 +13799,14 @@
 
 fi
 
-echo "$as_me:13815: checking whether $CC implements __FUNCTION__" >&5
+echo "$as_me:13802: checking whether $CC implements __FUNCTION__" >&5
 echo $ECHO_N "checking whether $CC implements __FUNCTION__... $ECHO_C" >&6
 if test "${ac_cv_cc_implements___FUNCTION__+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13822 "configure"
+#line 13809 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -13833,16 +13820,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13836: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13823: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13839: \$? = $ac_status" >&5
+  echo "$as_me:13826: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13842: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13829: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13845: \$? = $ac_status" >&5
+  echo "$as_me:13832: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_cc_implements___FUNCTION__="yes"
 else
@@ -13854,7 +13841,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:13857: result: $ac_cv_cc_implements___FUNCTION__" >&5
+echo "$as_me:13844: result: $ac_cv_cc_implements___FUNCTION__" >&5
 echo "${ECHO_T}$ac_cv_cc_implements___FUNCTION__" >&6
 if test "x$ac_cv_cc_implements___FUNCTION__" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13863,14 +13850,14 @@
 
 fi
 
-echo "$as_me:13866: checking whether $CC implements __func__" >&5
+echo "$as_me:13853: checking whether $CC implements __func__" >&5
 echo $ECHO_N "checking whether $CC implements __func__... $ECHO_C" >&6
 if test "${ac_cv_cc_implements___func__+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13873 "configure"
+#line 13860 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -13884,16 +13871,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13887: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13874: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13890: \$? = $ac_status" >&5
+  echo "$as_me:13877: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13893: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13880: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13896: \$? = $ac_status" >&5
+  echo "$as_me:13883: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_cc_implements___func__="yes"
 else
@@ -13905,7 +13892,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:13908: result: $ac_cv_cc_implements___func__" >&5
+echo "$as_me:13895: result: $ac_cv_cc_implements___func__" >&5
 echo "${ECHO_T}$ac_cv_cc_implements___func__" >&6
 if test "x$ac_cv_cc_implements___func__" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13914,14 +13901,14 @@
 
 fi
 
-echo "$as_me:13917: checking whether getopt has optreset support" >&5
+echo "$as_me:13904: checking whether getopt has optreset support" >&5
 echo $ECHO_N "checking whether getopt has optreset support... $ECHO_C" >&6
 if test "${ac_cv_have_getopt_optreset+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13924 "configure"
+#line 13911 "configure"
 #include "confdefs.h"
 
 #include <getopt.h>
@@ -13935,16 +13922,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13938: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13925: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13941: \$? = $ac_status" >&5
+  echo "$as_me:13928: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13944: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13931: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13947: \$? = $ac_status" >&5
+  echo "$as_me:13934: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_getopt_optreset="yes"
 else
@@ -13956,7 +13943,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:13959: result: $ac_cv_have_getopt_optreset" >&5
+echo "$as_me:13946: result: $ac_cv_have_getopt_optreset" >&5
 echo "${ECHO_T}$ac_cv_have_getopt_optreset" >&6
 if test "x$ac_cv_have_getopt_optreset" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13965,14 +13952,14 @@
 
 fi
 
-echo "$as_me:13968: checking if libc defines sys_errlist" >&5
+echo "$as_me:13955: checking if libc defines sys_errlist" >&5
 echo $ECHO_N "checking if libc defines sys_errlist... $ECHO_C" >&6
 if test "${ac_cv_libc_defines_sys_errlist+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13975 "configure"
+#line 13962 "configure"
 #include "confdefs.h"
 
 int
@@ -13984,16 +13971,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13987: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13974: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13990: \$? = $ac_status" >&5
+  echo "$as_me:13977: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13993: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13980: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13996: \$? = $ac_status" >&5
+  echo "$as_me:13983: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_libc_defines_sys_errlist="yes"
 else
@@ -14005,7 +13992,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:14008: result: $ac_cv_libc_defines_sys_errlist" >&5
+echo "$as_me:13995: result: $ac_cv_libc_defines_sys_errlist" >&5
 echo "${ECHO_T}$ac_cv_libc_defines_sys_errlist" >&6
 if test "x$ac_cv_libc_defines_sys_errlist" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -14014,14 +14001,14 @@
 
 fi
 
-echo "$as_me:14017: checking if libc defines sys_nerr" >&5
+echo "$as_me:14004: checking if libc defines sys_nerr" >&5
 echo $ECHO_N "checking if libc defines sys_nerr... $ECHO_C" >&6
 if test "${ac_cv_libc_defines_sys_nerr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 14024 "configure"
+#line 14011 "configure"
 #include "confdefs.h"
 
 int
@@ -14033,16 +14020,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14036: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14023: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14039: \$? = $ac_status" >&5
+  echo "$as_me:14026: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14042: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14029: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14045: \$? = $ac_status" >&5
+  echo "$as_me:14032: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_libc_defines_sys_nerr="yes"
 else
@@ -14054,7 +14041,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:14057: result: $ac_cv_libc_defines_sys_nerr" >&5
+echo "$as_me:14044: result: $ac_cv_libc_defines_sys_nerr" >&5
 echo "${ECHO_T}$ac_cv_libc_defines_sys_nerr" >&6
 if test "x$ac_cv_libc_defines_sys_nerr" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -14085,23 +14072,23 @@
 for ac_header in sectok.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:14088: checking for $ac_header" >&5
+echo "$as_me:14075: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14094 "configure"
+#line 14081 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:14098: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:14085: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:14104: \$? = $ac_status" >&5
+  echo "$as_me:14091: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -14120,7 +14107,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:14123: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:14110: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -14131,12 +14118,12 @@
 done
 
 			if test "$ac_cv_header_sectok_h" != yes; then
-				{ { echo "$as_me:14134: error: Can't find sectok.h" >&5
+				{ { echo "$as_me:14121: error: Can't find sectok.h" >&5
 echo "$as_me: error: Can't find sectok.h" >&2;}
    { (exit 1); exit 1; }; }
 			fi
 
-echo "$as_me:14139: checking for sectok_open in -lsectok" >&5
+echo "$as_me:14126: checking for sectok_open in -lsectok" >&5
 echo $ECHO_N "checking for sectok_open in -lsectok... $ECHO_C" >&6
 if test "${ac_cv_lib_sectok_sectok_open+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14144,7 +14131,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lsectok  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 14147 "configure"
+#line 14134 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14163,16 +14150,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14166: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14153: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14169: \$? = $ac_status" >&5
+  echo "$as_me:14156: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14172: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14159: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14175: \$? = $ac_status" >&5
+  echo "$as_me:14162: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_sectok_sectok_open=yes
 else
@@ -14183,7 +14170,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:14186: result: $ac_cv_lib_sectok_sectok_open" >&5
+echo "$as_me:14173: result: $ac_cv_lib_sectok_sectok_open" >&5
 echo "${ECHO_T}$ac_cv_lib_sectok_sectok_open" >&6
 if test $ac_cv_lib_sectok_sectok_open = yes; then
   cat >>confdefs.h <<EOF
@@ -14195,7 +14182,7 @@
 fi
 
 			if test "$ac_cv_lib_sectok_sectok_open" != yes; then
-				{ { echo "$as_me:14198: error: Can't find libsectok" >&5
+				{ { echo "$as_me:14185: error: Can't find libsectok" >&5
 echo "$as_me: error: Can't find libsectok" >&2;}
    { (exit 1); exit 1; }; }
 			fi
@@ -14225,7 +14212,7 @@
   OPENSC_CONFIG=$opensc_config_prefix/bin/opensc-config
   # Extract the first word of "opensc-config", so it can be a program name with args.
 set dummy opensc-config; ac_word=$2
-echo "$as_me:14228: checking for $ac_word" >&5
+echo "$as_me:14215: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_OPENSC_CONFIG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14242,7 +14229,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_OPENSC_CONFIG="$ac_dir/$ac_word"
-   echo "$as_me:14245: found $ac_dir/$ac_word" >&5
+   echo "$as_me:14232: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -14254,10 +14241,10 @@
 OPENSC_CONFIG=$ac_cv_path_OPENSC_CONFIG
 
 if test -n "$OPENSC_CONFIG"; then
-  echo "$as_me:14257: result: $OPENSC_CONFIG" >&5
+  echo "$as_me:14244: result: $OPENSC_CONFIG" >&5
 echo "${ECHO_T}$OPENSC_CONFIG" >&6
 else
-  echo "$as_me:14260: result: no" >&5
+  echo "$as_me:14247: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -14291,7 +14278,7 @@
 #define DNS 1
 EOF
 
-			echo "$as_me:14294: checking for library containing getrrsetbyname" >&5
+			echo "$as_me:14281: checking for library containing getrrsetbyname" >&5
 echo $ECHO_N "checking for library containing getrrsetbyname... $ECHO_C" >&6
 if test "${ac_cv_search_getrrsetbyname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14299,7 +14286,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_getrrsetbyname=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 14302 "configure"
+#line 14289 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14318,16 +14305,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14321: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14308: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14324: \$? = $ac_status" >&5
+  echo "$as_me:14311: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14327: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14314: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14330: \$? = $ac_status" >&5
+  echo "$as_me:14317: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_getrrsetbyname="none required"
 else
@@ -14339,7 +14326,7 @@
   for ac_lib in resolv; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 14342 "configure"
+#line 14329 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14358,16 +14345,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14361: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14348: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14364: \$? = $ac_status" >&5
+  echo "$as_me:14351: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14367: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14354: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14370: \$? = $ac_status" >&5
+  echo "$as_me:14357: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_getrrsetbyname="-l$ac_lib"
 break
@@ -14380,7 +14367,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:14383: result: $ac_cv_search_getrrsetbyname" >&5
+echo "$as_me:14370: result: $ac_cv_search_getrrsetbyname" >&5
 echo "${ECHO_T}$ac_cv_search_getrrsetbyname" >&6
 if test "$ac_cv_search_getrrsetbyname" != no; then
   test "$ac_cv_search_getrrsetbyname" = "none required" || LIBS="$ac_cv_search_getrrsetbyname $LIBS"
@@ -14391,7 +14378,7 @@
 else
 
 					# Needed by our getrrsetbyname()
-					echo "$as_me:14394: checking for library containing res_query" >&5
+					echo "$as_me:14381: checking for library containing res_query" >&5
 echo $ECHO_N "checking for library containing res_query... $ECHO_C" >&6
 if test "${ac_cv_search_res_query+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14399,7 +14386,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_res_query=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 14402 "configure"
+#line 14389 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14418,16 +14405,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14421: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14408: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14424: \$? = $ac_status" >&5
+  echo "$as_me:14411: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14427: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14414: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14430: \$? = $ac_status" >&5
+  echo "$as_me:14417: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_res_query="none required"
 else
@@ -14439,7 +14426,7 @@
   for ac_lib in resolv; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 14442 "configure"
+#line 14429 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14458,16 +14445,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14461: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14448: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14464: \$? = $ac_status" >&5
+  echo "$as_me:14451: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14467: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14454: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14470: \$? = $ac_status" >&5
+  echo "$as_me:14457: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_res_query="-l$ac_lib"
 break
@@ -14480,14 +14467,14 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:14483: result: $ac_cv_search_res_query" >&5
+echo "$as_me:14470: result: $ac_cv_search_res_query" >&5
 echo "${ECHO_T}$ac_cv_search_res_query" >&6
 if test "$ac_cv_search_res_query" != no; then
   test "$ac_cv_search_res_query" = "none required" || LIBS="$ac_cv_search_res_query $LIBS"
 
 fi
 
-					echo "$as_me:14490: checking for library containing dn_expand" >&5
+					echo "$as_me:14477: checking for library containing dn_expand" >&5
 echo $ECHO_N "checking for library containing dn_expand... $ECHO_C" >&6
 if test "${ac_cv_search_dn_expand+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14495,7 +14482,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_dn_expand=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 14498 "configure"
+#line 14485 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14514,16 +14501,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14517: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14504: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14520: \$? = $ac_status" >&5
+  echo "$as_me:14507: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14523: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14510: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14526: \$? = $ac_status" >&5
+  echo "$as_me:14513: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_dn_expand="none required"
 else
@@ -14535,7 +14522,7 @@
   for ac_lib in resolv; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 14538 "configure"
+#line 14525 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14554,16 +14541,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14557: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14544: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14560: \$? = $ac_status" >&5
+  echo "$as_me:14547: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14563: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14550: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14566: \$? = $ac_status" >&5
+  echo "$as_me:14553: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_dn_expand="-l$ac_lib"
 break
@@ -14576,7 +14563,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:14579: result: $ac_cv_search_dn_expand" >&5
+echo "$as_me:14566: result: $ac_cv_search_dn_expand" >&5
 echo "${ECHO_T}$ac_cv_search_dn_expand" >&6
 if test "$ac_cv_search_dn_expand" != no; then
   test "$ac_cv_search_dn_expand" = "none required" || LIBS="$ac_cv_search_dn_expand $LIBS"
@@ -14586,13 +14573,13 @@
 for ac_func in _getshort _getlong
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:14589: checking for $ac_func" >&5
+echo "$as_me:14576: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14595 "configure"
+#line 14582 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -14623,16 +14610,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14626: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14613: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14629: \$? = $ac_status" >&5
+  echo "$as_me:14616: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14632: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14619: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14635: \$? = $ac_status" >&5
+  echo "$as_me:14622: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -14642,7 +14629,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:14645: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:14632: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -14652,13 +14639,13 @@
 fi
 done
 
-					echo "$as_me:14655: checking for HEADER.ad" >&5
+					echo "$as_me:14642: checking for HEADER.ad" >&5
 echo $ECHO_N "checking for HEADER.ad... $ECHO_C" >&6
 if test "${ac_cv_member_HEADER_ad+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14661 "configure"
+#line 14648 "configure"
 #include "confdefs.h"
 #include <arpa/nameser.h>
 
@@ -14673,16 +14660,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:14676: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:14663: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14679: \$? = $ac_status" >&5
+  echo "$as_me:14666: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:14682: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14669: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14685: \$? = $ac_status" >&5
+  echo "$as_me:14672: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_member_HEADER_ad=yes
 else
@@ -14692,7 +14679,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:14695: result: $ac_cv_member_HEADER_ad" >&5
+echo "$as_me:14682: result: $ac_cv_member_HEADER_ad" >&5
 echo "${ECHO_T}$ac_cv_member_HEADER_ad" >&6
 if test $ac_cv_member_HEADER_ad = yes; then
   cat >>confdefs.h <<\EOF
@@ -14727,10 +14714,10 @@
 EOF
 
 			KRB5_MSG="yes"
-                        echo "$as_me:14730: checking whether we are using Heimdal" >&5
+                        echo "$as_me:14717: checking whether we are using Heimdal" >&5
 echo $ECHO_N "checking whether we are using Heimdal... $ECHO_C" >&6
                         cat >conftest.$ac_ext <<_ACEOF
-#line 14733 "configure"
+#line 14720 "configure"
 #include "confdefs.h"
  #include <krb5.h>
 int
@@ -14742,18 +14729,18 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:14745: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:14732: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14748: \$? = $ac_status" >&5
+  echo "$as_me:14735: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:14751: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14738: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14754: \$? = $ac_status" >&5
+  echo "$as_me:14741: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:14756: result: yes" >&5
+   echo "$as_me:14743: result: yes" >&5
 echo "${ECHO_T}yes" >&6
                                          cat >>confdefs.h <<\EOF
 #define HEIMDAL 1
@@ -14764,7 +14751,7 @@
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:14767: result: no" >&5
+ echo "$as_me:14754: result: no" >&5
 echo "${ECHO_T}no" >&6
                                          K5LIBS="-lkrb5 -lk5crypto -lcom_err"
 
@@ -14776,7 +14763,7 @@
                         if test ! -z "$blibpath" ; then
                                 blibpath="$blibpath:${KRB5ROOT}/lib"
                         fi
-			echo "$as_me:14779: checking for library containing dn_expand" >&5
+			echo "$as_me:14766: checking for library containing dn_expand" >&5
 echo $ECHO_N "checking for library containing dn_expand... $ECHO_C" >&6
 if test "${ac_cv_search_dn_expand+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14784,7 +14771,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_dn_expand=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 14787 "configure"
+#line 14774 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14803,16 +14790,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14806: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14793: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14809: \$? = $ac_status" >&5
+  echo "$as_me:14796: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14812: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14799: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14815: \$? = $ac_status" >&5
+  echo "$as_me:14802: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_dn_expand="none required"
 else
@@ -14824,7 +14811,7 @@
   for ac_lib in resolv; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 14827 "configure"
+#line 14814 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14843,16 +14830,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14846: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14833: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14849: \$? = $ac_status" >&5
+  echo "$as_me:14836: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14852: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14839: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14855: \$? = $ac_status" >&5
+  echo "$as_me:14842: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_dn_expand="-l$ac_lib"
 break
@@ -14865,14 +14852,14 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:14868: result: $ac_cv_search_dn_expand" >&5
+echo "$as_me:14855: result: $ac_cv_search_dn_expand" >&5
 echo "${ECHO_T}$ac_cv_search_dn_expand" >&6
 if test "$ac_cv_search_dn_expand" != no; then
   test "$ac_cv_search_dn_expand" = "none required" || LIBS="$ac_cv_search_dn_expand $LIBS"
 
 fi
 
-			echo "$as_me:14875: checking for gss_init_sec_context in -lgssapi" >&5
+			echo "$as_me:14862: checking for gss_init_sec_context in -lgssapi" >&5
 echo $ECHO_N "checking for gss_init_sec_context in -lgssapi... $ECHO_C" >&6
 if test "${ac_cv_lib_gssapi_gss_init_sec_context+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14880,7 +14867,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgssapi $K5LIBS $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 14883 "configure"
+#line 14870 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14899,16 +14886,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14902: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14889: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14905: \$? = $ac_status" >&5
+  echo "$as_me:14892: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14908: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14895: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14911: \$? = $ac_status" >&5
+  echo "$as_me:14898: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gssapi_gss_init_sec_context=yes
 else
@@ -14919,7 +14906,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:14922: result: $ac_cv_lib_gssapi_gss_init_sec_context" >&5
+echo "$as_me:14909: result: $ac_cv_lib_gssapi_gss_init_sec_context" >&5
 echo "${ECHO_T}$ac_cv_lib_gssapi_gss_init_sec_context" >&6
 if test $ac_cv_lib_gssapi_gss_init_sec_context = yes; then
    cat >>confdefs.h <<\EOF
@@ -14928,7 +14915,7 @@
 
 				  K5LIBS="-lgssapi $K5LIBS"
 else
-   echo "$as_me:14931: checking for gss_init_sec_context in -lgssapi_krb5" >&5
+   echo "$as_me:14918: checking for gss_init_sec_context in -lgssapi_krb5" >&5
 echo $ECHO_N "checking for gss_init_sec_context in -lgssapi_krb5... $ECHO_C" >&6
 if test "${ac_cv_lib_gssapi_krb5_gss_init_sec_context+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14936,7 +14923,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgssapi_krb5 $K5LIBS $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 14939 "configure"
+#line 14926 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14955,16 +14942,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14958: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14945: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14961: \$? = $ac_status" >&5
+  echo "$as_me:14948: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14964: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14951: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14967: \$? = $ac_status" >&5
+  echo "$as_me:14954: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gssapi_krb5_gss_init_sec_context=yes
 else
@@ -14975,7 +14962,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:14978: result: $ac_cv_lib_gssapi_krb5_gss_init_sec_context" >&5
+echo "$as_me:14965: result: $ac_cv_lib_gssapi_krb5_gss_init_sec_context" >&5
 echo "${ECHO_T}$ac_cv_lib_gssapi_krb5_gss_init_sec_context" >&6
 if test $ac_cv_lib_gssapi_krb5_gss_init_sec_context = yes; then
    cat >>confdefs.h <<\EOF
@@ -14984,29 +14971,29 @@
 
 				  	  K5LIBS="-lgssapi_krb5 $K5LIBS"
 else
-  { echo "$as_me:14987: WARNING: Cannot find any suitable gss-api library - build may fail" >&5
+  { echo "$as_me:14974: WARNING: Cannot find any suitable gss-api library - build may fail" >&5
 echo "$as_me: WARNING: Cannot find any suitable gss-api library - build may fail" >&2;}
 fi
 
 fi
 
-			echo "$as_me:14993: checking for gssapi.h" >&5
+			echo "$as_me:14980: checking for gssapi.h" >&5
 echo $ECHO_N "checking for gssapi.h... $ECHO_C" >&6
 if test "${ac_cv_header_gssapi_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14999 "configure"
+#line 14986 "configure"
 #include "confdefs.h"
 #include <gssapi.h>
 _ACEOF
-if { (eval echo "$as_me:15003: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:14990: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:15009: \$? = $ac_status" >&5
+  echo "$as_me:14996: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -15025,7 +15012,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:15028: result: $ac_cv_header_gssapi_h" >&5
+echo "$as_me:15015: result: $ac_cv_header_gssapi_h" >&5
 echo "${ECHO_T}$ac_cv_header_gssapi_h" >&6
 if test $ac_cv_header_gssapi_h = yes; then
   :
@@ -15036,23 +15023,23 @@
 for ac_header in gssapi.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:15039: checking for $ac_header" >&5
+echo "$as_me:15026: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15045 "configure"
+#line 15032 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:15049: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:15036: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:15055: \$? = $ac_status" >&5
+  echo "$as_me:15042: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -15071,7 +15058,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:15074: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:15061: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -15079,7 +15066,7 @@
 EOF
 
 else
-  { echo "$as_me:15082: WARNING: Cannot find any suitable gss-api header - build may fail" >&5
+  { echo "$as_me:15069: WARNING: Cannot find any suitable gss-api header - build may fail" >&5
 echo "$as_me: WARNING: Cannot find any suitable gss-api header - build may fail" >&2;}
 
 fi
@@ -15089,23 +15076,23 @@
 
 			oldCPP="$CPPFLAGS"
 			CPPFLAGS="$CPPFLAGS -I${KRB5ROOT}/include/gssapi"
-			echo "$as_me:15092: checking for gssapi_krb5.h" >&5
+			echo "$as_me:15079: checking for gssapi_krb5.h" >&5
 echo $ECHO_N "checking for gssapi_krb5.h... $ECHO_C" >&6
 if test "${ac_cv_header_gssapi_krb5_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15098 "configure"
+#line 15085 "configure"
 #include "confdefs.h"
 #include <gssapi_krb5.h>
 _ACEOF
-if { (eval echo "$as_me:15102: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:15089: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:15108: \$? = $ac_status" >&5
+  echo "$as_me:15095: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -15124,7 +15111,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:15127: result: $ac_cv_header_gssapi_krb5_h" >&5
+echo "$as_me:15114: result: $ac_cv_header_gssapi_krb5_h" >&5
 echo "${ECHO_T}$ac_cv_header_gssapi_krb5_h" >&6
 if test $ac_cv_header_gssapi_krb5_h = yes; then
   :
@@ -15169,7 +15156,7 @@
 		TestPath="${TestPath}${PATH_SEPARATOR}/usr/openwin/bin"
 		# Extract the first word of "xauth", so it can be a program name with args.
 set dummy xauth; ac_word=$2
-echo "$as_me:15172: checking for $ac_word" >&5
+echo "$as_me:15159: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_xauth_path+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -15186,7 +15173,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_xauth_path="$ac_dir/$ac_word"
-   echo "$as_me:15189: found $ac_dir/$ac_word" >&5
+   echo "$as_me:15176: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -15197,10 +15184,10 @@
 xauth_path=$ac_cv_path_xauth_path
 
 if test -n "$xauth_path"; then
-  echo "$as_me:15200: result: $xauth_path" >&5
+  echo "$as_me:15187: result: $xauth_path" >&5
 echo "${ECHO_T}$xauth_path" >&6
 else
-  echo "$as_me:15203: result: no" >&5
+  echo "$as_me:15190: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -15244,13 +15231,13 @@
 
 if test -z "$no_dev_ptmx" ; then
 	if test "x$disable_ptmx_check" != "xyes" ; then
-		echo "$as_me:15247: checking for \"/dev/ptmx\"" >&5
+		echo "$as_me:15234: checking for \"/dev/ptmx\"" >&5
 echo $ECHO_N "checking for \"/dev/ptmx\"... $ECHO_C" >&6
 if test "${ac_cv_file___dev_ptmx_+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   test "$cross_compiling" = yes &&
-  { { echo "$as_me:15253: error: cannot check for file existence when cross compiling" >&5
+  { { echo "$as_me:15240: error: cannot check for file existence when cross compiling" >&5
 echo "$as_me: error: cannot check for file existence when cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 if test -r ""/dev/ptmx""; then
@@ -15259,7 +15246,7 @@
   ac_cv_file___dev_ptmx_=no
 fi
 fi
-echo "$as_me:15262: result: $ac_cv_file___dev_ptmx_" >&5
+echo "$as_me:15249: result: $ac_cv_file___dev_ptmx_" >&5
 echo "${ECHO_T}$ac_cv_file___dev_ptmx_" >&6
 if test $ac_cv_file___dev_ptmx_ = yes; then
 
@@ -15273,13 +15260,13 @@
 
 	fi
 fi
-echo "$as_me:15276: checking for \"/dev/ptc\"" >&5
+echo "$as_me:15263: checking for \"/dev/ptc\"" >&5
 echo $ECHO_N "checking for \"/dev/ptc\"... $ECHO_C" >&6
 if test "${ac_cv_file___dev_ptc_+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   test "$cross_compiling" = yes &&
-  { { echo "$as_me:15282: error: cannot check for file existence when cross compiling" >&5
+  { { echo "$as_me:15269: error: cannot check for file existence when cross compiling" >&5
 echo "$as_me: error: cannot check for file existence when cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 if test -r ""/dev/ptc""; then
@@ -15288,7 +15275,7 @@
   ac_cv_file___dev_ptc_=no
 fi
 fi
-echo "$as_me:15291: result: $ac_cv_file___dev_ptc_" >&5
+echo "$as_me:15278: result: $ac_cv_file___dev_ptc_" >&5
 echo "${ECHO_T}$ac_cv_file___dev_ptc_" >&6
 if test $ac_cv_file___dev_ptc_ = yes; then
 
@@ -15311,7 +15298,7 @@
 			MANTYPE=$withval
 			;;
 		*)
-			{ { echo "$as_me:15314: error: invalid man type: $withval" >&5
+			{ { echo "$as_me:15301: error: invalid man type: $withval" >&5
 echo "$as_me: error: invalid man type: $withval" >&2;}
    { (exit 1); exit 1; }; }
 			;;
@@ -15324,7 +15311,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:15327: checking for $ac_word" >&5
+echo "$as_me:15314: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_NROFF+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -15341,7 +15328,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_NROFF="$ac_dir/$ac_word"
-   echo "$as_me:15344: found $ac_dir/$ac_word" >&5
+   echo "$as_me:15331: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -15352,10 +15339,10 @@
 NROFF=$ac_cv_path_NROFF
 
 if test -n "$NROFF"; then
-  echo "$as_me:15355: result: $NROFF" >&5
+  echo "$as_me:15342: result: $NROFF" >&5
 echo "${ECHO_T}$NROFF" >&6
 else
-  echo "$as_me:15358: result: no" >&5
+  echo "$as_me:15345: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -15412,10 +15399,10 @@
 fi;
 
 if test -z "$disable_shadow" ; then
-	echo "$as_me:15415: checking if the systems has expire shadow information" >&5
+	echo "$as_me:15402: checking if the systems has expire shadow information" >&5
 echo $ECHO_N "checking if the systems has expire shadow information... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 15418 "configure"
+#line 15405 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -15431,16 +15418,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:15434: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:15421: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:15437: \$? = $ac_status" >&5
+  echo "$as_me:15424: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:15440: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15427: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15443: \$? = $ac_status" >&5
+  echo "$as_me:15430: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    sp_expire_available=yes
 else
@@ -15451,14 +15438,14 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 	if test "x$sp_expire_available" = "xyes" ; then
-		echo "$as_me:15454: result: yes" >&5
+		echo "$as_me:15441: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 		cat >>confdefs.h <<\EOF
 #define HAS_SHADOW_EXPIRE 1
 EOF
 
 	else
-		echo "$as_me:15461: result: no" >&5
+		echo "$as_me:15448: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 fi
@@ -15495,13 +15482,13 @@
 
 else
 
-echo "$as_me:15498: checking for \"/etc/default/login\"" >&5
+echo "$as_me:15485: checking for \"/etc/default/login\"" >&5
 echo $ECHO_N "checking for \"/etc/default/login\"... $ECHO_C" >&6
 if test "${ac_cv_file___etc_default_login_+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   test "$cross_compiling" = yes &&
-  { { echo "$as_me:15504: error: cannot check for file existence when cross compiling" >&5
+  { { echo "$as_me:15491: error: cannot check for file existence when cross compiling" >&5
 echo "$as_me: error: cannot check for file existence when cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 if test -r ""/etc/default/login""; then
@@ -15510,7 +15497,7 @@
   ac_cv_file___etc_default_login_=no
 fi
 fi
-echo "$as_me:15513: result: $ac_cv_file___etc_default_login_" >&5
+echo "$as_me:15500: result: $ac_cv_file___etc_default_login_" >&5
 echo "${ECHO_T}$ac_cv_file___etc_default_login_" >&6
 if test $ac_cv_file___etc_default_login_ = yes; then
    external_path_file=/etc/default/login
@@ -15538,7 +15525,7 @@
   withval="$with_default_path"
 
 		if test "x$external_path_file" = "x/etc/login.conf" ; then
-			{ echo "$as_me:15541: WARNING:
+			{ echo "$as_me:15528: WARNING:
 --with-default-path=PATH has no effect on this system.
 Edit /etc/login.conf instead." >&5
 echo "$as_me: WARNING:
@@ -15546,7 +15533,7 @@
 Edit /etc/login.conf instead." >&2;}
 		elif test "x$withval" != "xno" ; then
 			if test ! -z "$external_path_file" ; then
-				{ echo "$as_me:15549: WARNING:
+				{ echo "$as_me:15536: WARNING:
 --with-default-path=PATH will only be used if PATH is not defined in
 $external_path_file ." >&5
 echo "$as_me: WARNING:
@@ -15559,11 +15546,11 @@
 
 else
    if test "x$external_path_file" = "x/etc/login.conf" ; then
-		{ echo "$as_me:15562: WARNING: Make sure the path to scp is in /etc/login.conf" >&5
+		{ echo "$as_me:15549: WARNING: Make sure the path to scp is in /etc/login.conf" >&5
 echo "$as_me: WARNING: Make sure the path to scp is in /etc/login.conf" >&2;}
 	else
 		if test ! -z "$external_path_file" ; then
-			{ echo "$as_me:15566: WARNING:
+			{ echo "$as_me:15553: WARNING:
 If PATH is defined in $external_path_file, ensure the path to scp is included,
 otherwise scp will not work." >&5
 echo "$as_me: WARNING:
@@ -15575,7 +15562,7 @@
 
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15578 "configure"
+#line 15565 "configure"
 #include "confdefs.h"
 
 /* find out what STDPATH is */
@@ -15612,15 +15599,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:15615: \"$ac_link\"") >&5
+if { (eval echo "$as_me:15602: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:15618: \$? = $ac_status" >&5
+  echo "$as_me:15605: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:15620: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15607: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15623: \$? = $ac_status" >&5
+  echo "$as_me:15610: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    user_path=`cat conftest.stdpath`
 else
@@ -15644,7 +15631,7 @@
 			echo $user_path | grep "^$t_bindir"  > /dev/null 2>&1
 			if test $? -ne 0  ; then
 				user_path=$user_path:$t_bindir
-				echo "$as_me:15647: result: Adding $t_bindir to USER_PATH so scp will work" >&5
+				echo "$as_me:15634: result: Adding $t_bindir to USER_PATH so scp will work" >&5
 echo "${ECHO_T}Adding $t_bindir to USER_PATH so scp will work" >&6
 			fi
 		fi
@@ -15674,7 +15661,7 @@
 
 fi;
 
-echo "$as_me:15677: checking if we need to convert IPv4 in IPv6-mapped addresses" >&5
+echo "$as_me:15664: checking if we need to convert IPv4 in IPv6-mapped addresses" >&5
 echo $ECHO_N "checking if we need to convert IPv4 in IPv6-mapped addresses... $ECHO_C" >&6
 IPV4_IN6_HACK_MSG="no"
 
@@ -15683,7 +15670,7 @@
   withval="$with_4in6"
 
 		if test "x$withval" != "xno" ; then
-			echo "$as_me:15686: result: yes" >&5
+			echo "$as_me:15673: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 			cat >>confdefs.h <<\EOF
 #define IPV4_IN_IPV6 1
@@ -15691,14 +15678,14 @@
 
 			IPV4_IN6_HACK_MSG="yes"
 		else
-			echo "$as_me:15694: result: no" >&5
+			echo "$as_me:15681: result: no" >&5
 echo "${ECHO_T}no" >&6
 		fi
 
 else
 
 		if test "x$inet6_default_4in6" = "xyes"; then
-			echo "$as_me:15701: result: yes (default)" >&5
+			echo "$as_me:15688: result: yes (default)" >&5
 echo "${ECHO_T}yes (default)" >&6
 			cat >>confdefs.h <<\EOF
 #define IPV4_IN_IPV6 1
@@ -15706,7 +15693,7 @@
 
 			IPV4_IN6_HACK_MSG="yes"
 		else
-			echo "$as_me:15709: result: no (default)" >&5
+			echo "$as_me:15696: result: no (default)" >&5
 echo "${ECHO_T}no (default)" >&6
 		fi
 
@@ -15746,7 +15733,7 @@
 		if test "x$withval" != "xno" ; then
 			piddir=$withval
 			if test ! -d $piddir ; then
-			{ echo "$as_me:15749: WARNING: ** no $piddir directory on this system **" >&5
+			{ echo "$as_me:15736: WARNING: ** no $piddir directory on this system **" >&5
 echo "$as_me: WARNING: ** no $piddir directory on this system **" >&2;}
 			fi
 		fi
@@ -15869,10 +15856,10 @@
 
 fi;
 
-echo "$as_me:15872: checking if your system defines LASTLOG_FILE" >&5
+echo "$as_me:15859: checking if your system defines LASTLOG_FILE" >&5
 echo $ECHO_N "checking if your system defines LASTLOG_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 15875 "configure"
+#line 15862 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -15896,29 +15883,29 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:15899: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:15886: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:15902: \$? = $ac_status" >&5
+  echo "$as_me:15889: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:15905: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15892: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15908: \$? = $ac_status" >&5
+  echo "$as_me:15895: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:15910: result: yes" >&5
+   echo "$as_me:15897: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:15916: result: no" >&5
+		echo "$as_me:15903: result: no" >&5
 echo "${ECHO_T}no" >&6
-		echo "$as_me:15918: checking if your system defines _PATH_LASTLOG" >&5
+		echo "$as_me:15905: checking if your system defines _PATH_LASTLOG" >&5
 echo $ECHO_N "checking if your system defines _PATH_LASTLOG... $ECHO_C" >&6
 		cat >conftest.$ac_ext <<_ACEOF
-#line 15921 "configure"
+#line 15908 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -15939,24 +15926,24 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:15942: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:15929: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:15945: \$? = $ac_status" >&5
+  echo "$as_me:15932: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:15948: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15935: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15951: \$? = $ac_status" >&5
+  echo "$as_me:15938: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:15953: result: yes" >&5
+   echo "$as_me:15940: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-			echo "$as_me:15959: result: no" >&5
+			echo "$as_me:15946: result: no" >&5
 echo "${ECHO_T}no" >&6
 			system_lastlog_path=no
 
@@ -15974,7 +15961,7 @@
 				fi
 		done
 		if test -z "$conf_lastlog_location"; then
-			{ echo "$as_me:15977: WARNING: ** Cannot find lastlog **" >&5
+			{ echo "$as_me:15964: WARNING: ** Cannot find lastlog **" >&5
 echo "$as_me: WARNING: ** Cannot find lastlog **" >&2;}
 					fi
 	fi
@@ -15987,10 +15974,10 @@
 
 fi
 
-echo "$as_me:15990: checking if your system defines UTMP_FILE" >&5
+echo "$as_me:15977: checking if your system defines UTMP_FILE" >&5
 echo $ECHO_N "checking if your system defines UTMP_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 15993 "configure"
+#line 15980 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -16008,23 +15995,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16011: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:15998: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16014: \$? = $ac_status" >&5
+  echo "$as_me:16001: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16017: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16004: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16020: \$? = $ac_status" >&5
+  echo "$as_me:16007: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:16022: result: yes" >&5
+   echo "$as_me:16009: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:16027: result: no" >&5
+ echo "$as_me:16014: result: no" >&5
 echo "${ECHO_T}no" >&6
 	  system_utmp_path=no
 
@@ -16052,10 +16039,10 @@
 
 fi
 
-echo "$as_me:16055: checking if your system defines WTMP_FILE" >&5
+echo "$as_me:16042: checking if your system defines WTMP_FILE" >&5
 echo $ECHO_N "checking if your system defines WTMP_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 16058 "configure"
+#line 16045 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -16073,23 +16060,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16076: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16063: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16079: \$? = $ac_status" >&5
+  echo "$as_me:16066: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16082: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16069: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16085: \$? = $ac_status" >&5
+  echo "$as_me:16072: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:16087: result: yes" >&5
+   echo "$as_me:16074: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:16092: result: no" >&5
+ echo "$as_me:16079: result: no" >&5
 echo "${ECHO_T}no" >&6
 	  system_wtmp_path=no
 
@@ -16117,10 +16104,10 @@
 
 fi
 
-echo "$as_me:16120: checking if your system defines UTMPX_FILE" >&5
+echo "$as_me:16107: checking if your system defines UTMPX_FILE" >&5
 echo $ECHO_N "checking if your system defines UTMPX_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 16123 "configure"
+#line 16110 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -16141,23 +16128,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16144: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16131: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16147: \$? = $ac_status" >&5
+  echo "$as_me:16134: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16150: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16137: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16153: \$? = $ac_status" >&5
+  echo "$as_me:16140: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:16155: result: yes" >&5
+   echo "$as_me:16142: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:16160: result: no" >&5
+ echo "$as_me:16147: result: no" >&5
 echo "${ECHO_T}no" >&6
 	  system_utmpx_path=no
 
@@ -16177,10 +16164,10 @@
 
 fi
 
-echo "$as_me:16180: checking if your system defines WTMPX_FILE" >&5
+echo "$as_me:16167: checking if your system defines WTMPX_FILE" >&5
 echo $ECHO_N "checking if your system defines WTMPX_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 16183 "configure"
+#line 16170 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -16201,23 +16188,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16204: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16191: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16207: \$? = $ac_status" >&5
+  echo "$as_me:16194: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16210: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16197: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16213: \$? = $ac_status" >&5
+  echo "$as_me:16200: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:16215: result: yes" >&5
+   echo "$as_me:16202: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:16220: result: no" >&5
+ echo "$as_me:16207: result: no" >&5
 echo "${ECHO_T}no" >&6
 	  system_wtmpx_path=no
 
@@ -16239,7 +16226,7 @@
 
 if test ! -z "$blibpath" ; then
 	LDFLAGS="$LDFLAGS $blibflags$blibpath"
-	{ echo "$as_me:16242: WARNING: Please check and edit blibpath in LDFLAGS in Makefile" >&5
+	{ echo "$as_me:16229: WARNING: Please check and edit blibpath in LDFLAGS in Makefile" >&5
 echo "$as_me: WARNING: Please check and edit blibpath in LDFLAGS in Makefile" >&2;}
 fi
 
@@ -16331,7 +16318,7 @@
 : ${CONFIG_STATUS=./config.status}
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
-{ echo "$as_me:16334: creating $CONFIG_STATUS" >&5
+{ echo "$as_me:16321: creating $CONFIG_STATUS" >&5
 echo "$as_me: creating $CONFIG_STATUS" >&6;}
 cat >$CONFIG_STATUS <<_ACEOF
 #! $SHELL
@@ -16504,7 +16491,7 @@
     echo "$ac_cs_version"; exit 0 ;;
   --he | --h)
     # Conflict between --help and --header
-    { { echo "$as_me:16507: error: ambiguous option: $1
+    { { echo "$as_me:16494: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -16523,7 +16510,7 @@
     ac_need_defaults=false;;
 
   # This is an error.
-  -*) { { echo "$as_me:16526: error: unrecognized option: $1
+  -*) { { echo "$as_me:16513: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -16563,7 +16550,7 @@
   "scard/Makefile" ) CONFIG_FILES="$CONFIG_FILES scard/Makefile" ;;
   "ssh_prng_cmds" ) CONFIG_FILES="$CONFIG_FILES ssh_prng_cmds" ;;
   "config.h" ) CONFIG_HEADERS="$CONFIG_HEADERS config.h" ;;
-  *) { { echo "$as_me:16566: error: invalid argument: $ac_config_target" >&5
+  *) { { echo "$as_me:16553: error: invalid argument: $ac_config_target" >&5
 echo "$as_me: error: invalid argument: $ac_config_target" >&2;}
    { (exit 1); exit 1; }; };;
   esac
@@ -16819,7 +16806,7 @@
   esac
 
   if test x"$ac_file" != x-; then
-    { echo "$as_me:16822: creating $ac_file" >&5
+    { echo "$as_me:16809: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
     rm -f "$ac_file"
   fi
@@ -16837,7 +16824,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:16840: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:16827: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -16850,7 +16837,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:16853: error: cannot find input file: $f" >&5
+           { { echo "$as_me:16840: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -16911,7 +16898,7 @@
   * )   ac_file_in=$ac_file.in ;;
   esac
 
-  test x"$ac_file" != x- && { echo "$as_me:16914: creating $ac_file" >&5
+  test x"$ac_file" != x- && { echo "$as_me:16901: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
 
   # First look for the input files in the build tree, otherwise in the
@@ -16922,7 +16909,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:16925: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:16912: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -16935,7 +16922,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:16938: error: cannot find input file: $f" >&5
+           { { echo "$as_me:16925: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -17052,7 +17039,7 @@
   rm -f $tmp/in
   if test x"$ac_file" != x-; then
     if cmp -s $ac_file $tmp/config.h 2>/dev/null; then
-      { echo "$as_me:17055: $ac_file is unchanged" >&5
+      { echo "$as_me:17042: $ac_file is unchanged" >&5
 echo "$as_me: $ac_file is unchanged" >&6;}
     else
       ac_dir=`$as_expr X"$ac_file" : 'X\(.*[^/]\)//*[^/][^/]*/*$' \| \
diff -ru openssh-3.7.1p2.orig/configure.ac openssh-3.7.1p2/configure.ac
--- openssh-3.7.1p2.orig/configure.ac	2003-09-23 19:24:21.000000000 +1000
+++ openssh-3.7.1p2/configure.ac	2003-10-06 16:13:14.000000000 +1000
@@ -146,7 +146,6 @@
 	AC_DEFINE(USE_PIPES)
 	AC_DEFINE(LOGIN_NO_ENDOPT)
 	AC_DEFINE(LOGIN_NEEDS_UTMPX)
-	AC_DEFINE(DISABLE_SHADOW)
 	AC_DEFINE(DISABLE_UTMP)
 	AC_DEFINE(LOCKED_PASSWD_STRING, "*")
 	AC_DEFINE(SPT_TYPE,SPT_PSTAT)
@@ -163,7 +162,6 @@
 	AC_DEFINE(USE_PIPES)
 	AC_DEFINE(LOGIN_NO_ENDOPT)
 	AC_DEFINE(LOGIN_NEEDS_UTMPX)
-	AC_DEFINE(DISABLE_SHADOW)
 	AC_DEFINE(DISABLE_UTMP)
 	AC_DEFINE(LOCKED_PASSWD_STRING, "*")
 	AC_DEFINE(SPT_TYPE,SPT_PSTAT)
@@ -177,7 +175,6 @@
 	AC_DEFINE(USE_PIPES)
 	AC_DEFINE(LOGIN_NO_ENDOPT)
 	AC_DEFINE(LOGIN_NEEDS_UTMPX)
-	AC_DEFINE(DISABLE_SHADOW)
 	AC_DEFINE(DISABLE_UTMP)
 	AC_DEFINE(LOCKED_PASSWD_STRING, "*")
 	AC_DEFINE(SPT_TYPE,SPT_PSTAT)
@@ -897,7 +894,6 @@
 			AC_CHECK_FUNCS(pam_getenvlist)
 			AC_CHECK_FUNCS(pam_putenv)
 
-			disable_shadow=yes
 			PAM_MSG="yes"
 
 			AC_DEFINE(USE_PAM)
diff -ru openssh-3.7.1p2.orig/openbsd-compat/xcrypt.c openssh-3.7.1p2/openbsd-compat/xcrypt.c
--- openssh-3.7.1p2.orig/openbsd-compat/xcrypt.c	2003-09-07 09:43:42.000000000 +1000
+++ openssh-3.7.1p2/openbsd-compat/xcrypt.c	2003-10-06 16:13:14.000000000 +1000
@@ -104,10 +104,6 @@
 
 	if (spw != NULL)
 		pw_password = spw->ufld.fd_encrypt;
-# elif defined(__hpux) && !defined(HAVE_SECUREWARE)
-	struct pr_passwd *spw;
-        if (iscomsec() && (spw = getprpwnam(pw->pw_name)) != NULL)
-                pw_password = spw->ufld.fd_encrypt;
 # endif
 
 	return pw_password;
diff -ru openssh-3.7.1p2.orig/scp.0 openssh-3.7.1p2/scp.0
--- openssh-3.7.1p2.orig/scp.0	2003-09-23 19:55:16.000000000 +1000
+++ openssh-3.7.1p2/scp.0	2003-10-06 16:13:21.000000000 +1000
@@ -1,4 +1,4 @@
-SCP(1)                     OpenBSD Reference Manual                     SCP(1)
+SCP(1)                  System General Commands Manual                  SCP(1)
 
 NAME
      scp - secure copy (remote file copy program)
@@ -41,8 +41,8 @@
              about their progress.  This is helpful in debugging connection,
              authentication, and configuration problems.
 
-     -B      Selects batch mode (prevents asking for passwords or passphras-
-             es).
+     -B      Selects batch mode (prevents asking for passwords or
+             passphrases).
 
      -q      Disables the progress meter.
 
@@ -91,4 +91,4 @@
      Timo Rinne <tri@iki.fi> and
      Tatu Ylonen <ylo@cs.hut.fi>
 
-OpenBSD 3.4                   September 25, 1999                             2
+BSD                           September 25, 1999                           BSD
diff -ru openssh-3.7.1p2.orig/sftp-server.0 openssh-3.7.1p2/sftp-server.0
--- openssh-3.7.1p2.orig/sftp-server.0	2003-09-23 19:55:18.000000000 +1000
+++ openssh-3.7.1p2/sftp-server.0	2003-10-06 16:13:24.000000000 +1000
@@ -1,4 +1,4 @@
-SFTP-SERVER(8)          OpenBSD System Manager's Manual         SFTP-SERVER(8)
+SFTP-SERVER(8)              System Manager's Manual             SFTP-SERVER(8)
 
 NAME
      sftp-server - SFTP server subsystem
@@ -8,14 +8,14 @@
 
 DESCRIPTION
      sftp-server is a program that speaks the server side of SFTP protocol to
-     stdout and expects client requests from stdin.  sftp-server is not in-
-     tended to be called directly, but from sshd(8) using the Subsystem op-
-     tion.  See sshd(8) for more information.
+     stdout and expects client requests from stdin.  sftp-server is not
+     intended to be called directly, but from sshd(8) using the Subsystem
+     option.  See sshd(8) for more information.
 
 SEE ALSO
      sftp(1), ssh(1), sshd(8)
 
-     T. Ylonen, and S. Lehtinen, SSH File Transfer Protocol, draft-ietf-secsh-
+     T. Ylonen and S. Lehtinen, SSH File Transfer Protocol, draft-ietf-secsh-
      filexfer-00.txt, January 2001, work in progress material.
 
 AUTHORS
@@ -24,4 +24,4 @@
 HISTORY
      sftp-server first appeared in OpenBSD 2.8 .
 
-OpenBSD 3.4                     August 30, 2000                              1
+BSD                             August 30, 2000                            BSD
diff -ru openssh-3.7.1p2.orig/sftp.0 openssh-3.7.1p2/sftp.0
--- openssh-3.7.1p2.orig/sftp.0	2003-09-23 19:55:18.000000000 +1000
+++ openssh-3.7.1p2/sftp.0	2003-10-06 16:13:24.000000000 +1000
@@ -1,4 +1,4 @@
-SFTP(1)                    OpenBSD Reference Manual                    SFTP(1)
+SFTP(1)                 System General Commands Manual                 SFTP(1)
 
 NAME
      sftp - secure file transfer program
@@ -15,8 +15,8 @@
      sftp is an interactive file transfer program, similar to ftp(1), which
      performs all operations over an encrypted ssh(1) transport.  It may also
      use many features of ssh, such as public key authentication and compres-
-     sion.  sftp connects and logs into the specified host, then enters an in-
-     teractive command mode.
+     sion.  sftp connects and logs into the specified host, then enters an
+     interactive command mode.
 
      The second usage format will retrieve files automatically if a non-inter-
      active authentication method is used; otherwise it will do so after suc-
@@ -31,8 +31,8 @@
      sshd(8) and ssh-keygen(1) for details).  The options are as follows:
 
      -b batchfile
-             Batch mode reads a series of commands from an input batchfile in-
-             stead of stdin.  Since it lacks user interaction it should be
+             Batch mode reads a series of commands from an input batchfile
+             instead of stdin.  Since it lacks user interaction it should be
              used in conjunction with non-interactive authentication.  sftp
              will abort if any of the following commands fail: get, put,
              rename, ln, rm, mkdir, chdir, ls, lchdir, chmod, chown, chgrp,
@@ -82,8 +82,8 @@
 
 INTERACTIVE COMMANDS
      Once in interactive mode, sftp understands a set of commands similar to
-     those of ftp(1).  Commands are case insensitive and pathnames may be en-
-     closed in quotes if they contain spaces.
+     those of ftp(1).  Commands are case insensitive and pathnames may be
+     enclosed in quotes if they contain spaces.
 
      bye     Quit sftp.
 
@@ -140,9 +140,9 @@
              Toggle display of progress meter.
 
      put [flags] local-path [remote-path]
-             Upload local-path and store it on the remote machine.  If the re-
-             mote path name is not specified, it is given the same name it has
-             on the local machine.  If the -P flag is specified, then the
+             Upload local-path and store it on the remote machine.  If the
+             remote path name is not specified, it is given the same name it
+             has on the local machine.  If the -P flag is specified, then the
              file's full permission and access time are copied too.
 
      pwd     Display remote working directory.
@@ -175,7 +175,7 @@
      scp(1), ssh(1), ssh-add(1), ssh-keygen(1), ssh_config(5), sftp-server(8),
      sshd(8)
 
-     T. Ylonen, and S. Lehtinen, SSH File Transfer Protocol, draft-ietf-secsh-
+     T. Ylonen and S. Lehtinen, SSH File Transfer Protocol, draft-ietf-secsh-
      filexfer-00.txt, January 2001, work in progress material.
 
-OpenBSD 3.4                    February 4, 2001                              3
+BSD                            February 4, 2001                            BSD
diff -ru openssh-3.7.1p2.orig/ssh-add.0 openssh-3.7.1p2/ssh-add.0
--- openssh-3.7.1p2.orig/ssh-add.0	2003-09-23 19:55:16.000000000 +1000
+++ openssh-3.7.1p2/ssh-add.0	2003-10-06 16:13:21.000000000 +1000
@@ -1,4 +1,4 @@
-SSH-ADD(1)                 OpenBSD Reference Manual                 SSH-ADD(1)
+SSH-ADD(1)              System General Commands Manual              SSH-ADD(1)
 
 NAME
      ssh-add - adds RSA or DSA identities to the authentication agent
@@ -9,8 +9,8 @@
      ssh-add -e reader
 
 DESCRIPTION
-     ssh-add adds RSA or DSA identities to the authentication agent, ssh-
-     agent(1).  When run without arguments, it adds the files
+     ssh-add adds RSA or DSA identities to the authentication agent,
+     ssh-agent(1).  When run without arguments, it adds the files
      $HOME/.ssh/id_rsa, $HOME/.ssh/id_dsa and $HOME/.ssh/identity.  Alterna-
      tive file names can be given on the command line.  If any file requires a
      passphrase, ssh-add asks for the passphrase from the user.  The
@@ -99,4 +99,4 @@
      ated OpenSSH.  Markus Friedl contributed the support for SSH protocol
      versions 1.5 and 2.0.
 
-OpenBSD 3.4                   September 25, 1999                             2
+BSD                           September 25, 1999                           BSD
diff -ru openssh-3.7.1p2.orig/ssh-agent.0 openssh-3.7.1p2/ssh-agent.0
--- openssh-3.7.1p2.orig/ssh-agent.0	2003-09-23 19:55:16.000000000 +1000
+++ openssh-3.7.1p2/ssh-agent.0	2003-10-06 16:13:22.000000000 +1000
@@ -1,4 +1,4 @@
-SSH-AGENT(1)               OpenBSD Reference Manual               SSH-AGENT(1)
+SSH-AGENT(1)            System General Commands Manual            SSH-AGENT(1)
 
 NAME
      ssh-agent - authentication agent
@@ -18,8 +18,8 @@
      The options are as follows:
 
      -a bind_address
-             Bind the agent to the unix-domain socket bind_address.  The de-
-             fault is /tmp/ssh-XXXXXXXX/agent.<ppid>.
+             Bind the agent to the unix-domain socket bind_address.  The
+             default is /tmp/ssh-XXXXXXXX/agent.<ppid>.
 
      -c      Generate C-shell commands on stdout.  This is the default if
              SHELL looks like it's a csh style of shell.
@@ -34,8 +34,8 @@
              Set a default value for the maximum lifetime of identities added
              to the agent.  The lifetime may be specified in seconds or in a
              time format specified in sshd(8).  A lifetime specified for an
-             identity with ssh-add(1) overrides this value.  Without this op-
-             tion the default maximum lifetime is forever.
+             identity with ssh-add(1) overrides this value.  Without this
+             option the default maximum lifetime is forever.
 
      -d      Debug mode.  When this option is specified ssh-agent will not
              fork.
@@ -67,15 +67,15 @@
      looks at these variables and uses them to establish a connection to the
      agent.
 
-     The agent will never send a private key over its request channel.  In-
-     stead, operations that require a private key will be performed by the
+     The agent will never send a private key over its request channel.
+     Instead, operations that require a private key will be performed by the
      agent, and the result will be returned to the requester.  This way, pri-
      vate keys are not exposed to clients using the agent.
 
      A unix-domain socket is created and the name of this socket is stored in
      the SSH_AUTH_SOCK environment variable.  The socket is made accessible
-     only to the current user.  This method is easily abused by root or anoth-
-     er instance of the same user.
+     only to the current user.  This method is easily abused by root or
+     another instance of the same user.
 
      The SSH_AGENT_PID environment variable holds the agent's process ID.
 
@@ -111,4 +111,4 @@
      ated OpenSSH.  Markus Friedl contributed the support for SSH protocol
      versions 1.5 and 2.0.
 
-OpenBSD 3.4                   September 25, 1999                             2
+BSD                           September 25, 1999                           BSD
diff -ru openssh-3.7.1p2.orig/ssh-keygen.0 openssh-3.7.1p2/ssh-keygen.0
--- openssh-3.7.1p2.orig/ssh-keygen.0	2003-09-23 19:55:16.000000000 +1000
+++ openssh-3.7.1p2/ssh-keygen.0	2003-10-06 16:13:22.000000000 +1000
@@ -1,4 +1,4 @@
-SSH-KEYGEN(1)              OpenBSD Reference Manual              SSH-KEYGEN(1)
+SSH-KEYGEN(1)           System General Commands Manual           SSH-KEYGEN(1)
 
 NAME
      ssh-keygen - authentication key generation, management and conversion
@@ -38,14 +38,14 @@
      name but ``.pub'' appended.  The program also asks for a passphrase.  The
      passphrase may be empty to indicate no passphrase (host keys must have an
      empty passphrase), or it may be a string of arbitrary length.  A
-     passphrase is similar to a password, except it can be a phrase with a se-
-     ries of words, punctuation, numbers, whitespace, or any string of charac-
-     ters you want.  Good passphrases are 10-30 characters long, are not sim-
-     ple sentences or otherwise easily guessable (English prose has only 1-2
-     bits of entropy per character, and provides very bad passphrases), and
-     contain a mix of upper and lowercase letters, numbers, and non-alphanu-
-     meric characters.  The passphrase can be changed later by using the -p
-     option.
+     passphrase is similar to a password, except it can be a phrase with a
+     series of words, punctuation, numbers, whitespace, or any string of char-
+     acters you want.  Good passphrases are 10-30 characters long, are not
+     simple sentences or otherwise easily guessable (English prose has only
+     1-2 bits of entropy per character, and provides very bad passphrases),
+     and contain a mix of upper and lowercase letters, numbers, and non-
+     alphanumeric characters.  The passphrase can be changed later by using
+     the -p option.
 
      There is no way to recover a lost passphrase.  If the passphrase is lost
      or forgotten, a new key must be generated and copied to the corresponding
@@ -155,9 +155,9 @@
 MODULI GENERATION
      ssh-keygen may be used to generate groups for the Diffie-Hellman Group
      Exchange (DH-GEX) protocol.  Generating these groups is a two-step pro-
-     cess: first, candidate primes are generated using a fast, but memory in-
-     tensive process.  These candidate primes are then tested for suitability
-     (a CPU-intensive process).
+     cess: first, candidate primes are generated using a fast, but memory
+     intensive process.  These candidate primes are then tested for suitabil-
+     ity (a CPU-intensive process).
 
      Generation of primes is performed using the -G option.  The desired
      length of the primes may be specified by the -b option.  For example:
@@ -188,8 +188,8 @@
 FILES
      $HOME/.ssh/identity
              Contains the protocol version 1 RSA authentication identity of
-             the user.  This file should not be readable by anyone but the us-
-             er.  It is possible to specify a passphrase when generating the
+             the user.  This file should not be readable by anyone but the
+             user.  It is possible to specify a passphrase when generating the
              key; that passphrase will be used to encrypt the private part of
              this file using 3DES.  This file is not automatically accessed by
              ssh-keygen but it is offered as the default file for the private
@@ -204,8 +204,8 @@
 
      $HOME/.ssh/id_dsa
              Contains the protocol version 2 DSA authentication identity of
-             the user.  This file should not be readable by anyone but the us-
-             er.  It is possible to specify a passphrase when generating the
+             the user.  This file should not be readable by anyone but the
+             user.  It is possible to specify a passphrase when generating the
              key; that passphrase will be used to encrypt the private part of
              this file using 3DES.  This file is not automatically accessed by
              ssh-keygen but it is offered as the default file for the private
@@ -220,8 +220,8 @@
 
      $HOME/.ssh/id_rsa
              Contains the protocol version 2 RSA authentication identity of
-             the user.  This file should not be readable by anyone but the us-
-             er.  It is possible to specify a passphrase when generating the
+             the user.  This file should not be readable by anyone but the
+             user.  It is possible to specify a passphrase when generating the
              key; that passphrase will be used to encrypt the private part of
              this file using 3DES.  This file is not automatically accessed by
              ssh-keygen but it is offered as the default file for the private
@@ -241,14 +241,14 @@
 SEE ALSO
      ssh(1), ssh-add(1), ssh-agent(1), moduli(5), sshd(8)
 
-     J. Galbraith, and R. Thayer, SECSH Public Key File Format, draft-ietf-
+     J. Galbraith and R. Thayer, SECSH Public Key File Format, draft-ietf-
      secsh-publickeyfile-01.txt, March 2001, work in progress material.
 
 AUTHORS
      OpenSSH is a derivative of the original and free ssh 1.2.12 release by
      Tatu Ylonen.  Aaron Campbell, Bob Beck, Markus Friedl, Niels Provos, Theo
-     de Raadt and Dug Song removed many bugs, re-added newer features and
-     created OpenSSH.  Markus Friedl contributed the support for SSH protocol
+     de Raadt and Dug Song removed many bugs, re-added newer features and cre-
+     ated OpenSSH.  Markus Friedl contributed the support for SSH protocol
      versions 1.5 and 2.0.
 
-OpenBSD 3.4                   September 25, 1999                             4
+BSD                           September 25, 1999                           BSD
diff -ru openssh-3.7.1p2.orig/ssh-keyscan.0 openssh-3.7.1p2/ssh-keyscan.0
--- openssh-3.7.1p2.orig/ssh-keyscan.0	2003-09-23 19:55:17.000000000 +1000
+++ openssh-3.7.1p2/ssh-keyscan.0	2003-10-06 16:13:22.000000000 +1000
@@ -1,4 +1,4 @@
-SSH-KEYSCAN(1)             OpenBSD Reference Manual             SSH-KEYSCAN(1)
+SSH-KEYSCAN(1)          System General Commands Manual          SSH-KEYSCAN(1)
 
 NAME
      ssh-keyscan - gather ssh public keys
@@ -29,8 +29,8 @@
              Set the timeout for connection attempts.  If timeout seconds have
              elapsed since a connection was initiated to a host or since the
              last time anything was read from that host, then the connection
-             is closed and the host in question considered unavailable.  De-
-             fault is 5 seconds.
+             is closed and the host in question considered unavailable.
+             Default is 5 seconds.
 
      -t type
              Specifies the type of the key to fetch from the scanned hosts.
@@ -54,9 +54,9 @@
 SECURITY
      If a ssh_known_hosts file is constructed using ssh-keyscan without veri-
      fying the keys, users will be vulnerable to attacks.  On the other hand,
-     if the security model allows such a risk, ssh-keyscan can help in the de-
-     tection of tampered keyfiles or man in the middle attacks which have be-
-     gun after the ssh_known_hosts file was created.
+     if the security model allows such a risk, ssh-keyscan can help in the
+     detection of tampered keyfiles or man in the middle attacks which have
+     begun after the ssh_known_hosts file was created.
 
 FILES
      Input format:
@@ -100,4 +100,4 @@
      This is because it opens a connection to the ssh port, reads the public
      key, and drops the connection as soon as it gets the key.
 
-OpenBSD 3.4                     January 1, 1996                              2
+BSD                             January 1, 1996                            BSD
diff -ru openssh-3.7.1p2.orig/ssh-keysign.0 openssh-3.7.1p2/ssh-keysign.0
--- openssh-3.7.1p2.orig/ssh-keysign.0	2003-09-23 19:55:19.000000000 +1000
+++ openssh-3.7.1p2/ssh-keysign.0	2003-10-06 16:13:25.000000000 +1000
@@ -1,4 +1,4 @@
-SSH-KEYSIGN(8)          OpenBSD System Manager's Manual         SSH-KEYSIGN(8)
+SSH-KEYSIGN(8)              System Manager's Manual             SSH-KEYSIGN(8)
 
 NAME
      ssh-keysign - ssh helper program for hostbased authentication
@@ -39,4 +39,4 @@
 AUTHORS
      Markus Friedl <markus@openbsd.org>
 
-OpenBSD 3.4                      May 24, 2002                                1
+BSD                              May 24, 2002                              BSD
diff -ru openssh-3.7.1p2.orig/ssh-rand-helper.0 openssh-3.7.1p2/ssh-rand-helper.0
--- openssh-3.7.1p2.orig/ssh-rand-helper.0	2003-09-23 19:55:19.000000000 +1000
+++ openssh-3.7.1p2/ssh-rand-helper.0	2003-10-06 16:13:24.000000000 +1000
@@ -1,4 +1,4 @@
-SSH-RAND-HELPER(8)      OpenBSD System Manager's Manual     SSH-RAND-HELPER(8)
+SSH-RAND-HELPER(8)          System Manager's Manual         SSH-RAND-HELPER(8)
 
 NAME
      ssh-rand-helper - Random number gatherer for OpenSSH
@@ -46,4 +46,4 @@
 SEE ALSO
      ssh(1), ssh-add(1), ssh-keygen(1), sshd(8)
 
-OpenBSD 3.4                     April 14, 2002                               1
+BSD                             April 14, 2002                             BSD
diff -ru openssh-3.7.1p2.orig/ssh.0 openssh-3.7.1p2/ssh.0
--- openssh-3.7.1p2.orig/ssh.0	2003-09-23 19:55:17.000000000 +1000
+++ openssh-3.7.1p2/ssh.0	2003-10-06 16:13:23.000000000 +1000
@@ -1,4 +1,4 @@
-SSH(1)                     OpenBSD Reference Manual                     SSH(1)
+SSH(1)                  System General Commands Manual                  SSH(1)
 
 NAME
      ssh - OpenSSH SSH client (remote login program)
@@ -14,13 +14,13 @@
 DESCRIPTION
      ssh (SSH client) is a program for logging into a remote machine and for
      executing commands on a remote machine.  It is intended to replace rlogin
-     and rsh, and provide secure encrypted communications between two untrust-
-     ed hosts over an insecure network.  X11 connections and arbitrary TCP/IP
-     ports can also be forwarded over the secure channel.
+     and rsh, and provide secure encrypted communications between two
+     untrusted hosts over an insecure network.  X11 connections and arbitrary
+     TCP/IP ports can also be forwarded over the secure channel.
 
      ssh connects and logs into the specified hostname.  The user must prove
-     his/her identity to the remote machine using one of several methods de-
-     pending on the protocol version used:
+     his/her identity to the remote machine using one of several methods
+     depending on the protocol version used:
 
    SSH protocol version 1
 
@@ -96,8 +96,8 @@
      server checks whether the matching public key is listed in
      $HOME/.ssh/authorized_keys and grants access if both the key is found and
      the signature is correct.  The session identifier is derived from a
-     shared Diffie-Hellman value and is only known to the client and the serv-
-     er.
+     shared Diffie-Hellman value and is only known to the client and the
+     server.
 
      If public key authentication fails or is not available a password can be
      sent encrypted to the remote host for proving the user's identity.
@@ -112,8 +112,8 @@
 
    Login session and remote execution
 
-     When the user's identity has been accepted by the server, the server ei-
-     ther executes the given command, or logs into the machine and gives the
+     When the user's identity has been accepted by the server, the server
+     either executes the given command, or logs into the machine and gives the
      user a normal shell on the remote machine.  All communication with the
      remote command or shell will be automatically encrypted.
 
@@ -168,11 +168,11 @@
      the -X and -x options described later) and the user is using X11 (the
      DISPLAY environment variable is set), the connection to the X11 display
      is automatically forwarded to the remote side in such a way that any X11
-     programs started from the shell (or command) will go through the encrypt-
-     ed channel, and the connection to the real X server will be made from the
-     local machine.  The user should not manually set DISPLAY.  Forwarding of
-     X11 connections can be configured on the command line or in configuration
-     files.
+     programs started from the shell (or command) will go through the
+     encrypted channel, and the connection to the real X server will be made
+     from the local machine.  The user should not manually set DISPLAY.  For-
+     warding of X11 connections can be configured on the command line or in
+     configuration files.
 
      The DISPLAY value set by ssh will point to the server machine, but with a
      display number greater than zero.  This is normal, and happens because
@@ -187,9 +187,9 @@
      machine (and no cookies are sent in the plain).
 
      If the ForwardAgent variable is set to ``yes'' (or, see the description
-     of the -A and -a options described later) and the user is using an au-
-     thentication agent, the connection to the agent is automatically forward-
-     ed to the remote side.
+     of the -A and -a options described later) and the user is using an
+     authentication agent, the connection to the agent is automatically for-
+     warded to the remote side.
 
      Forwarding of arbitrary TCP/IP connections over the secure channel can be
      specified either on the command line or in a configuration file.  One
@@ -255,10 +255,10 @@
              fully transparent.
 
      -f      Requests ssh to go to background just before command execution.
-             This is useful if ssh is going to ask for passwords or passphras-
-             es, but the user wants it in the background.  This implies -n.
-             The recommended way to start X11 programs at a remote site is
-             with something like ssh -f host xterm.
+             This is useful if ssh is going to ask for passwords or
+             passphrases, but the user wants it in the background.  This
+             implies -n.  The recommended way to start X11 programs at a
+             remote site is with something like ssh -f host xterm.
 
      -g      Allows remote hosts to connect to local forwarded ports.
 
@@ -266,14 +266,14 @@
              Selects a file from which the identity (private key) for RSA or
              DSA authentication is read.  The default is $HOME/.ssh/identity
              for protocol version 1, and $HOME/.ssh/id_rsa and
-             $HOME/.ssh/id_dsa for protocol version 2.  Identity files may al-
-             so be specified on a per-host basis in the configuration file.
+             $HOME/.ssh/id_dsa for protocol version 2.  Identity files may
+             also be specified on a per-host basis in the configuration file.
              It is possible to have multiple -i options (and multiple identi-
              ties specified in configuration files).
 
      -I smartcard_device
-             Specifies which smartcard device to use.  The argument is the de-
-             vice ssh should use to communicate with a smartcard used for
+             Specifies which smartcard device to use.  The argument is the
+             device ssh should use to communicate with a smartcard used for
              storing the user's private RSA key.
 
      -k      Disables forwarding of Kerberos tickets.  This may also be speci-
@@ -290,12 +290,13 @@
 
      -n      Redirects stdin from /dev/null (actually, prevents reading from
              stdin).  This must be used when ssh is run in the background.  A
-             common trick is to use this to run X11 programs on a remote ma-
-             chine.  For example, ssh -n shadows.cs.hut.fi emacs & will start
-             an emacs on shadows.cs.hut.fi, and the X11 connection will be au-
-             tomatically forwarded over an encrypted channel.  The ssh program
-             will be put in the background.  (This does not work if ssh needs
-             to ask for a password or passphrase; see also the -f option.)
+             common trick is to use this to run X11 programs on a remote
+             machine.  For example, ssh -n shadows.cs.hut.fi emacs & will
+             start an emacs on shadows.cs.hut.fi, and the X11 connection will
+             be automatically forwarded over an encrypted channel.  The ssh
+             program will be put in the background.  (This does not work if
+             ssh needs to ask for a password or passphrase; see also the -f
+             option.)
 
      -N      Do not execute a remote command.  This is useful for just for-
              warding ports (protocol version 2 only).
@@ -313,10 +314,10 @@
              suppressed.
 
      -s      May be used to request invocation of a subsystem on the remote
-             system.  Subsystems are a feature of the SSH2 protocol which fa-
-             cilitate the use of SSH as a secure transport for other applica-
-             tions (eg. sftp).  The subsystem is specified as the remote com-
-             mand.
+             system.  Subsystems are a feature of the SSH2 protocol which
+             facilitate the use of SSH as a secure transport for other appli-
+             cations (eg. sftp).  The subsystem is specified as the remote
+             command.
 
      -t      Force pseudo-tty allocation.  This can be used to execute arbi-
              trary screen-based programs on a remote machine, which can be
@@ -453,9 +454,9 @@
              ments.
 
      SSH_TTY
-             This is set to the name of the tty (path to the device) associat-
-             ed with the current shell or command.  If the current session has
-             no tty, this variable is not set.
+             This is set to the name of the tty (path to the device) associ-
+             ated with the current shell or command.  If the current session
+             has no tty, this variable is not set.
 
      TZ      The timezone variable is set to indicate the present timezone if
              it was set when the daemon was started (i.e., the daemon passes
@@ -524,8 +525,8 @@
              by sshd(8) to verify the client host when logging in; other names
              are needed because ssh does not convert the user-supplied name to
              a canonical name before checking the key, because someone with
-             access to the name servers would then be able to fool host au-
-             thentication.
+             access to the name servers would then be able to fool host
+             authentication.
 
      /etc/ssh/ssh_config
              Systemwide configuration file.  The file format and configuration
@@ -555,8 +556,8 @@
              for anyone else.  The recommended permission for most machines is
              read/write for the user, and not accessible by others.
 
-             Note that by default sshd(8) will be installed so that it re-
-             quires successful RSA host authentication before permitting
+             Note that by default sshd(8) will be installed so that it
+             requires successful RSA host authentication before permitting
              .rhosts authentication.  If the server machine does not have the
              client's host key in /etc/ssh/ssh_known_hosts, it can be stored
              in $HOME/.ssh/known_hosts.  The easiest way to do this is to con-
@@ -573,8 +574,8 @@
              canonical hosts names, one per line (the full format is described
              on the sshd(8) manual page).  If the client host is found in this
              file, login is automatically permitted provided client and server
-             user names are the same.  Additionally, successful RSA host au-
-             thentication is normally required.  This file should only be
+             user names are the same.  Additionally, successful RSA host
+             authentication is normally required.  This file should only be
              writable by root.
 
      /etc/shosts.equiv
@@ -611,8 +612,8 @@
 AUTHORS
      OpenSSH is a derivative of the original and free ssh 1.2.12 release by
      Tatu Ylonen.  Aaron Campbell, Bob Beck, Markus Friedl, Niels Provos, Theo
-     de Raadt and Dug Song removed many bugs, re-added newer features and
-     created OpenSSH.  Markus Friedl contributed the support for SSH protocol
+     de Raadt and Dug Song removed many bugs, re-added newer features and cre-
+     ated OpenSSH.  Markus Friedl contributed the support for SSH protocol
      versions 1.5 and 2.0.
 
-OpenBSD 3.4                   September 25, 1999                            10
+BSD                           September 25, 1999                           BSD
diff -ru openssh-3.7.1p2.orig/ssh_config.0 openssh-3.7.1p2/ssh_config.0
--- openssh-3.7.1p2.orig/ssh_config.0	2003-09-23 19:55:19.000000000 +1000
+++ openssh-3.7.1p2/ssh_config.0	2003-10-06 16:13:26.000000000 +1000
@@ -1,4 +1,4 @@
-SSH_CONFIG(5)             OpenBSD Programmer's Manual            SSH_CONFIG(5)
+SSH_CONFIG(5)             System File Formats Manual             SSH_CONFIG(5)
 
 NAME
      ssh_config - OpenSSH SSH client configuration files
@@ -46,8 +46,8 @@
              canonicalized host name before matching).
 
      AddressFamily
-             Specifies which address family to use when connecting.  Valid ar-
-             guments are ``any'', ``inet'' (Use IPv4 only) or ``inet6'' (Use
+             Specifies which address family to use when connecting.  Valid
+             arguments are ``any'', ``inet'' (Use IPv4 only) or ``inet6'' (Use
              IPv6 only.)
 
      BatchMode
@@ -68,22 +68,22 @@
 
      CheckHostIP
              If this flag is set to ``yes'', ssh will additionally check the
-             host IP address in the known_hosts file.  This allows ssh to de-
-             tect if a host key changed due to DNS spoofing.  If the option is
-             set to ``no'', the check will not be executed.  The default is
+             host IP address in the known_hosts file.  This allows ssh to
+             detect if a host key changed due to DNS spoofing.  If the option
+             is set to ``no'', the check will not be executed.  The default is
              ``yes''.
 
      Cipher  Specifies the cipher to use for encrypting the session in proto-
              col version 1.  Currently, ``blowfish'', ``3des'', and ``des''
-             are supported.  des is only supported in the ssh client for in-
-             teroperability with legacy protocol 1 implementations that do not
-             support the 3des cipher.  Its use is strongly discouraged due to
-             cryptographic weaknesses.  The default is ``3des''.
+             are supported.  des is only supported in the ssh client for
+             interoperability with legacy protocol 1 implementations that do
+             not support the 3des cipher.  Its use is strongly discouraged due
+             to cryptographic weaknesses.  The default is ``3des''.
 
      Ciphers
              Specifies the ciphers allowed for protocol version 2 in order of
-             preference.  Multiple ciphers must be comma-separated.  The de-
-             fault is
+             preference.  Multiple ciphers must be comma-separated.  The
+             default is
 
                ``aes128-cbc,3des-cbc,blowfish-cbc,cast128-cbc,arcfour,
                  aes192-cbc,aes256-cbc''
@@ -108,24 +108,24 @@
              option applies to protocol version 1 only.
 
      ConnectionAttempts
-             Specifies the number of tries (one per second) to make before ex-
-             iting.  The argument must be an integer.  This may be useful in
+             Specifies the number of tries (one per second) to make before
+             exiting.  The argument must be an integer.  This may be useful in
              scripts if the connection sometimes fails.  The default is 1.
 
      ConnectTimeout
              Specifies the timeout (in seconds) used when connecting to the
              ssh server, instead of using the default system TCP timeout.
-             This value is used only when the target is down or really un-
-             reachable, not when it refuses the connection.
+             This value is used only when the target is down or really
+             unreachable, not when it refuses the connection.
 
      DynamicForward
              Specifies that a TCP/IP port on the local machine be forwarded
              over the secure channel, and the application protocol is then
              used to determine where to connect to from the remote machine.
              The argument must be a port number.  Currently the SOCKS4 and
-             SOCKS5 protocols are supported, and ssh will act as a SOCKS serv-
-             er.  Multiple forwardings may be specified, and additional for-
-             wardings can be given on the command line.  Only the superuser
+             SOCKS5 protocols are supported, and ssh will act as a SOCKS
+             server.  Multiple forwardings may be specified, and additional
+             forwardings can be given on the command line.  Only the superuser
              can forward privileged ports.
 
      EnableSSHKeysign
@@ -156,9 +156,9 @@
              the agent.
 
      ForwardX11
-             Specifies whether X11 connections will be automatically redirect-
-             ed over the secure channel and DISPLAY set.  The argument must be
-             ``yes'' or ``no''.  The default is ``no''.
+             Specifies whether X11 connections will be automatically redi-
+             rected over the secure channel and DISPLAY set.  The argument
+             must be ``yes'' or ``no''.  The default is ``no''.
 
              X11 forwarding should be enabled with caution.  Users with the
              ability to bypass file permissions on the remote host (for the
@@ -171,30 +171,31 @@
              forwarded ports.  By default, ssh binds local port forwardings to
              the loopback address.  This prevents other remote hosts from con-
              necting to forwarded ports.  GatewayPorts can be used to specify
-             that ssh should bind local port forwardings to the wildcard ad-
-             dress, thus allowing remote hosts to connect to forwarded ports.
-             The argument must be ``yes'' or ``no''.  The default is ``no''.
+             that ssh should bind local port forwardings to the wildcard
+             address, thus allowing remote hosts to connect to forwarded
+             ports.  The argument must be ``yes'' or ``no''.  The default is
+             ``no''.
 
      GlobalKnownHostsFile
              Specifies a file to use for the global host key database instead
              of /etc/ssh/ssh_known_hosts.
 
      GSSAPIAuthentication
-             Specifies whether authentication based on GSSAPI may be used, ei-
-             ther using the result of a successful key exchange, or using GSS-
-             API user authentication.  The default is ``yes''.  Note that this
-             option applies to protocol version 2 only.
+             Specifies whether authentication based on GSSAPI may be used,
+             either using the result of a successful key exchange, or using
+             GSSAPI user authentication.  The default is ``yes''.  Note that
+             this option applies to protocol version 2 only.
 
      GSSAPIDelegateCredentials
              Forward (delegate) credentials to the server.  The default is
-             ``no''.  Note that this option applies to protocol version 2 on-
-             ly.
+             ``no''.  Note that this option applies to protocol version 2
+             only.
 
      HostbasedAuthentication
              Specifies whether to try rhosts based authentication with public
              key authentication.  The argument must be ``yes'' or ``no''.  The
-             default is ``no''.  This option applies to protocol version 2 on-
-             ly and is similar to RhostsRSAAuthentication.
+             default is ``no''.  This option applies to protocol version 2
+             only and is similar to RhostsRSAAuthentication.
 
      HostKeyAlgorithms
              Specifies the protocol version 2 host key algorithms that the
@@ -220,8 +221,8 @@
              col version 1, and $HOME/.ssh/id_rsa and $HOME/.ssh/id_dsa for
              protocol version 2.  Additionally, any identities represented by
              the authentication agent will be used for authentication.  The
-             file name may use the tilde syntax to refer to a user's home di-
-             rectory.  It is possible to have multiple identity files speci-
+             file name may use the tilde syntax to refer to a user's home
+             directory.  It is possible to have multiple identity files speci-
              fied in configuration files; all these identities will be tried
              in sequence.
 
@@ -254,20 +255,20 @@
              DEBUG and DEBUG1 are equivalent.  DEBUG2 and DEBUG3 each specify
              higher levels of verbose output.
 
-     MACs    Specifies the MAC (message authentication code) algorithms in or-
-             der of preference.  The MAC algorithm is used in protocol version
-             2 for data integrity protection.  Multiple algorithms must be
-             comma-separated.  The default is ``hmac-md5,hmac-sha1,hmac-
-             ripemd160,hmac-sha1-96,hmac-md5-96''.
+     MACs    Specifies the MAC (message authentication code) algorithms in
+             order of preference.  The MAC algorithm is used in protocol ver-
+             sion 2 for data integrity protection.  Multiple algorithms must
+             be comma-separated.  The default is
+             ``hmac-md5,hmac-sha1,hmac-ripemd160,hmac-sha1-96,hmac-md5-96''.
 
      NoHostAuthenticationForLocalhost
              This option can be used if the home directory is shared across
-             machines.  In this case localhost will refer to a different ma-
-             chine on each of the machines and the user will get many warnings
-             about changed host keys.  However, this option disables host au-
-             thentication for localhost.  The argument to this keyword must be
-             ``yes'' or ``no''.  The default is to check the host key for lo-
-             calhost.
+             machines.  In this case localhost will refer to a different
+             machine on each of the machines and the user will get many warn-
+             ings about changed host keys.  However, this option disables host
+             authentication for localhost.  The argument to this keyword must
+             be ``yes'' or ``no''.  The default is to check the host key for
+             localhost.
 
      NumberOfPasswordPrompts
              Specifies the number of password prompts before giving up.  The
@@ -282,11 +283,11 @@
              is 22.
 
      PreferredAuthentications
-             Specifies the order in which the client should try protocol 2 au-
-             thentication methods.  This allows a client to prefer one method
-             (e.g.  keyboard-interactive) over another method (e.g.  password)
-             The default for this option is: ``hostbased,publickey,keyboard-
-             interactive,password''.
+             Specifies the order in which the client should try protocol 2
+             authentication methods.  This allows a client to prefer one
+             method (e.g.  keyboard-interactive) over another method (e.g.
+             password) The default for this option is:
+             ``hostbased,publickey,keyboard-interactive,password''.
 
      Protocol
              Specifies the protocol versions ssh should support in order of
@@ -304,10 +305,10 @@
              write to its standard output.  It should eventually connect an
              sshd(8) server running on some machine, or execute sshd -i some-
              where.  Host key management will be done using the HostName of
-             the host being connected (defaulting to the name typed by the us-
-             er).  Setting the command to ``none'' disables this option en-
-             tirely.  Note that CheckHostIP is not available for connects with
-             a proxy command.
+             the host being connected (defaulting to the name typed by the
+             user).  Setting the command to ``none'' disables this option
+             entirely.  Note that CheckHostIP is not available for connects
+             with a proxy command.
 
      PubkeyAuthentication
              Specifies whether to try public key authentication.  The argument
@@ -389,8 +390,8 @@
              This is the per-user configuration file.  The format of this file
              is described above.  This file is used by the ssh client.  This
              file does not usually contain any sensitive information, but the
-             recommended permissions are read/write for the user, and not ac-
-             cessible by others.
+             recommended permissions are read/write for the user, and not
+             accessible by others.
 
      /etc/ssh/ssh_config
              Systemwide configuration file.  This file provides defaults for
@@ -408,4 +409,4 @@
      ated OpenSSH.  Markus Friedl contributed the support for SSH protocol
      versions 1.5 and 2.0.
 
-OpenBSD 3.4                   September 25, 1999                             7
+BSD                           September 25, 1999                           BSD
diff -ru openssh-3.7.1p2.orig/sshd.0 openssh-3.7.1p2/sshd.0
--- openssh-3.7.1p2.orig/sshd.0	2003-09-23 19:55:18.000000000 +1000
+++ openssh-3.7.1p2/sshd.0	2003-10-06 16:13:24.000000000 +1000
@@ -1,4 +1,4 @@
-SSHD(8)                 OpenBSD System Manager's Manual                SSHD(8)
+SSHD(8)                     System Manager's Manual                    SSHD(8)
 
 NAME
      sshd - OpenSSH SSH daemon
@@ -14,8 +14,8 @@
      intended to be as easy to install and use as possible.
 
      sshd is the daemon that listens for connections from clients.  It is nor-
-     mally started at boot from /etc/rc.  It forks a new daemon for each in-
-     coming connection.  The forked daemons handle key exchange, encryption,
+     mally started at boot from /etc/rc.  It forks a new daemon for each
+     incoming connection.  The forked daemons handle key exchange, encryption,
      authentication, command execution, and data exchange.  This implementa-
      tion of sshd supports both SSH protocol version 1 and 2 simultaneously.
      sshd works as follows:
@@ -24,15 +24,15 @@
 
      Each host has a host-specific RSA key (normally 1024 bits) used to iden-
      tify the host.  Additionally, when the daemon starts, it generates a
-     server RSA key (normally 768 bits).  This key is normally regenerated ev-
-     ery hour if it has been used, and is never stored on disk.
+     server RSA key (normally 768 bits).  This key is normally regenerated
+     every hour if it has been used, and is never stored on disk.
 
      Whenever a client connects, the daemon responds with its public host and
      server keys.  The client compares the RSA host key against its own
      database to verify that it has not changed.  The client then generates a
      256 bit random number.  It encrypts this random number using both the
-     host key and the server key, and sends the encrypted number to the serv-
-     er.  Both sides then use this random number as a session key which is
+     host key and the server key, and sends the encrypted number to the
+     server.  Both sides then use this random number as a session key which is
      used to encrypt all further communications in the session.  The rest of
      the session is encrypted using a conventional cipher, currently Blowfish
      or 3DES, with 3DES being used by default.  The client selects the encryp-
@@ -40,8 +40,8 @@
 
      Next, the server and the client enter an authentication dialog.  The
      client tries to authenticate itself using .rhosts authentication, .rhosts
-     authentication combined with RSA host authentication, RSA challenge-re-
-     sponse authentication, or password based authentication.
+     authentication combined with RSA host authentication, RSA challenge-
+     response authentication, or password based authentication.
 
      Regardless of the authentication type, the account is checked to ensure
      that it is accessible.  An account is not accessible if it is locked,
@@ -69,9 +69,10 @@
 
      The rest of the session is encrypted using a symmetric cipher, currently
      128 bit AES, Blowfish, 3DES, CAST128, Arcfour, 192 bit AES, or 256 bit
-     AES.  The client selects the encryption algorithm to use from those of-
-     fered by the server.  Additionally, session integrity is provided through
-     a cryptographic message authentication code (hmac-sha1 or hmac-md5).
+     AES.  The client selects the encryption algorithm to use from those
+     offered by the server.  Additionally, session integrity is provided
+     through a cryptographic message authentication code (hmac-sha1 or hmac-
+     md5).
 
      Protocol version 2 provides a public key based user (PubkeyAuthentica-
      tion) or client host (HostbasedAuthentication) authentication method,
@@ -112,8 +113,8 @@
      -d      Debug mode.  The server sends verbose debug output to the system
              log, and does not put itself in the background.  The server also
              will not fork and will only process one connection.  This option
-             is only intended for debugging for the server.  Multiple -d op-
-             tions increase the debugging level.  Maximum is 3.
+             is only intended for debugging for the server.  Multiple -d
+             options increase the debugging level.  Maximum is 3.
 
      -e      When this option is specified, sshd will send the output to the
              standard error instead of the system log.
@@ -124,10 +125,10 @@
              figuration file.
 
      -g login_grace_time
-             Gives the grace time for clients to authenticate themselves (de-
-             fault 120 seconds).  If the client fails to authenticate the user
-             within this many seconds, the server disconnects and exits.  A
-             value of zero indicates no limit.
+             Gives the grace time for clients to authenticate themselves
+             (default 120 seconds).  If the client fails to authenticate the
+             user within this many seconds, the server disconnects and exits.
+             A value of zero indicates no limit.
 
      -h host_key_file
              Specifies a file from which a host key is read.  This option must
@@ -141,9 +142,9 @@
      -i      Specifies that sshd is being run from inetd(8).  sshd is normally
              not run from inetd because it needs to generate the server key
              before it can respond to the client, and this may take tens of
-             seconds.  Clients would have to wait too long if the key was re-
-             generated every time.  However, with small key sizes (e.g., 512)
-             using sshd from inetd may be feasible.
+             seconds.  Clients would have to wait too long if the key was
+             regenerated every time.  However, with small key sizes (e.g.,
+             512) using sshd from inetd may be feasible.
 
      -k key_gen_time
              Specifies how often the ephemeral protocol version 1 server key
@@ -165,8 +166,8 @@
              fied in the configuration file are ignored when a command-line
              port is specified.
 
-     -q      Quiet mode.  Nothing is sent to the system log.  Normally the be-
-             ginning, authentication, and termination of each connection is
+     -q      Quiet mode.  Nothing is sent to the system log.  Normally the
+             beginning, authentication, and termination of each connection is
              logged.
 
      -t      Test mode.  Only check the validity of the configuration file and
@@ -181,10 +182,10 @@
              indicates that only dotted decimal addresses should be put into
              the utmp file.  -u0 may also be used to prevent sshd from making
              DNS requests unless the authentication mechanism or configuration
-             requires it.  Authentication mechanisms that may require DNS in-
-             clude RhostsRSAAuthentication, HostbasedAuthentication and using
-             a from="pattern-list" option in a key file.  Configuration op-
-             tions that require DNS include using a USER@HOST pattern in
+             requires it.  Authentication mechanisms that may require DNS
+             include RhostsRSAAuthentication, HostbasedAuthentication and
+             using a from="pattern-list" option in a key file.  Configuration
+             options that require DNS include using a USER@HOST pattern in
              AllowUsers or DenyUsers.
 
      -D      When this option is specified sshd will not detach and does not
@@ -216,14 +217,14 @@
 
            5.   Sets up basic environment.
 
-           6.   Reads $HOME/.ssh/environment if it exists and users are al-
-                lowed to change their environment.  See the
+           6.   Reads $HOME/.ssh/environment if it exists and users are
+                allowed to change their environment.  See the
                 PermitUserEnvironment option in sshd_config(5).
 
            7.   Changes to user's home directory.
 
-           8.   If $HOME/.ssh/rc exists, runs it; else if /etc/ssh/sshrc ex-
-                ists, runs it; otherwise runs xauth.  The ``rc'' files are
+           8.   If $HOME/.ssh/rc exists, runs it; else if /etc/ssh/sshrc
+                exists, runs it; otherwise runs xauth.  The ``rc'' files are
                 given the X11 authentication protocol and cookie in standard
                 input.
 
@@ -247,8 +248,8 @@
      to identify the key).  For protocol version 2 the keytype is ``ssh-dss''
      or ``ssh-rsa''.
 
-     Note that lines in this file are usually several hundred bytes long (be-
-     cause of the size of the public key encoding).  You don't want to type
+     Note that lines in this file are usually several hundred bytes long
+     (because of the size of the public key encoding).  You don't want to type
      them in; instead, copy the identity.pub, id_dsa.pub or the id_rsa.pub
      file and edit it.
 
@@ -269,25 +270,25 @@
              key is not accepted.  The purpose of this option is to optionally
              increase security: public key authentication by itself does not
              trust the network or name servers or anything (but the key); how-
-             ever, if somebody somehow steals the key, the key permits an in-
-             truder to log in from anywhere in the world.  This additional op-
-             tion makes using a stolen key more difficult (name servers and/or
-             routers would have to be compromised in addition to just the
-             key).
+             ever, if somebody somehow steals the key, the key permits an
+             intruder to log in from anywhere in the world.  This additional
+             option makes using a stolen key more difficult (name servers
+             and/or routers would have to be compromised in addition to just
+             the key).
 
      command="command"
              Specifies that the command is executed whenever this key is used
              for authentication.  The command supplied by the user (if any) is
              ignored.  The command is run on a pty if the client requests a
              pty; otherwise it is run without a tty.  If an 8-bit clean chan-
-             nel is required, one must not request a pty or should specify no-
-             pty.  A quote may be included in the command by quoting it with a
-             backslash.  This option might be useful to restrict certain pub-
-             lic keys to perform just a specific operation.  An example might
-             be a key that permits remote backups but nothing else.  Note that
-             the client may specify TCP/IP and/or X11 forwarding unless they
-             are explicitly prohibited.  Note that this option applies to
-             shell, command or subsystem execution.
+             nel is required, one must not request a pty or should specify
+             no-pty.  A quote may be included in the command by quoting it
+             with a backslash.  This option might be useful to restrict cer-
+             tain public keys to perform just a specific operation.  An exam-
+             ple might be a key that permits remote backups but nothing else.
+             Note that the client may specify TCP/IP and/or X11 forwarding
+             unless they are explicitly prohibited.  Note that this option
+             applies to shell, command or subsystem execution.
 
      environment="NAME=value"
              Specifies that the string is to be added to the environment when
@@ -299,8 +300,8 @@
 
      no-port-forwarding
              Forbids TCP/IP forwarding when this key is used for authentica-
-             tion.  Any port forward requests by the client will return an er-
-             ror.  This might be used, e.g., in connection with the command
+             tion.  Any port forward requests by the client will return an
+             error.  This might be used, e.g., in connection with the command
              option.
 
      no-X11-forwarding
@@ -318,24 +319,24 @@
              nect to the specified host and port.  IPv6 addresses can be spec-
              ified with an alternative syntax: host/port.  Multiple permitopen
              options may be applied separated by commas.  No pattern matching
-             is performed on the specified hostnames, they must be literal do-
-             mains or addresses.
+             is performed on the specified hostnames, they must be literal
+             domains or addresses.
 
    Examples
      1024 33 12121...312314325 ylo@foo.bar
 
      from="*.niksula.hut.fi,!pc.niksula.hut.fi" 1024 35 23...2334 ylo@niksula
 
-     command="dump /home",no-pty,no-port-forwarding 1024 33 23...2323 back-
-     up.hut.fi
+     command="dump /home",no-pty,no-port-forwarding 1024 33 23...2323
+     backup.hut.fi
 
      permitopen="10.2.1.55:80",permitopen="10.2.1.56:25" 1024 33 23...2323
 
 SSH_KNOWN_HOSTS FILE FORMAT
      The /etc/ssh/ssh_known_hosts and $HOME/.ssh/known_hosts files contain
      host public keys for all known hosts.  The global file should be prepared
-     by the administrator (optional), and the per-user file is maintained au-
-     tomatically: whenever the user connects from an unknown host its key is
+     by the administrator (optional), and the per-user file is maintained
+     automatically: whenever the user connects from an unknown host its key is
      added to the per-user file.
 
      Each line in these files contains the following fields: hostnames, bits,
@@ -345,8 +346,8 @@
      cards); each pattern in turn is matched against the canonical host name
      (when authenticating a client) or against the user-supplied name (when
      authenticating a server).  A pattern may also be preceded by `!' to indi-
-     cate negation: if the host name matches a negated pattern, it is not ac-
-     cepted (by that line) even if it matched another pattern on the line.
+     cate negation: if the host name matches a negated pattern, it is not
+     accepted (by that line) even if it matched another pattern on the line.
 
      Bits, exponent, and modulus are taken directly from the RSA host key;
      they can be obtained, e.g., from /etc/ssh/ssh_host_key.pub.  The optional
@@ -415,8 +416,8 @@
              the user's account.  This file must be readable by root (which
              may on some machines imply it being world-readable if the user's
              home directory resides on an NFS volume).  It is recommended that
-             it not be accessible by others.  The format of this file is de-
-             scribed above.  Users will place the contents of their
+             it not be accessible by others.  The format of this file is
+             described above.  Users will place the contents of their
              identity.pub, id_dsa.pub and/or id_rsa.pub files into this file,
              as described in ssh-keygen(1).
 
@@ -437,8 +438,8 @@
              world-readable.
 
      /etc/hosts.allow, /etc/hosts.deny
-             Access controls that should be enforced by tcp-wrappers are de-
-             fined here.  Further details are described in hosts_access(5).
+             Access controls that should be enforced by tcp-wrappers are
+             defined here.  Further details are described in hosts_access(5).
 
      $HOME/.rhosts
              This file contains host-username pairs, separated by a space, one
@@ -463,21 +464,22 @@
              they have the same user name on both machines.  The host name may
              also be followed by a user name; such users are permitted to log
              in as any user on this machine (except root).  Additionally, the
-             syntax ``+@group'' can be used to specify netgroups.  Negated en-
-             tries start with `-'.
+             syntax ``+@group'' can be used to specify netgroups.  Negated
+             entries start with `-'.
 
-             If the client host/user is successfully matched in this file, lo-
-             gin is automatically permitted provided the client and server us-
-             er names are the same.  Additionally, successful RSA host authen-
-             tication is normally required.  This file must be writable only
-             by root; it is recommended that it be world-readable.
+             If the client host/user is successfully matched in this file,
+             login is automatically permitted provided the client and server
+             user names are the same.  Additionally, successful RSA host
+             authentication is normally required.  This file must be writable
+             only by root; it is recommended that it be world-readable.
 
              Warning: It is almost never a good idea to use user names in
              hosts.equiv.  Beware that it really means that the named user(s)
              can log in as anybody, which includes bin, daemon, adm, and other
-             accounts that own critical binaries and directories.  Using a us-
-             er name practically grants the user root access.  The only valid
-             use for user names that I can think of is in negative entries.
+             accounts that own critical binaries and directories.  Using a
+             user name practically grants the user root access.  The only
+             valid use for user names that I can think of is in negative
+             entries.
 
              Note that this warning also applies to rsh/rlogin.
 
@@ -495,18 +497,18 @@
              is controlled via the PermitUserEnvironment option.
 
      $HOME/.ssh/rc
-             If this file exists, it is run with /bin/sh after reading the en-
-             vironment files but before starting the user's shell or command.
-             It must not produce any output on stdout; stderr must be used in-
-             stead.  If X11 forwarding is in use, it will receive the "proto
-             cookie" pair in its standard input (and DISPLAY in its environ-
-             ment).  The script must call xauth(1) because sshd will not run
-             xauth automatically to add X11 cookies.
+             If this file exists, it is run with /bin/sh after reading the
+             environment files but before starting the user's shell or com-
+             mand.  It must not produce any output on stdout; stderr must be
+             used instead.  If X11 forwarding is in use, it will receive the
+             "proto cookie" pair in its standard input (and DISPLAY in its
+             environment).  The script must call xauth(1) because sshd will
+             not run xauth automatically to add X11 cookies.
 
              The primary purpose of this file is to run any initialization
-             routines which may be needed before the user's home directory be-
-             comes accessible; AFS is a particular example of such an environ-
-             ment.
+             routines which may be needed before the user's home directory
+             becomes accessible; AFS is a particular example of such an envi-
+             ronment.
 
              This file will probably contain some initialization code followed
              by something similar to:
@@ -548,9 +550,9 @@
 AUTHORS
      OpenSSH is a derivative of the original and free ssh 1.2.12 release by
      Tatu Ylonen.  Aaron Campbell, Bob Beck, Markus Friedl, Niels Provos, Theo
-     de Raadt and Dug Song removed many bugs, re-added newer features and
-     created OpenSSH.  Markus Friedl contributed the support for SSH protocol
+     de Raadt and Dug Song removed many bugs, re-added newer features and cre-
+     ated OpenSSH.  Markus Friedl contributed the support for SSH protocol
      versions 1.5 and 2.0.  Niels Provos and Markus Friedl contributed support
      for privilege separation.
 
-OpenBSD 3.4                   September 25, 1999                             9
+BSD                           September 25, 1999                           BSD
diff -ru openssh-3.7.1p2.orig/sshd_config.0 openssh-3.7.1p2/sshd_config.0
--- openssh-3.7.1p2.orig/sshd_config.0	2003-09-23 19:55:19.000000000 +1000
+++ openssh-3.7.1p2/sshd_config.0	2003-10-06 16:13:25.000000000 +1000
@@ -1,4 +1,4 @@
-SSHD_CONFIG(5)            OpenBSD Programmer's Manual           SSHD_CONFIG(5)
+SSHD_CONFIG(5)            System File Formats Manual            SSHD_CONFIG(5)
 
 NAME
      sshd_config - OpenSSH SSH daemon configuration file
@@ -25,30 +25,30 @@
 
      AllowTcpForwarding
              Specifies whether TCP forwarding is permitted.  The default is
-             ``yes''.  Note that disabling TCP forwarding does not improve se-
-             curity unless users are also denied shell access, as they can al-
-             ways install their own forwarders.
+             ``yes''.  Note that disabling TCP forwarding does not improve
+             security unless users are also denied shell access, as they can
+             always install their own forwarders.
 
      AllowUsers
              This keyword can be followed by a list of user name patterns,
-             separated by spaces.  If specified, login is allowed only for us-
-             er names that match one of the patterns.  `*' and `?' can be used
-             as wildcards in the patterns.  Only user names are valid; a nu-
-             merical user ID is not recognized.  By default, login is allowed
-             for all users.  If the pattern takes the form USER@HOST then USER
-             and HOST are separately checked, restricting logins to particular
-             users from particular hosts.
+             separated by spaces.  If specified, login is allowed only for
+             user names that match one of the patterns.  `*' and `?' can be
+             used as wildcards in the patterns.  Only user names are valid; a
+             numerical user ID is not recognized.  By default, login is
+             allowed for all users.  If the pattern takes the form USER@HOST
+             then USER and HOST are separately checked, restricting logins to
+             particular users from particular hosts.
 
      AuthorizedKeysFile
              Specifies the file that contains the public keys that can be used
              for user authentication.  AuthorizedKeysFile may contain tokens
              of the form %T which are substituted during connection set-up.
              The following tokens are defined: %% is replaced by a literal
-             '%', %h is replaced by the home directory of the user being au-
-             thenticated and %u is replaced by the username of that user.  Af-
-             ter expansion, AuthorizedKeysFile is taken to be an absolute path
-             or one relative to the user's home directory.  The default is
-             ``.ssh/authorized_keys''.
+             '%', %h is replaced by the home directory of the user being
+             authenticated and %u is replaced by the username of that user.
+             After expansion, AuthorizedKeysFile is taken to be an absolute
+             path or one relative to the user's home directory.  The default
+             is ``.ssh/authorized_keys''.
 
      Banner  In some jurisdictions, sending a warning message before authenti-
              cation may be relevant for getting legal protection.  The con-
@@ -78,8 +78,8 @@
      ClientAliveCountMax
              Sets the number of client alive messages (see above) which may be
              sent without sshd receiving any messages back from the client.
-             If this threshold is reached while client alive messages are be-
-             ing sent, sshd will disconnect the client, terminating the ses-
+             If this threshold is reached while client alive messages are
+             being sent, sshd will disconnect the client, terminating the ses-
              sion.  It is important to note that the use of client alive mes-
              sages is very different from KeepAlive (below).  The client alive
              messages are sent through the encrypted channel and therefore
@@ -101,8 +101,8 @@
              separated by spaces.  Login is disallowed for users whose primary
              group or supplementary group list matches one of the patterns.
              `*' and `?' can be used as wildcards in the patterns.  Only group
-             names are valid; a numerical group ID is not recognized.  By de-
-             fault, login is allowed for all groups.
+             names are valid; a numerical group ID is not recognized.  By
+             default, login is allowed for all groups.
 
      DenyUsers
              This keyword can be followed by a list of user name patterns,
@@ -135,8 +135,8 @@
              applies to protocol version 2 only.
 
      HostbasedAuthentication
-             Specifies whether rhosts or /etc/hosts.equiv authentication to-
-             gether with successful public key client host authentication is
+             Specifies whether rhosts or /etc/hosts.equiv authentication
+             together with successful public key client host authentication is
              allowed (hostbased authentication).  This option is similar to
              RhostsRSAAuthentication and applies to protocol version 2 only.
              The default is ``no''.
@@ -154,8 +154,8 @@
              Specifies that .rhosts and .shosts files will not be used in
              RhostsRSAAuthentication or HostbasedAuthentication.
 
-             /etc/hosts.equiv and /etc/shosts.equiv are still used.  The de-
-             fault is ``yes''.
+             /etc/hosts.equiv and /etc/shosts.equiv are still used.  The
+             default is ``yes''.
 
      IgnoreUserKnownHosts
              Specifies whether sshd should ignore the user's
@@ -230,15 +230,15 @@
 
      MACs    Specifies the available MAC (message authentication code) algo-
              rithms.  The MAC algorithm is used in protocol version 2 for data
-             integrity protection.  Multiple algorithms must be comma-separat-
-             ed.  The default is ``hmac-md5,hmac-sha1,hmac-ripemd160,hmac-
-             sha1-96,hmac-md5-96''.
+             integrity protection.  Multiple algorithms must be comma-sepa-
+             rated.  The default is
+             ``hmac-md5,hmac-sha1,hmac-ripemd160,hmac-sha1-96,hmac-md5-96''.
 
      MaxStartups
              Specifies the maximum number of concurrent unauthenticated con-
              nections to the sshd daemon.  Additional connections will be
-             dropped until authentication succeeds or the LoginGraceTime ex-
-             pires for a connection.  The default is 10.
+             dropped until authentication succeeds or the LoginGraceTime
+             expires for a connection.  The default is 10.
 
              Alternatively, random early drop can be enabled by specifying the
              three colon separated values ``start:rate:full'' (e.g.,
@@ -249,8 +249,8 @@
              unauthenticated connections reaches ``full'' (60).
 
      PasswordAuthentication
-             Specifies whether password authentication is allowed.  The de-
-             fault is ``yes''.
+             Specifies whether password authentication is allowed.  The
+             default is ``yes''.
 
      PermitEmptyPasswords
              When password authentication is allowed, it specifies whether the
@@ -276,9 +276,9 @@
      PermitUserEnvironment
              Specifies whether ~/.ssh/environment and environment= options in
              ~/.ssh/authorized_keys are processed by sshd.  The default is
-             ``no''.  Enabling environment processing may enable users to by-
-             pass access restrictions in some configurations using mechanisms
-             such as LD_PRELOAD.
+             ``no''.  Enabling environment processing may enable users to
+             bypass access restrictions in some configurations using mecha-
+             nisms such as LD_PRELOAD.
 
      PidFile
              Specifies the file that contains the process ID of the sshd dae-
@@ -301,28 +301,28 @@
              Specifies the protocol versions sshd supports.  The possible val-
              ues are ``1'' and ``2''.  Multiple versions must be comma-sepa-
              rated.  The default is ``2,1''.  Note that the order of the pro-
-             tocol list does not indicate preference, because the client se-
-             lects among multiple protocol versions offered by the server.
+             tocol list does not indicate preference, because the client
+             selects among multiple protocol versions offered by the server.
              Specifying ``2,1'' is identical to ``1,2''.
 
      PubkeyAuthentication
-             Specifies whether public key authentication is allowed.  The de-
-             fault is ``yes''.  Note that this option applies to protocol ver-
-             sion 2 only.  RhostsRSAAuthentication should be used instead, be-
-             cause it performs RSA-based host authentication in addition to
+             Specifies whether public key authentication is allowed.  The
+             default is ``yes''.  Note that this option applies to protocol
+             version 2 only.  RhostsRSAAuthentication should be used instead,
+             because it performs RSA-based host authentication in addition to
              normal rhosts or /etc/hosts.equiv authentication.  The default is
              ``no''.  This option applies to protocol version 1 only.
 
      RhostsRSAAuthentication
-             Specifies whether rhosts or /etc/hosts.equiv authentication to-
-             gether with successful RSA host authentication is allowed.  The
-             default is ``no''.  This option applies to protocol version 1 on-
-             ly.
+             Specifies whether rhosts or /etc/hosts.equiv authentication
+             together with successful RSA host authentication is allowed.  The
+             default is ``no''.  This option applies to protocol version 1
+             only.
 
      RSAAuthentication
-             Specifies whether pure RSA authentication is allowed.  The de-
-             fault is ``yes''.  This option applies to protocol version 1 on-
-             ly.
+             Specifies whether pure RSA authentication is allowed.  The
+             default is ``yes''.  This option applies to protocol version 1
+             only.
 
      ServerKeyBits
              Defines the number of bits in the ephemeral protocol version 1
@@ -337,17 +337,17 @@
 
      Subsystem
              Configures an external subsystem (e.g., file transfer daemon).
-             Arguments should be a subsystem name and a command to execute up-
-             on subsystem request.  The command sftp-server(8) implements the
-             ``sftp'' file transfer subsystem.  By default no subsystems are
-             defined.  Note that this option applies to protocol version 2 on-
-             ly.
+             Arguments should be a subsystem name and a command to execute
+             upon subsystem request.  The command sftp-server(8) implements
+             the ``sftp'' file transfer subsystem.  By default no subsystems
+             are defined.  Note that this option applies to protocol version 2
+             only.
 
      SyslogFacility
              Gives the facility code that is used when logging messages from
-             sshd.  The possible values are: DAEMON, USER, AUTH, LOCAL0, LO-
-             CAL1, LOCAL2, LOCAL3, LOCAL4, LOCAL5, LOCAL6, LOCAL7.  The de-
-             fault is AUTH.
+             sshd.  The possible values are: DAEMON, USER, AUTH, LOCAL0,
+             LOCAL1, LOCAL2, LOCAL3, LOCAL4, LOCAL5, LOCAL6, LOCAL7.  The
+             default is AUTH.
 
      UseDNS  Specifies whether sshd should lookup the remote host name and
              check that the resolved host name for the remote IP address maps
@@ -356,8 +356,8 @@
      UseLogin
              Specifies whether login(1) is used for interactive login ses-
              sions.  The default is ``no''.  Note that login(1) is never used
-             for remote command execution.  Note also, that if this is en-
-             abled, X11Forwarding will be disabled because login(1) does not
+             for remote command execution.  Note also, that if this is
+             enabled, X11Forwarding will be disabled because login(1) does not
              know how to handle xauth(1) cookies.  If UsePrivilegeSeparation
              is specified, it will be disabled after authentication.
 
@@ -367,8 +367,8 @@
              to run sshd as a non-root user.
 
      UsePrivilegeSeparation
-             Specifies whether sshd separates privileges by creating an un-
-             privileged child process to deal with incoming network traffic.
+             Specifies whether sshd separates privileges by creating an
+             unprivileged child process to deal with incoming network traffic.
              After successful authentication, another process will be created
              that has the privilege of the authenticated user.  The goal of
              privilege separation is to prevent privilege escalation by con-
@@ -387,11 +387,11 @@
              When X11 forwarding is enabled, there may be additional exposure
              to the server and to client displays if the sshd proxy display is
              configured to listen on the wildcard address (see X11UseLocalhost
-             below), however this is not the default.  Additionally, the au-
-             thentication spoofing and authentication data verification and
-             substitution occur on the client side.  The security risk of us-
-             ing X11 forwarding is that the client's X11 display server may be
-             exposed to attack when the ssh client requests forwarding (see
+             below), however this is not the default.  Additionally, the
+             authentication spoofing and authentication data verification and
+             substitution occur on the client side.  The security risk of
+             using X11 forwarding is that the client's X11 display server may
+             be exposed to attack when the ssh client requests forwarding (see
              the warnings for ForwardX11 in ssh_config(5)).  A system adminis-
              trator may have a stance in which they want to protect clients
              that may expose themselves to attack by unwittingly requesting
@@ -411,8 +411,8 @@
              proxy display.  However, some older X11 clients may not function
              with this configuration.  X11UseLocalhost may be set to ``no'' to
              specify that the forwarding server should be bound to the wild-
-             card address.  The argument must be ``yes'' or ``no''.  The de-
-             fault is ``yes''.
+             card address.  The argument must be ``yes'' or ``no''.  The
+             default is ``yes''.
 
      XAuthLocation
              Specifies the full pathname of the xauth(1) program.  The default
@@ -457,4 +457,4 @@
      versions 1.5 and 2.0.  Niels Provos and Markus Friedl contributed support
      for privilege separation.
 
-OpenBSD 3.4                   September 25, 1999                             7
+BSD                           September 25, 1999                           BSD
Only in openssh-3.7.1p2: stamp-h.in
